# -*- coding: utf-8 -*-
#COPYRIGHT 2018 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
from arcpy.arcobjects._base import _ObjectWithoutInitCall, passthrough_attr
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
from arcpy.geoprocessing._base import gp_fixargs
from arcpy.pdfdocument import PDFDocument, PDFDocumentOpen, PDFDocumentCreate
from arcpy.utils import ArgAdaptor
from arcpy._symbology import Symbology, ColorRamp, ClassBreak, RasterClassBreak, Symbol, Item, RasterItem, ItemGroup
from arcpy._renderer import UniqueValueRenderer, SimpleRenderer, Graduated_colors_renderer, Graduated_symbols_renderer
from arcpy import metadata
class constants(ArgAdaptor):
    """Represents the constants that can be passed into various ExportTo* mp functions"""
    __args__ = {
        # For add position
        'add_position': {
            'AUTO_ARRANGE': 'auto_arrange',
            'BOTTOM': 'bottom',
            'TOP': 'top'
        },
        # For color mode
        'color_mode': {
            '24-BIT_TRUE_COLOR': 1,
            '8-BIT_ADAPTIVE_PALETTE': 2,
            '8-BIT_GRAYSCALE': 3,
            '32-BIT_WITH_ALPHA': 4,
            '32-BIT_CMYK_TRUE_COLOR': 5,
            '40-BIT_CMYK_WITH_ALPHA': 6
        },
        # For element type
        'element_type': {
            'GRAPHIC_ELEMENT': 'GRAPHIC_ELEMENT',
            'LEGEND_ELEMENT': 'LEGEND_ELEMENT',
            'MAPFRAME_ELEMENT': 'MAPFRAME_ELEMENT',
            'MAPSURROUND_ELEMENT': 'MAPSURROUND_ELEMENT',
            'PICTURE_ELEMENT': 'PICTURE_ELEMENT',
            'TEXT_ELEMENT': 'TEXT_ELEMENT'
        },
        # For encryption
        'encryption': {
            'RC4': 2
        },
        # For extrusion type
        'extrusion_type': {
            'ABSOLUTE_HEIGHT': 'ABSOLUTE_HEIGHT',
            'BASE_HEIGHT': 'BASE_HEIGHT',
            'MAX_HEIGHT': 'MAX_HEIGHT',
            'MIN_HEIGHT': 'MIN_HEIGHT',
            'NONE': 'NONE'
        },
        # For image compression
        'image_compression': {
            'NONE': 1,
            'RLE': 2,
            'LZW': 3,
            'DEFLATE': 4,
            'JPEG': 5,
            'ADAPTIVE': 6
        },
        # For image quality
        'image_quality': {
            'BEST': 1,
            'BETTER': 2,
            'NORMAL': 3,
            'FASTER': 4,
            'FASTEST': 5
        },
        # For insert position
        'insert_position': {
            'AFTER': 'after',
            'BEFORE': 'before'
        },
        # For jpeg color mode
        'jpeg_color_mode': {
            '24-BIT_TRUE_COLOR': 1,
            '8-BIT_GRAYSCALE': 3
        },
        # For layer property
        'layer_property': {
            'BRIGHTNESS': 'brightness',
            'CONNECTIONPROPERTIES': 'connectionProperties',
            'CONTRAST': 'contrast',
            'DATASOURCE': 'dataSource',
            'DEFINITIONQUERY': 'definitionQuery',
            'LONGNAME': 'longName',
            'MAXTHRESHOLD': 'maxThreshold',
            'MINTHRESHOLD': 'minThreshold',
            'NAME': 'name',
            'TRANSPARENCY': 'transparency'
        },
        # For layers attributes
        'layers_attributes': {
            'NONE': 1,
            'LAYERS_ONLY': 2,
            'LAYERS_AND_ATTRIBUTES': 3
        },
        # For method
        'method': {
            'DIFFERENCE': 'DIFFERENCE',
            'INTERSECT': 'INTERSECT',
            'NEW': 'NEW',
            'SYMDIFFERENCE': 'SYMDIFFERENCE',
            'UNION': 'UNION'
        },
        # For pdf layout
        'pdf_layout': {
            'DONT_CARE': 0,
            'SINGLE_PAGE': 1,
            'ONE_COLUMN': 2,
            'TWO_COLUMN_LEFT': 3,
            'TWO_COLUMN_RIGHT': 4,
            'TWO_PAGE_LEFT': 5,
            'TWO_PAGE_RIGHT': 6
        },
        # For pdf open view
        'pdf_open_view': {
            'VIEWER_DEFAULT': 0,
            'USE_NONE': 1,
            'USE_THUMBS': 2,
            'USE_BOOKMARKS': 3,
            'FULL_SCREEN': 4,
            'LAYERS': 5,
            'ATTACHMENT': 6
        },
        # For permissions
        'permissions': {
            'ALL': -268435457,
            'OPEN': 1,
            'SECURE': 2,
            'PRINT': 4,
            'EDIT': 8,
            'COPY': 16,
            'EDIT_NOTES': 32,
            'FILL_AND_SIGN': 256,
            'DOC_ASSEMBLY': 1024,
            'HIGH_PRINT': 2052,
            'ALL_MASTER': 2104
        },
        # For server type
        'server_type': {
            'HOSTING_SERVER': 'HOSTING_SERVER'
        },
        # For service type
        'service_type': {
            'FEATURE_ACCESS': 'FEATURE_ACCESS',
            'TILED': 'TILED'
        },
        # For tiff compression
        'tiff_compression': {
            'NONE': 1,
            'JPEG': 2,
            'PACK_BITS': 3,
            'LZW': 4,
            'DEFLATE': 5
        },
        'page_range_type': {
            'ALL': 'ALL',
            'CURRENT': 'CURRENT',
            'RANGE': 'RANGE',
            'SELECTED': 'SELECTED'
        },
        'report_page_range_type': {
            'ALL': 'ALL',
            'LAST': 'LAST',
            'EVEN': 'EVEN',
            'ODD': 'ODD',
            'RANGE': 'RANGE',
        },
        'multiple_files': {
            'PDF_SINGLE_FILE': 'PDF_SINGLE_FILE',
            'PDF_MULTIPLE_FILES_PAGE_NAME': 'PDF_MULTIPLE_FILES_PAGE_NAME',
            'PDF_MULTIPLE_FILES_PAGE_NUMBER': 'PDF_MULTIPLE_FILES_PAGE_NUMBER'
        },
        # For CIM version
        'cim_version': {
            'V2': 2,
        },
        
        # For time_inclusion
        'time_inclusion': {
            'INCLUDE_START_AND_END': 'INCLUDE_START_AND_END',
            'INCLUDE_ONLY_START': 'INCLUDE_ONLY_START',
            'INCLUDE_ONLY_END': 'INCLUDE_ONLY_END',
            'EXCLUDE_START_AND_END': 'EXCLUDE_START_AND_END'
        },
        }
class ArcGISProject(_ObjectWithoutInitCall):
    """ArcGISProject(aprx_path)

       Provides a reference to an ArcGIS project ( .aprx ) stored on disk or to
       the project currently loaded within the ArcGIS Pro application using the
       CURRENT keyword.

         aprx_path(String):
       A string that includes the full system path and file name of an existing
       ArcGIS project ( .aprx ) or a string that contains the CURRENT keyword."""
    dateSaved = passthrough_attr('dateSaved')
    defaultGeodatabase = passthrough_attr('defaultGeodatabase')
    defaultToolbox = passthrough_attr('defaultToolbox')
    filePath = passthrough_attr('filePath')
    activeMap = passthrough_attr('activeMap')
    homeFolder = passthrough_attr('homeFolder')
    documentVersion = passthrough_attr('version')
    activeView = passthrough_attr('activeView')
    metadata = passthrough_attr('metadata')
    def importDocument(self, document_path, include_layout=True, reuse_existing_maps = False):
        """ArcGISProject.importDocument(document_path, {include_layout}, {reuse_existing_maps})

           Imports map ( .mxd ), globe ( .3dd ) and scene ( .sxd ) documents
           into an ArcGIS Pro project.

             document_path(String):
           A string that includes the system path and name of a ( .mxd , .3dd ,
           or .sxd ) document  to import.

             include_layout{Boolean}:
           A Boolean indicating if the layout from a map document ( .mxd ) is
           imported.  If  set to True , the layout and all data frames are
           imported. If set to False , only the data frames are imported.  This
           parameter is ignored for globe ( .3dd ) and scene ( .sxd ) documents.

             reuse_existing_maps{Boolean}:
           A Boolean to check if the maps referenced by the layout already exist
           in the project. If set to True, update layout to reference the existing
           maps. The default is set to False. """
        return convertArcObjectToPythonObject(self._arc_object.importDocument(*gp_fixargs((document_path, include_layout, reuse_existing_maps), True)))

    def listBrokenDataSources(self):
        """ArcGISProject.listBrokenDataSources()

           Returns a Python list of Layer and/or Table objects that have broken
           connections to their original source data for all maps in a project."""
        return convertArcObjectToPythonObject(self._arc_object.listBrokenDataSources(*gp_fixargs((), True)))

    def listLayouts(self, wildcard=None):
        """ArcGISProject.listLayouts({wildcard})

           Returns a Python list of Layout objects in an ArcGIS project ( .aprx
           ).

             wildcard{String}:
           A wildcard is based on the layout name and is not case sensitive.  A
           combination of asterisks (*) and characters can be used to help
           limit the resulting list."""
        return convertArcObjectToPythonObject(self._arc_object.listLayouts(*gp_fixargs((wildcard,), True)))

    def listReports(self, wildcard=None):
        """ArcGISProject.listReports({wildcard})

           Returns a Python list of Report objects in an ArcGIS project ( .aprx
           ).

             wildcard{String}:
           A wildcard is based on the report name and is not case sensitive.  A
           combination of asterisks (*) and characters can be used to help
           limit the resulting list."""
        return convertArcObjectToPythonObject(self._arc_object.listReports(*gp_fixargs((wildcard,), True)))

    def listMaps(self, wildcard=None):
        """ArcGISProject.listMaps({wildcard})

           Returns a Python list of Map objects in an ArcGIS project ( .aprx ).

             wildcard{String}:
           A wildcard is based on the map name and is not case sensitive. A
           combination of asterisks (*) and characters can be used to help
           limit the resulting list."""
        return convertArcObjectToPythonObject(self._arc_object.listMaps(*gp_fixargs((wildcard,), True)))

    def save(self):
        """ArcGISProject.save()

           Saves changes to an ArcGISProject ( .aprx )."""
        return convertArcObjectToPythonObject(self._arc_object.save(*gp_fixargs((), True)))

    def saveACopy(self, file_name):
        """ArcGISProject.saveACopy(file_name)

           Saves an ArcGISProject ( .aprx ) to a new file path or name.

             file_name(String):
           A string used to save an ArcGISProject ( .aprx ) to a new file path
           or file name."""
        return convertArcObjectToPythonObject(self._arc_object.saveACopy(*gp_fixargs((file_name,), True)))

    def updateConnectionProperties(self, current_connection_info, new_connection_info, auto_update_joins_and_relates=True, validate=True, ignore_case=False):
        """ArcGISProject.updateConnectionProperties(current_connection_info,
           new_connection_info, {auto_update_joins_and_relates}, {validate}, {ignore_case})

           Replaces connection properties using a dictionary or a path to a
           workspace.

             current_connection_info(String):
           A string that represents the workspace path or a Python dictionary
           that contains connection properties to the source you want to update.

             new_connection_info(String):
           A string that represents the workspace path or a Python dictionary
           that contains connection properties with the new source information.

             auto_update_joins_and_relates{Boolean}:
           If  set to True , the updateConnectionProperties method will also
           update the connections for associated joins or relates.

             validate{Boolean}:
           If  set to True , the connection properties will only be updated if
           the new_connection_info value is a valid connection.  If it is not
           valid, the connection will not be replaced.   If set to False , the
           method will set all connections to match the new_connection_info ,
           regardless of a valid match.  In this case, if a match does not
           exist, then the data sources would be broken.

             ignore_case{Boolean}:
           If set to True, UpdateConnectionProperties will ignore the case of
           current_connection_info. The default value is False, where
           UpdateConnectionProperties will honor the case of current_connection_info.
           The ignore_case parameter doesn't apply to the new_connection_info parameter. """
        return convertArcObjectToPythonObject(self._arc_object.updateConnectionProperties(*gp_fixargs((current_connection_info, new_connection_info, auto_update_joins_and_relates, validate, ignore_case), True)))

    def listColorRamps(self, wildcard=None):

        """ArcGISProject.listColorRamps({wildcard})
           wildcard{String}
        """
        return convertArcObjectToPythonObject(self._arc_object.listColorRamps(*gp_fixargs((wildcard,), True)))

    def __init__(self, aprx_path):
        """ArcGISProject(aprx_path)

           Provides a reference to an ArcGIS project ( .aprx ) stored on disk or to the project currently loaded within the ArcGIS Pro application using the CURRENT keyword.

             aprx_path(String):
           A string that includes the full system path and file name of an existing ArcGIS project ( .aprx ) or a string that contains the CURRENT keyword."""
        import arcgisscripting
        self._arc_object = arcgisscripting._mapping.ArcGISProject(*gp_fixargs((aprx_path,), True))

class Bookmark(_ObjectWithoutInitCall):
    """Provides access to bookmark methods and properties."""
    hasThumbnail = passthrough_attr('hasThumbnail')
    map = passthrough_attr('map')
    name = passthrough_attr('name')
    def updateThumbnail(self):
        """Bookmark.updateThumbnail()

           Updates a bookmark's thumbnail image."""
        return convertArcObjectToPythonObject(self._arc_object.updateThumbnail(*gp_fixargs((), True)))

    def __eq__(self, other):
        if type(self)!= type(other):
            return False
        else:
            return convertArcObjectToPythonObject(self._arc_object.isBookmarkSame(*gp_fixargs((other,), True)))

class Camera(_ObjectWithoutInitCall):
    """The Camera object provides access to  2D and 3D viewer properties that
       control the display in a MapFrame ."""
    heading = passthrough_attr('heading')
    mode = passthrough_attr('mode')
    pitch = passthrough_attr('pitch')
    roll = passthrough_attr('roll')
    scale = passthrough_attr('scale')
    X = passthrough_attr('X')
    Y = passthrough_attr('Y')
    Z = passthrough_attr('Z')
    def getExtent(self):
        """Camera.getExtent()

           Returns an Extent object for a 2D map frame."""
        return convertArcObjectToPythonObject(self._arc_object.getExtent(*gp_fixargs((), True)))

    def setExtent(self, extent):
        """Camera.setExtent(extent)

           Sets the Extent for a map frame in a layout.

             extent(Extent):
           A geoprocessing Extent object."""
        return convertArcObjectToPythonObject(self._arc_object.setExtent(*gp_fixargs((extent,), True)))

    def __eq__(self, other):
        if type(self)!= type(other):
            return False
        else:
            return convertArcObjectToPythonObject(self._arc_object.isCameraSame(*gp_fixargs((other,), True)))

class GraphicElement(_ObjectWithoutInitCall):
    """The GraphicElement object provides access to properties that enables its
       repositioning on the page layout, as well as methods that allow for
       duplicating and deleting existing graphic elements."""
    elementHeight = passthrough_attr('elementHeight')
    elementPositionX = passthrough_attr('elementPositionX')
    elementPositionY = passthrough_attr('elementPositionY')
    elementRotation = passthrough_attr('elementRotation')
    elementWidth = passthrough_attr('elementWidth')
    isGroup = passthrough_attr('isGroup')
    locked = passthrough_attr('locked')
    name = passthrough_attr('name')
    type = passthrough_attr('type')
    visible = passthrough_attr('visible')
    def clone(self, suffix=None):
        """GraphicElement.clone({suffix})

           Provides a mechanism to clone an existing graphic element on a page
           layout.

             suffix{String}:
           An optional string that is used to tag each newly created graphic
           element.  The new element will get the same element name as the
           parent graphic plus the suffix value along with  a numeric sequencer.
           For example, if the parent element name is Line and the suffix value
           is _copy , the newly cloned elements are named Line_copy ,
           Line_copy_1 , Line_copy_2 , and so on.  If a suffix is not provided,
           the results resemble Line_1 , Line_2 , Line_3 , and so on."""
        return convertArcObjectToPythonObject(self._arc_object.clone(*gp_fixargs((suffix,), True)))

    def delete(self):
        """GraphicElement.delete()

           Provides a mechanism to delete an existing graphic element on a page
           layout."""
        return convertArcObjectToPythonObject(self._arc_object.delete(*gp_fixargs((), True)))

    def __eq__(self, other):
        if type(self)!= type(other):
            return False
        else:
            return convertArcObjectToPythonObject(self._arc_object.isGraphicElementSame(*gp_fixargs((other,), True)))

class LabelClass(_ObjectWithoutInitCall):
    """Provides access to a layer's label class properties."""
    expression = passthrough_attr('expression')
    name = passthrough_attr('name')
    SQLQuery = passthrough_attr('SQLQuery')
    visible = passthrough_attr('visible')

class Layer(_ObjectWithoutInitCall):
    """Layer(lyr_file_path)

       References a layer file stored on disk.

         lyr_file_path(String):
       A string that includes the full path and file name of an existing layer
       file.  The supported extensions are .lyr or .lyrx ."""
    brightness = passthrough_attr('brightness')
    contrast = passthrough_attr('contrast')
    connectionProperties = passthrough_attr('connectionProperties', True)
    dataSource = passthrough_attr('dataSource', True)
    definitionQuery = passthrough_attr('definitionQuery')
    is3DLayer = passthrough_attr('is3DLayer')
    isBroken = passthrough_attr('isBroken')
    isFeatureLayer = passthrough_attr('isFeatureLayer')
    isSceneLayer = passthrough_attr('isSceneLayer')
    isBasemapLayer = passthrough_attr('isBasemapLayer')
    isGroupLayer = passthrough_attr('isGroupLayer')
    isNetworkAnalystLayer = passthrough_attr('isNetworkAnalystLayer')
    isNetworkDatasetLayer = passthrough_attr('isNetworkDatasetLayer')
    isRasterLayer = passthrough_attr('isRasterLayer')
    isWebLayer = passthrough_attr('isWebLayer')
    isTimeEnabled = passthrough_attr('isTimeEnabled')
    longName = passthrough_attr('longName')
    maxThreshold = passthrough_attr('maxThreshold')
    minThreshold = passthrough_attr('minThreshold')
    name = passthrough_attr('name')
    showLabels = passthrough_attr('showLabels')
    transparency = passthrough_attr('transparency')
    visible = passthrough_attr('visible')
    symbology = passthrough_attr('symbology')
    metadata = passthrough_attr('metadata')
    time = passthrough_attr('time')
    URI = passthrough_attr('URI')

    @constants.maskargs
    def extrusion(self, extrusion_type='NONE', expression=None):
        """Layer.extrusion({extrusion_type}, {expression})

           Extrudes 2D features in a layer to display 3D symbology.

             extrusion_type{String}:
           A string that specifies the extrusion method.  The default value is
           NONE which turns off layer extrusion.

            * ABSOLUTE_HEIGHT: The feature is extruded to the specified z-value,
            as a flat top, regardless of the z-values of the feature.

            * BASE_HEIGHT: A z-value is calculated for each vertex of the
            feature's base, and the feature is extruded to the various z-values
            creating a multifaceted top.

            * MAX_HEIGHT: Adds extrusion height to the minimum z-value of the
            feature, and the feature is extruded to a flat top at that value.

            * MIN_HEIGHT: Adds extrusion height to the minimum z-value of the
            feature, and the feature is extruded to a flat top at that value.

            * NONE: Features are not extruded.

             expression{String}:
           A string that defines the extrusion expression, which provides an
           absolute extrusion height  for each feature."""
        return convertArcObjectToPythonObject(self._arc_object.extrusion(*gp_fixargs((extrusion_type, expression), True)))

    def getSelectionSet(self):
        """Layer.getSelectionSet()

           Returns a layer's selection as a Python set of object IDs."""
        return convertArcObjectToPythonObject(self._arc_object.getSelectionSet(*gp_fixargs((), True)))

    def listLabelClasses(self, wildcard=None):
        """Layer.listLabelClasses({wildcard})

           Returns a Python list of LabelClass objects in a layer.

             wildcard{String}:
           A wildcard is based on the label class name and is not case
           sensitive. A combination of asterisks (*) and characters can be used
           to help
           limit the resulting list."""
        return convertArcObjectToPythonObject(self._arc_object.listLabelClasses(*gp_fixargs((wildcard,), True)))

    def listLayers(self, wildcard=None):
        """Layer.listLayers({wildcard})

           Returns a Python list of Layer objects in a layer file.

             wildcard{String}:
           A wildcard is based on the layer name and is not case sensitive. A
           combination of asterisks (*) and characters can be used to help
           limit the resulting list."""
        return convertArcObjectToPythonObject(self._arc_object.listLayers(*gp_fixargs((wildcard,), True)))

    def listTables(self, wildcard=None):
        """Layer.listTables({wildcard})

           Returns a Python list of Table objects in a layer file.

             wildcard{String}:
           A wildcard is based on the table name and is not case sensitive. A
           combination of asterisks (*) and characters can be used to help
           limit the resulting list."""
        return convertArcObjectToPythonObject(self._arc_object.listTables(*gp_fixargs((wildcard,), True)))

    def listDefinitionQueries(self, wildcard=None):
        """Layer.listDefinitionQueries({wildcard})

           Returns a Python list of DefinitionQueries that exist within a map.

             wildcard{String}:
           A wildcard is based on the defQuery name and is not case sensitive. A
           combination of asterisks (*) and characters can be used to help
           limit the resulting list."""
        return convertArcObjectToPythonObject(self._arc_object.listDefinitionQueries(*gp_fixargs((wildcard,), True)))

    def saveACopy(self, file_name):
        """Layer.saveACopy(file_name)

           Saves a layer to a layer file ( .lyrx ).

             file_name(String):
           A string that includes the location and name of the output layer file
           ( .lyrx )."""
        return convertArcObjectToPythonObject(self._arc_object.saveACopy(*gp_fixargs((file_name,), True)))

    @constants.maskargs
    def setSelectionSet(self, oidList=None, method='NEW'):
        """Layer.setSelectionSet({oidList}, {method})

           Sets a layer's selection using a Python set of Object IDs.

             oidList{Integer}:
           A Python set of Object IDs to use along with the appropriate
           selection method.

             method{String}:
           A string that specifies which selection method to use.

            * NEW: Creates a new feature selection from the oidList .

            * DIFFERENCE: Selects the features that are not in the current
            selection but are in the oidList .

            * INTERSECT: Selects the features that are in the current selection
            and the oidList .

            * SYMDIFFERENCE: Selects the features that are in the current
            selection or the oidList but not both.

            * UNION: Selects all the features in both the current selection and
            those in the oidList ."""
        return convertArcObjectToPythonObject(self._arc_object.setSelectionSet(*gp_fixargs((oidList, method), True)))

    def supports(self, layer_property):
        """Layer.supports(layer_property)

           Used to determine if a particular layer type supports a property on
           the layer object.  Not all layers support the same set of properties;
           the supports property can be used to test if a layer supports that
           property before attempting to set it.

             layer_property(String):
           The name of a particular layer property that will be tested.

            * BRIGHTNESS:   A raster layer's brightness value.

            * CONNECTIONPROPERTIES: A Layer's connection information.

            * CONTRAST:   A raster layer's contrast value

            * CREDITS:   A layer's credit information.

            * DATASOURCE:   A layer's file path or connection file.

            * DEFINITIONQUERY:   A layer's definition query string.

            * LONGNAME:   A layer's path including the group layers it may be
            nested within.

            * MAXTHRESHOLD:   A layer's maximum threshold to display the
            features.

            * MINTHRESHOLD:   A layer's minimum threshold to display the
            features.

            * NAME:   A layer's name.

            * TRANSPARENCY:   A layer's transparency value. 
            
            * URI:   A layer's URI/CIM path value. """
        return convertArcObjectToPythonObject(self._arc_object.supports(*gp_fixargs((layer_property,), True)))

    def updateConnectionProperties(self, current_connection_info, new_connection_info, auto_update_joins_and_relates=True, validate=True, ignore_case=False):
        """Layer.updateConnectionProperties(current_connection_info,
           new_connection_info, {auto_update_joins_and_relates}, {validate}, {ignore_case})

           Replaces connection properties using a dictionary or a path to a
           workspace.

             current_connection_info(String):
           A string that represents the workspace path or a Python dictionary
           that contains connection properties to the source you want to update.

             new_connection_info(String):
           A string that represents the workspace path or a Python dictionary
           that contains connection properties with the new source information.

             auto_update_joins_and_relates{Boolean}:
           If  set to True , the updateConnectionProperties method will also
           update the connections for associated joins or relates.

             validate{Boolean}:
           If  set to True , the connection properties will only be updated if
           the new_connection_info value is a valid connection.  If it is not
           valid, the connection will not be replaced.   If set to False , the
           method will set all connections to match the new_connection_info ,
           regardless of a valid match.  In this case, if a match does not
           exist, then the data sources would be broken.

             ignore_case{Boolean}:
           If set to True, UpdateConnectionProperties will ignore the case of
           current_connection_info. The default value is False, where
           UpdateConnectionProperties will honor the case of current_connection_info.
           The ignore_case parameter doesn't apply to the new_connection_info parameter. """
        return convertArcObjectToPythonObject(self._arc_object.updateConnectionProperties(*gp_fixargs((current_connection_info, new_connection_info, auto_update_joins_and_relates, validate, ignore_case), True)))

    def updateDefinitionQueries(self, definitionQueries):
        """
        Layer.updateDefinitionQueries(definitionQueries)

        """
        return convertArcObjectToPythonObject(self._arc_object.updateDefinitionQueries(*gp_fixargs((definitionQueries,), True)))

    def updateLayerFromJSON(self, json_data):
        """
        Layer.updateLayerFromJSON(json_data)

        """
        return convertArcObjectToPythonObject(self._arc_object.UpdateLayerFromJSON(*gp_fixargs((json_data,), True)))

    def enableTime(self, startTimeField=None, endTimeField=None, autoCalculateTimeRange=True, timeDimension=None):
        """Layer.enableTime({startTimeField}, {endTimeField}, {autoCalculateTimeRange}, {timeDimension})

           Returns a layerTime object created using the optional fields.
           
             startTimeField:
           A field from the attribute table for the startTimeField. Default is None.

             endTimeField:
           A field from the attribute table for the endTimeField. Default is None.

             autoCalculateTimeRange{Boolean}:
           If  set to True , the startTime and endTime is auto calculated based off 
           data in attribute table.
           
             timeDimension:
           A field representing the timeDimension name."""
        return convertArcObjectToPythonObject(self._arc_object.enableTime(*gp_fixargs((startTimeField, endTimeField, autoCalculateTimeRange, timeDimension), True)))

    def disableTime(self):
        """
        Layer.disableTime()

        """
        return convertArcObjectToPythonObject(self._arc_object.disableTime(*gp_fixargs((), True)))
    
    def __str__(self):
        return self.longName

    def __eq__(self, other):
        if type(self)!= type(other):
            return False
        else:
            return convertArcObjectToPythonObject(self._arc_object.isLayerSame(*gp_fixargs((other,), True)))

    @constants.maskargs
    def getDefinition(self, cim_version):
        """Layer.getDefinition(cim_version)

        Gets a layer's CIM definition.

          cim_version(String):
        A string that represents the major version of the CIM. """
        from .cim.cimloader import GetJSONTypeOBJ
        import json
        return GetJSONTypeOBJ(json.loads(convertArcObjectToPythonObject(self._arc_object.GetCimJSONString(*gp_fixargs((), True)))))

    @constants.maskargs
    def setDefinition(self, definition_object):
        """Layer.setDefinition(definition_object)

        Sets a layer's CIM definition.

          definition_object(Object):
        A modified CIM defintion object originally retrieved using getDefinition. """
        from .cim.cimloader import  CimJsonEncoder
        import json
        json_data = json.dumps(definition_object, cls=CimJsonEncoder)
        return convertArcObjectToPythonObject(self._arc_object.SetCimJSONString(json_data))

class LayerFile(_ObjectWithoutInitCall):
    """LayerFile(layer_file_path)

       References a layer file ( .lyr or .lyrx ) stored on disk.

         layer_file_path(String):
       A string that includes the full system path and file name of an existing
       layer file."""
    filePath = passthrough_attr('filePath')
    version = passthrough_attr('version')
    metadata = passthrough_attr('metadata')
    @constants.maskargs
    def addLayer(self, add_layer_or_layerfile, add_position='AUTO_ARRANGE'):
        """LayerFile.addLayer(add_layer_or_layerfile, {add_position})

           Provides the ability to add a Layer or LayerFile to a map within a
           project ( .aprx ) using basic placement options.

             add_layer_or_layerfile(Layer):
           A reference to a Layer or LayerFile object representing the layer or
           layers  to be added.

             add_position{String}:
           A constant that determines the placement of the added layer or layers
           in a map.

            * AUTO_ARRANGE: Automatically places the layer or layers based on
            its layer weight rules and geometry.

            * BOTTOM: Places the layer or layers at the bottom of the TOC layer
            stack.

            * TOP: Places the layer or layers at the top of the TOC layer stack."""
        return convertArcObjectToPythonObject(self._arc_object.addLayer(*gp_fixargs((add_layer_or_layerfile, add_position), True)))

    @constants.maskargs
    def addLayerToGroup(self, target_group_layer, add_layer_or_layerfile, add_position='AUTO_ARRANGE'):
        """LayerFile.addLayerToGroup(target_group_layer, add_layer_or_layerfile,
           {add_position})

           Provides the ability to add a Layer or the contents of a LayerFile to
           an existing group layer in a map within a project ( .aprx ) using
           basic placement options.

             target_group_layer(Layer):
           A reference to an existing group Layer object.

             add_layer_or_layerfile(Layer):
           A reference to a Layer or LayerFile object representing the layer or
           layers  to be added.

             add_position{String}:
           A constant that determines the placement of the added layer or layers
           in the target_group_layer .

            * AUTO_ARRANGE: Automatically places the layer based on its layer
            weight rules and geometry.

            * BOTTOM: Places the layer at the bottom of the TOC layer stack.

            * TOP: Places the layer at the top of the TOC layer stack."""
        return convertArcObjectToPythonObject(self._arc_object.addLayerToGroup(*gp_fixargs((target_group_layer, add_layer_or_layerfile, add_position), True)))

    @constants.maskargs
    def insertLayer(self, reference_layer, insert_layer_or_layerfile, insert_position='BEFORE'):
        """LayerFile.insertLayer(reference_layer, insert_layer_or_layerfile,
           {insert_position})

           Provides the ability to add a Layer or LayerFile to a map within a
           project ( .aprx ) by specifying  a specific location.

             reference_layer(Layer):
           A Layer object representing an existing layer that determines the
           location where the new layer will be inserted.

             insert_layer_or_layerfile(Layer):
           A reference to a Layer or LayerFile object representing the layer or
           layers  to be added.

             insert_position{String}:
           A constant that determines the placement of the added layer or layers
           relative to the reference_layer .

            * AFTER: Inserts the new layer after or below the reference layer.

            * BEFORE: Inserts the new layer before or above the reference layer."""
        return convertArcObjectToPythonObject(self._arc_object.insertLayer(*gp_fixargs((reference_layer, insert_layer_or_layerfile, insert_position), True)))

    def listBrokenDataSources(self):
        """LayerFile.listBrokenDataSources()

           Returns a Python list of Layer objects in a layer file that have
           broken connections to their original source data."""
        return convertArcObjectToPythonObject(self._arc_object.listBrokenDataSources(*gp_fixargs((), True)))

    def listLayers(self, wildcard=None):
        """LayerFile.listLayers({wildcard})

           Returns a Python list of Layer objects in a layer file.

             wildcard{String}:
           A wildcard is based on the layer name and is not case sensitive. A
           combination of asterisks (*) and characters can be used to help
           limit the resulting list."""
        return convertArcObjectToPythonObject(self._arc_object.listLayers(*gp_fixargs((wildcard,), True)))

    def listTables(self, wildcard=None):
        """LayerFile.listTables({wildcard})

           Returns a Python list of Table objects in a layer file.

             wildcard{String}:
           A wildcard is based on the table name and is not case sensitive. A
           combination of asterisks (*) and characters can be used to help
           limit the resulting list."""
        return convertArcObjectToPythonObject(self._arc_object.listTables(*gp_fixargs((wildcard,), True)))

    @constants.maskargs
    def moveLayer(self, reference_layer, move_layer, insert_position='BEFORE'):
        """LayerFile.moveLayer(reference_layer, move_layer, {insert_position})

           Provides the ability to move a layer or group layer in a map to  a
           specific location in the layer stack.

             reference_layer(Layer):
           A Layer object representing an existing layer that determines the
           location where the new layer will be moved.

             move_layer(Layer):
           A reference to a Layer object representing the layer to be moved.

             insert_position{String}:
           A constant that determines the placement of the moved layer relative
           to the reference layer.

            * AFTER: Moves the  layer after or below the reference layer.

            * BEFORE: Moves the layer before or above the reference layer."""
        return convertArcObjectToPythonObject(self._arc_object.moveLayer(*gp_fixargs((reference_layer, move_layer, insert_position), True)))

    def removeLayer(self, remove_layer):
        """LayerFile.removeLayer(remove_layer)

           Provides the ability to remove a layer from a map in a project.

             remove_layer(Layer):
           A reference to a Layer object representing the layer to be removed."""
        return convertArcObjectToPythonObject(self._arc_object.removeLayer(*gp_fixargs((remove_layer,), True)))

    def save(self):
        """LayerFile.save()

           Saves an existing layer file reference to a .lyrx file, even if the
           file referenced was a .lyr file."""
        return convertArcObjectToPythonObject(self._arc_object.save(*gp_fixargs((), True)))

    def saveACopy(self, file_name):
        """LayerFile.saveACopy(file_name)

           Saves a LayerFile to a new path or file name.

             file_name(String):
           A string used to save a LayerFile to a new path or file name.  You
           can only save to .lyrx files."""
        return convertArcObjectToPythonObject(self._arc_object.saveACopy(*gp_fixargs((file_name,), True)))

    def updateConnectionProperties(self, current_connection_info, new_connection_info, auto_update_joins_and_relates=True, validate=True, ignore_case=False):
        """LayerFile.updateConnectionProperties(current_connection_info,
           new_connection_info, {auto_update_joins_and_relates}, {validate}, {ignore_case})

           Replaces connection properties using a dictionary or a path to a
           workspace.

             current_connection_info(String):
           A string that represents the workspace path or a Python dictionary
           that contains connection properties to the source you want to update.

             new_connection_info(String):
           A string that represents the workspace path or a Python dictionary
           that contains connection properties with the new source information.

             auto_update_joins_and_relates{Boolean}:
           If  set to True , the updateConnectionProperties method will also
           update the connections for associated joins or relates.

             validate{Boolean}:
           If  set to True , the connection properties will only be updated if
           the new_connection_info value is a valid connection.  If it is not
           valid, the connection will not be replaced.   If set to False , the
           method will set all connections to match the new_connection_info ,
           regardless of a valid match.  In this case, if a match does not
           exist, then the data sources would be broken.

             ignore_case{Boolean}:
           If set to True, UpdateConnectionProperties will ignore the case of
           current_connection_info. The default value is False, where
           UpdateConnectionProperties will honor the case of current_connection_info.
           The ignore_case parameter doesn't apply to the new_connection_info parameter. """
        return convertArcObjectToPythonObject(self._arc_object.updateConnectionProperties(*gp_fixargs((current_connection_info, new_connection_info, auto_update_joins_and_relates, validate, ignore_case), True)))

    def __init__(self, layer_file_path):
        """LayerFile(layer_file_path)

           References a layer file ( .lyr or .lyrx ) stored on disk.

             layer_file_path(String):
           A string that includes the full system path and file name of an existing layer file."""
        import arcgisscripting
        self._arc_object = arcgisscripting._mapping.LayerFile(*gp_fixargs((layer_file_path,), True))

    def __str__(self):
        return self.filePath

class LayerTime(_ObjectWithoutInitCall):
    """LayerTime provides access to layer time level information in a Layer Object."""
    startTimeField = passthrough_attr('startTimeField')
    endTimeField = passthrough_attr('endTimeField')
    timeFormat = passthrough_attr('timeFormat')
    startTime = passthrough_attr('startTime')
    endTime = passthrough_attr('endTime')
    timeZone = passthrough_attr('timeZone')
    daylightSavings = passthrough_attr('daylightSavings')
    timeOffset = passthrough_attr('timeOffset')
    timeOffsetUnits = passthrough_attr('timeOffsetUnits')
    timeStepInterval = passthrough_attr('timeStepInterval')
    timeStepIntervalUnits = passthrough_attr('timeStepIntervalUnits')
    timeDimension = passthrough_attr('timeDimension')

class Layout(_ObjectWithoutInitCall):
    """The Layout object references a single-page layout in an ArcGIS Pro
       project ( .aprx ).  It provides access to common properties like page
       size and a number of different export methods."""
    name = passthrough_attr('name')
    pageHeight = passthrough_attr('pageHeight')
    pageUnits = passthrough_attr('pageUnits')
    pageWidth = passthrough_attr('pageWidth')
    mapSeries = passthrough_attr('mapSeries')
    metadata = passthrough_attr('metadata')
    URI = passthrough_attr('URI')

    def exportToBMP(self, out_bmp, resolution=96, bmp_color_mode='24-BIT_TRUE_COLOR', bmp_image_compression='NONE', embed_color_profile=True, clip_to_elements=False):
        """Layout.exportToBMP(out_bmp, {resolution}, {bmp_color_mode}, {bmp_image_compression}, {embed_color_profile}, {clip_to_elements})

           Exports the page layout to the Microsoft Windows Bitmap format (BMP).

             out_bmp(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             bmp_color_mode{String}:
          This value specifies the number of bits used to describe color.

            * 8-BIT_ADAPTIVE_PALETTE:   8-bit adaptive palette

            * 8-BIT_GRAYSCALE:   8-bit grayscale

            * 24-BIT_TRUE_COLOR:   24-bit true color.

             bmp_image_compression{String}:
          A string that specifies the compression scheme used to compress image or raster
          data in the output file. This option only applies to 8-bit bmp_color_mode options.

            * NONE:   Compression is not applied.

            * RLE:   Run-length encoded compression.

             embed_color_profile{Boolean}:
          If set to True, color profile information is embedded in the image's metadata.

             clip_to_elements{Boolean}:
          If set to True, the layout is clipped to the smallest bounding box that includes
          all layout elements."""
        return convertArcObjectToPythonObject(self._arc_object.exportToBMP(*gp_fixargs((out_bmp, resolution, bmp_color_mode, bmp_image_compression, embed_color_profile, clip_to_elements), True)))

    def exportToEMF(self, out_emf, resolution=96, image_quality='BEST', output_as_image=False, clip_to_elements=False):
        """Layout.exportToEMF(out_emf, {resolution}, {image_quality}, {output_as_image}, {clip_to_elements})

           Exports the page layout to the Enhanced Metafile (EMF) format.

             out_emf(String):
           A string that represents the system path and file name for the output
           export file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             image_quality{String}:
           A string that specifies output image quality, the draw resolution of
           map layers that draw as rasters.

             *  BEST —An output image quality resample ratio of 1

             *  BETTER —An output image quality resample ratio of 2

             *  NORMAL —An output image quality resample ratio of 3

             *  FASTER —An output image quality resample ratio of 4

             *  FASTEST —An output image quality resample ratio of 5

             output_as_image{Boolean}:
           If set to True, vector content can be saved as an image. Selecting this option
          for maps or layouts that contain vector layers with a high density of vertices
          can reduce the output file size. When exporting to PDF and this option is set to
          True, you cannot view PDF layers in the output.

             clip_to_elements{Boolean}:
           If set to True, the layout is clipped to the smallest bounding box that includes
           all layout elements."""
        return convertArcObjectToPythonObject(self._arc_object.exportToEMF(*gp_fixargs((out_emf, resolution, image_quality, output_as_image, clip_to_elements), True)))

    def exportToEPS(self, out_eps, resolution=96, image_compression='DEFLATE', image_quality='BEST',
                   embed_fonts=True, output_as_image=False, clip_to_elements=False):
        """Layout.exportToEPS(out_eps, {resolution}, {image_compression}, {image_quality}, {embed_fonts}, {output_as_image}, {clip_to_elements})

           Exports the page layout to an Encapsulated PostScript (EPS) format.

             out_eps(String):
           A string that represents the system path and file name for the output
           export file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             image_compression{String}:
           A string that specifies the compression scheme used to compress image
           or raster data in the output file.

             image_quality{String}:
           A string that specifies output image quality, the draw resolution of
           map layers that draw as rasters.

             embed_fonts{Boolean}:
           A Boolean that controls the embedding of fonts in the export file.
           Font embedding allows text and character markers to be displayed correctly
           when the document is viewed on a computer that does not have the necessary
           fonts installed.

             output_as_image{Boolean}:
           If set to True, vector content can be saved as an image. Selecting this option
          for maps or layouts that contain vector layers with a high density of vertices
          can reduce the output file size. When exporting to PDF and this option is set to
          True, you cannot view PDF layers in the output.

              clip_to_elements{Boolean}:
           If set to True, the layout is clipped to the smallest bounding box that includes
           all layout elements."""
        return convertArcObjectToPythonObject(self._arc_object.exportToEPS(*gp_fixargs((out_eps, resolution, image_compression, image_quality, embed_fonts, output_as_image, clip_to_elements), True)))

    def exportToGIF(self, out_gif, resolution=96, gif_color_mode='8-BIT_ADAPTIVE_PALETTE',
                    clip_to_elements=False):
        """Layout.exportToGIF(out_gif, {resolution}, {gif_color_mode}, {clip_to_elements})

           Exports the page layout to the Graphic Interchange format (GIF).

             out_gif(String):
           A string that represents the system path and file name for the output
           export file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             gif_color_mode{String}:
           This value specifies the number of bits used to describe color.

            * 8-BIT_ADAPTIVE_PALETTE:   8-bit adaptive palette

            * 8-BIT_GRAYSCALE:   8-bit grayscale

             clip_to_elements{Boolean}:
           If set to True , the layout is clipped to the smallest bounding box
           that includes all layout elements."""
        return convertArcObjectToPythonObject(self._arc_object.exportToGIF(*gp_fixargs((out_gif, resolution, gif_color_mode, clip_to_elements), True)))

    def exportToJPEG(self, out_jpg, resolution=96, jpeg_color_mode='24-BIT_TRUE_COLOR', jpeg_quality=80, embed_color_profile=True, clip_to_elements=False):
        """Layout.exportToJPEG(out_jpg, {resolution}, {jpeg_color_mode},
           {jpeg_quality}, {embed_color_profile}, {clip_to_elements})

           Exports the page layout to the Joint Photographic Experts Group
           format (JPEG) .

             out_jpg(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             jpeg_color_mode{String}:
           This value specifies the number of bits used to describe color.

            * 8-BIT_GRAYSCALE:   8-bit grayscale

            * 24-BIT_TRUE_COLOR:   24-bit true color

             jpeg_quality{Integer}:
           This value (0–100) controls the amount of compression applied to the
           output image. For JPEG, image quality is adversely affected the more
           compression is applied. A higher quality (highest = 100) setting will
           produce sharper images and larger file sizes. A lower quality setting
           will produce more image artifacts and smaller files.

             embed_color_profile{Boolean}:
           If set to True, color profile information is embedded in the image's metadata.

             clip_to_elements{Boolean}:
           If set to True , the layout is clipped to the smallest bounding box
           that includes all layout elements."""
        return convertArcObjectToPythonObject(self._arc_object.exportToJPEG(*gp_fixargs((out_jpg, resolution, False, jpeg_color_mode, jpeg_quality, embed_color_profile, clip_to_elements), True)))

    @constants.maskargs
    def exportToPDF(self, out_pdf, resolution=96, image_quality='BEST', compress_vector_graphics=True, image_compression='ADAPTIVE', embed_fonts=True, layers_attributes='LAYERS_ONLY', georef_info=True, jpeg_compression_quality=80, clip_to_elements=False, output_as_image= False, embed_color_profile=True, pdf_accessibility=False):
        """Layout.exportToPDF(out_pdf, {resolution}, {image_quality},
           {compress_vector_graphics}, {image_compression}, {embed_fonts},
           {layers_attributes}, {georef_info}, {jpeg_compression_quality},
           {clip_to_elements}, {output_as_image}, {embed_color_profile}, {pdf_accessibility})

           Exports the page layout  to the Portable Document Format (PDF).

             out_pdf(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (DPI).

             image_quality{String}:
           A string that defines output image quality, the draw resolution of
           map layers that draw as rasters.

            * BEST:  An output image quality resample ratio of 1.

            * BETTER:  An output image quality resample ratio of 2.

            * NORMAL:  An output image quality resample ratio of 3.

            * FASTER:  An output image quality resample ratio of 4.

            * FASTEST:  An output image quality resample ratio of 5.

             compress_vector_graphics{Boolean}:
           A Boolean that controls compression of vector and text portions of
           the output file. Image compression is defined separately.

             image_compression{String}:
           A string that defines the compression scheme used to compress image
           or raster data in the output file.

            * ADAPTIVE:   Automatically selects the best compression type for
            each image on the page.   JPEG will be used for large images with
            many unique colors.  DEFLATE will be used for all other images.

            * DEFLATE:   A lossless data compression.

            * JPEG:   A lossy data compression.

            * LZW:   Lempel-Ziv-Welch, a lossless data compression.

            * NONE:   Compression is not applied.

            * RLE:   Run-length encoded compression.

             embed_fonts{Boolean}:
           A Boolean that controls the embedding of fonts in the export file.
           Font embedding allows text and character markers to be displayed
           correctly when the document is viewed on a computer that does not
           have the necessary fonts installed.

             layers_attributes{String}:
           A string that controls inclusion of PDF layer and PDF object data
           (attributes) in the export file.

            * LAYERS_ONLY:  Export PDF layers only

            * LAYERS_AND_ATTRIBUTES:  Export PDF layers and feature attributes

            * NONE:  None

             georef_info{Boolean}:
           A Boolean that enables the export of coordinate system information
           for each data frame into the output PDF file.

             jpeg_compression_quality{Integer}:
           A number that controls compression quality value when
           image_compression is set to ADAPTIVE or JPEG . The valid range is 1
           to 100.    A jpeg_compression_quality of 100 provides the best-
           quality images but creates large export files.   The recommended
           range is between 70 and 90.

             clip_to_elements(Boolean):
           If set to True , the layout is clipped to the smallest bounding box
           that includes all layout elements

             output_as_image{Boolean}:
           If set to True to vector content will be saved as an image.
           Selecting this option for maps or layouts that contain vector layers
           with a high density of vertices can drastically reduce the output file
           size. If exporting to PDF and this option set to True, you will not be
           able to view PDF layers in the output.

             embed_color_profile{Boolean}:
           If set to True, color profile information is embedded in the image's metadata.
           
             pdf_accessibility{Boolean}:
           If set to True, enhanced PDF accessibility will occur."""
        return convertArcObjectToPythonObject(self._arc_object.exportToPDF(*gp_fixargs((out_pdf, resolution, image_quality, compress_vector_graphics, image_compression, embed_fonts, layers_attributes, georef_info, jpeg_compression_quality, clip_to_elements, output_as_image, embed_color_profile, pdf_accessibility), True)))

    @constants.maskargs
    def exportToPNG(self, out_png, resolution=96, color_mode='32-BIT_WITH_ALPHA', transparent_background=False, embed_color_profile=True, clip_to_elements=False):
        """Layout.exportToPNG(out_png, {resolution}, {color_mode}, {transparent_background}, {embed_color_profile}, {clip_to_elements})

           Exports the page layout to the Portable Network Graphics format
           (PNG).

             out_png(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             color_mode{String}:
           This value specifies the number of bits used to describe color.

            * 8-BIT_ADAPTIVE_PALETTE:   8-bit adaptive palette

            * 8-BIT_GRAYSCALE:   8-bit grayscale

            * 24-BIT_TRUE_COLOR:   24-bit true color

            * 32-BIT_WITH_ALPHA:   32-bit with alpha

              transparent_background{Boolean}:
            If set to True, the white page background is set to transparent.

              embed_color_profile{Boolean}:
            If set to True, color profile information is embedded in the image's metadata.

              clip_to_elements{Boolean}:
            If set to True, the layout is clipped to the smallest bounding box that includes all layout elements."""
        return convertArcObjectToPythonObject(self._arc_object.exportToPNG(*gp_fixargs((out_png, resolution, False, color_mode, transparent_background, embed_color_profile, clip_to_elements), True)))

    def exportToSVG(self, out_svg, resolution=96, compress_to_svgz=False, image_quality='BEST', embed_fonts=True, output_as_image=False, clip_to_elements=False):
        """Layout.exportToSVG(out_svg, {resolution}, {compress_to_svgz}, {image_quality}, {embed_fonts},
           {output_as_image}, {clip_to_elements})

           Exports the page layout to the Scalable Vector Graphics format (SVG).

             out_svg(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             compress_to_svgz{Boolean}:
           If set to True , the output is compressed.

             image_quality{String}:
           A string that specifies output image quality, the draw resolution of map layers that draw as rasters.

             embed_fonts{Boolean}:
           A Boolean that controls the embedding of fonts in the export file. Font embedding allows text
           and character markers to be displayed correctly when the document is viewed on a computer that
           does not have the necessary fonts installed.

            output_as_image{Boolean}:
          If set to True, vector content can be saved as an image. Selecting this option for maps or
         layouts that contain vector layers with a high density of vertices can reduce the output file
         size. When exporting to PDF and this option is set to True, you cannot view PDF layers in the output.

            clip_to_elements{Boolean}:
          If set to True, the layout is clipped to the smallest bounding box that includes all layout elements."""
        return convertArcObjectToPythonObject(self._arc_object.exportToSVG(*gp_fixargs((out_svg, resolution, compress_to_svgz, image_quality, embed_fonts, output_as_image, clip_to_elements), True)))

    def exportToTGA(self, out_tga, resolution=96, color_mode='24-BIT_TRUE_COLOR', transparent_background=False, clip_to_elements=False):
        """Layout.exportToTGA(out_tga, {resolution}, {color_mode}, {clip_to_elements})

           Exports the page layout to the Truevision Graphics Adapter format
           (TGA).

             out_tga(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             color_mode{String}:
           This value specifies the number of bits used to describe color.

            * 8-BIT_ADAPTIVE_PALETTE:   8-bit adaptive palette

            * 8-BIT_GRAYSCALE:   8-bit grayscale

            * 24-BIT_TRUE_COLOR:   24-bit true color

            * 32-BIT_WITH_ALPHA:   32-bit with alpha.

              transparent_background{Boolean} - If set to True, the white page background is set
              to transparent.

              clip_to_elements{Boolean}:
            If set to True, the layout is clipped to the smallest bounding box that includes all layout elements."""
        return convertArcObjectToPythonObject(self._arc_object.exportToTGA(*gp_fixargs((out_tga, resolution, color_mode, transparent_background, clip_to_elements), True)))

    @constants.maskargs
    def exportToTIFF(self, out_tif, resolution=96, color_mode='24-BIT_TRUE_COLOR', tiff_compression='LZW',
                     jpeg_compression_quality=80, transparent_background=False, embed_color_profile=True, clip_to_elements=False,
                     world_file=False, geoTIFF_tags=False, georef_mapframe=None):
        """Layout.exportToTIFF(out_tif, {resolution}, {color_mode},
           {tiff_compression}, {jpeg_compression_quality},
           {transparent_background}, {embed_color_profile}, {clip_to_elements},
           {world_file}, {geoTIFF_tags}, {georef_mapframe})

           Exports the page layout to the Tagged Image File Format (TIFF).

             out_tif(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             color_mode{String}:
           This value specifies the number of bits used to describe color.

            * 8-BIT_ADAPTIVE_PALETTE:   8-bit adaptive palette

            * 8-BIT_GRAYSCALE:   8-bit grayscale

            * 24-BIT_TRUE_COLOR:   24-bit true color

            * 32-BIT_WITH_ALPHA:   32-bit with alpha

            * 32-BIT_CMYK_TRUE_COLOR:    32-bit true color for CMYK

            * 40-BIT_CMYK_WITH_ALPHA:    40-bit with alpha for CMYK

             tiff_compression{String}:
           This value represents a compression scheme.

            * DEFLATE:   A lossless data compression.

            * JPEG: JPEG compression.

            * LZW:   Lempel-Ziv-Welch, a lossless data compression.

            * NONE:   Compression is not applied.

            * PACK_BITS:   Pack bits compression.

             jpeg_compression_quality{Integer}:
           A number that controls compression quality value when
           image_compression is set to ADAPTIVE or JPEG . The valid range is 1
           to 100.    A jpeg_compression_quality of 100 provides the best-
           quality images but creates large export files.   The recommended
           range is between 70 and 90.

             transparent_background{Boolean}:
           If set to True, the white page background is set to transparent.

             embed_color_profile{Boolean}:
           If set to True, color profile information is embedded in the image's metadata.

             clip_to_elements{Boolean}:
           If set to True, the layout is clipped to the smallest bounding box that includes all layout elements.

             world_file{Boolean}:
           If set to True and a valid georef_mapframe is set, a world file will be generated based on the map frame's 
           coordinate system.

             geoTIFF_tags{Boolean}:
           If set to True and a valid georef_mapframe is set, geoTIFF tags will be embedded in the resulting image and 
           based on the map frame's coordinate system.

             georef_mapframe{Mapframe}:
           The map frame used to define the coordinate system for georeference information."""
        return convertArcObjectToPythonObject(self._arc_object.exportToTIFF(*gp_fixargs((out_tif, resolution, color_mode, tiff_compression,
                                              jpeg_compression_quality, transparent_background, embed_color_profile, clip_to_elements, 
                                              world_file, geoTIFF_tags, georef_mapframe), True)))

    def exportToAIX(self, out_aix, resolution=300, image_quality='BEST', compress_vector_graphics=True, image_compression='ADAPTIVE', jpeg_compression_quality=80, embed_fonts=True, embed_color_profile=True, clip_to_elements=False, keep_layout_background=True):
        """Layout.exportToAIX(out_aix, {resolution}, {image_quality},
           {compress_vector_graphics}, {image_compression},
           {jpeg_compression_quality}, {embed_fonts},
           {embed_color_profile}, {clip_to_elements},
           {keep_layout_background})

           Exports the page layout  to the Adobe Illustrator Format (AIX).

             out_aix(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (DPI).

             image_quality{String}:
           A string that defines output image quality, the draw resolution of
           map layers that draw as rasters.

            * BEST:  An output image quality resample ratio of 1.

            * BETTER:  An output image quality resample ratio of 2.

            * NORMAL:  An output image quality resample ratio of 3.

            * FASTER:  An output image quality resample ratio of 4.

            * FASTEST:  An output image quality resample ratio of 5.

             compress_vector_graphics{Boolean}:
           A Boolean that controls compression of vector and text portions of
           the output file. Image compression is defined separately.

             image_compression{String}:
           A string that defines the compression scheme used to compress image
           or raster data in the output file.

            * ADAPTIVE:   Automatically selects the best compression type for
            each image on the page.   JPEG will be used for large images with
            many unique colors.  DEFLATE will be used for all other images.

            * DEFLATE:   A lossless data compression.

            * JPEG:   A lossy data compression.

            * LZW:   Lempel-Ziv-Welch, a lossless data compression.

            * NONE:   Compression is not applied.

            * RLE:   Run-length encoded compression.

             jpeg_compression_quality{Integer}:
           A number that controls compression quality value when
           image_compression is set to ADAPTIVE or JPEG . The valid range is 1
           to 100.    A jpeg_compression_quality of 100 provides the best-
           quality images but creates large export files.   The recommended
           range is between 70 and 90.

             embed_fonts{Boolean}:
           A Boolean that controls the embedding of fonts in the export file.
           Font embedding allows text and character markers to be displayed
           correctly when the document is viewed on a computer that does not
           have the necessary fonts installed.

             embed_color_profile{Boolean}:
           If set to True, color profile information is embedded in the image's metadata.

            clip_to_elements(Boolean):
           If set to True , the layout is clipped to the smallest bounding box
           that includes all layout elements.

            keep_layout_background(Boolean):
           A boolean that determines if the white background of the layout will be kept."""
        return convertArcObjectToPythonObject(self._arc_object.exportToAIX(*gp_fixargs((out_aix, resolution, image_quality, compress_vector_graphics, image_compression, jpeg_compression_quality, embed_fonts, embed_color_profile, clip_to_elements, keep_layout_background), True)))

    def exportToPAGX(self, out_pagx):
        from os import remove
        from os.path import isfile
        if isfile(out_pagx):
            remove(out_pagx)
        return convertArcObjectToPythonObject(self._arc_object.exportToPAGX(*gp_fixargs((out_pagx,), True)))

    @constants.maskargs
    def listElements(self, element_type=None, wildcard=None):
        """Layout.listElements({element_type}, {wildcard})

           Returns a Python list of page layout elements  that exist on  a
           Layout object.

             element_type{String}:
           A string that represents the element type that will be used to filter
           the returned list of elements.

            * GRAPHIC_ELEMENT:   Filter for GraphicElement objects.

            * LEGEND_ELEMENT:   Filter for LegendElement objects.

            * MAPFRAME_ELEMENT: Filter for MapFrame objects.

            * MAPSURROUND_ELEMENT:   Filter for MapsurroundElement objects.

            * PICTURE_ELEMENT:   Filter for PictureElement objects.

            * TEXT_ELEMENT:   Filter for TextElement objects.

             wildcard{String}:
           A wildcard is based on the element name and is not case sensitive.  A
           combination of asterisks (*) and characters can be used to help limit
           the results."""
        return convertArcObjectToPythonObject(self._arc_object.listElements(*gp_fixargs((element_type, wildcard), True)))

    def __eq__(self, other):
        if type(self)!= type(other):
            return False
        else:
            return convertArcObjectToPythonObject(self._arc_object.isLayoutSame(*gp_fixargs((other,), True)))

    @constants.maskargs
    def getDefinition(self, cim_version):
        """Layout.getDefinition(cim_version)

        Gets a layout's CIM definition.

          cim_version(String):
        A string that represents the major version of the CIM. """
        from .cim.cimloader import GetJSONTypeOBJ
        import json
        return GetJSONTypeOBJ(json.loads(convertArcObjectToPythonObject(self._arc_object.GetCimJSONString(*gp_fixargs((), True)))))

    @constants.maskargs
    def setDefinition(self, definition_object):
        """Layout.setDefinition(definition_object)

        Sets a layout's CIM definition.

          definition_object(Object):
        A modified CIM defintion object originally retrieved using getDefinition. """
        from .cim.cimloader import  CimJsonEncoder
        import json
        json_data = json.dumps(definition_object, cls=CimJsonEncoder)
        return convertArcObjectToPythonObject(self._arc_object.SetCimJSONString(json_data))

class LegendElement(_ObjectWithoutInitCall):
    """The LegendElement object provides access to properties that enable its positioning 
       and resizing on the page layout as well as modifying its title. It also provides 
       access to individual LegendItems."""
    elementHeight = passthrough_attr('elementHeight')
    elementPositionX = passthrough_attr('elementPositionX')
    elementPositionY = passthrough_attr('elementPositionY')
    elementWidth = passthrough_attr('elementWidth')
    locked = passthrough_attr('locked')
    name = passthrough_attr('name')
    mapFrame = passthrough_attr('mapFrame')
    title = passthrough_attr('title')
    type = passthrough_attr('type')
    visible = passthrough_attr('visible')
    elementRotation = passthrough_attr('elementRotation')
    showTitle = passthrough_attr('showTitle')
    syncNewLayer = passthrough_attr('syncNewLayer')
    syncLayerOrder = passthrough_attr('syncLayerOrder')
    syncLayerVisibility = passthrough_attr('syncLayerVisibility')
    syncReferenceScale = passthrough_attr('syncReferenceScale')
    columnCount = passthrough_attr('columnCount')
    fittingStrategy = passthrough_attr('fittingStrategy')
    items = passthrough_attr('items')

    def removeItem(self, remove_item):
        """LegendElement.removeItem(remove_item)

           The removeItem method removes a single legend item from a legend.

             remove_item(LegendItem):
           A reference to a LegendItem object representing the item to be removed."""
        return convertArcObjectToPythonObject(self._arc_object.removeItem(*gp_fixargs((remove_item,), True)))

    def addItem(self, layer, add_position='TOP'):
        """LegendElement.addItem(layer, {add_position})

           The addItem method allows you to add a layer to a legend on a layout.
           The default add_position adds the layer to the top of the list of legend 
           items, therefore appears first. For more precise legend item placement, 
           refer to the moveItem method.

             layer(Layer):
           A reference to a Layer object representing the layer to be added to a legend 
           as a LegendItem. 

             add_position{String}:
           A constant that determines the placement of the added layer within the legend.

            * BOTTOM: Places the layer or layers at the bottom of the TOC layer stack.
 
            * TOP: Places the layer or layers at the top of the TOC layer stack. (DEFAULT)"""
        return convertArcObjectToPythonObject(self._arc_object.addItem(*gp_fixargs((layer, add_position), True)))

    def moveItem(self, reference_item, move_item, move_position='BEFORE'):
        """LegendElement.moveItem(reference_item, move_item, {move_position})

           The moveItem method moves a legend item in a legend. 
           The move_item can be moved either AFTER or BEFORE the reference_item.

             reference_item(LegendItem):
           A LegendItem object representing an existing legend item that determines 
           the relative location where the move_item will be moved.

             move_item(LegendItem):
           A reference to a LegendItem object representing the layer to be moved.

             move_position{String}:
           A constant that determines the placement of the moved layer relative to 
           the reference layer.

            * AFTER: Moves the legend item after or below the reference_item.

            * BEFORE: Moves the legend item before or above the reference_item. (DEFAULT)"""
        return convertArcObjectToPythonObject(self._arc_object.moveItem(*gp_fixargs((reference_item, move_item, move_position), True)))

class LegendItem(_ObjectWithoutInitCall):
    """LegendItem provides access to legend item level information in a LegendElement."""
    arrangement = passthrough_attr('arrangement')
    patchHeight = passthrough_attr('patchHeight')
    patchWidth = passthrough_attr('patchWidth')
    showFeatureCount = passthrough_attr('showFeatureCount')
    showVisibleFeatures = passthrough_attr('showVisibleFeatures')
    visible = passthrough_attr('visible')
    type = passthrough_attr('type')
    name = passthrough_attr('name')
    column = passthrough_attr('column')

class Report(_ObjectWithoutInitCall):
    """The Report object references a report in an ArcGIS Pro
       project ( .aprx ).  It provides access to common properties like dataReference,
       definitionQuery, and the export method."""
    name = passthrough_attr('name')
    referenceDataSource = passthrough_attr('referenceDataSource')
    definitionQuery = passthrough_attr('definitionQuery')
    metadata = passthrough_attr('metadata')

    def setReferenceDataSource(self, data_source):
        """Report.setReferenceDataSource(data_source)

           Change the datasource that the report references.

             data_source(Layer, Table, or String):
           A Layer object, Table object, or the URI to an external datasource that
           is used to populate the report data."""
        return convertArcObjectToPythonObject(self._arc_object.setReferenceDataSource(*gp_fixargs((data_source,), True)))

    def exportToPDF(self, out_pdf, page_range_type='ALL', page_range='', starting_page_number=1, total_page_number=None, resolution=96, image_quality='BEST', compress_vector_graphics=True, image_compression='ADAPTIVE', embed_fonts=True, jpeg_compression_quality=80):
        """Report.exportToPDF(out_pdf, {page_range_type}, {page_range} {starting_page_number},
            {total_page_number}, {resolution}, {image_quality}, {compress_vector_graphics},
            {image_compression}, {embed_fonts}, {jpeg_compression_quality})

           Exports the report to the Portable Document Format (PDF).

             out_pdf(String):
           A string that represents the path and file name for the output export
           file.

             page_range_type{String}:
           A string that defines the type of page range to export.  The default is 'ALL'.

            * ALL:      Export all pages of the report.

            * LAST:     Export only the last page of the report.

            * EVEN:     Export only the even numbered pages of the report.

            * ODD:      Export only the odd numbered pages of the report.

            * RANGE:    Export a range of pages specified using the page_range parameter.

             page_range{String}:
           Specify dash-delimited range and/or a comma-delimited sequence of pages to export.
           Only applies when page_range_type parameter is set to 'RANGE'.  The default is all pages.

             starting_page_number{Integer}:
           The number used for the first page of the report.  All pages will be numbered sequentially starting from the
           starting_page_number.  The default is 1.

             total_page_number{Integer}:
           Hardcode the total number of pages label (e.g. when your report page display "X of Y" pages).
           Useful when you want to combine multiple reports into one.  The default is None, which means it will
           use the counted number of pages.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (DPI).

             image_quality{String}:
           A string that defines output image quality, the draw resolution of
           map layers that draw as rasters.

            * BEST:  An output image quality resample ratio of 1.

            * BETTER:  An output image quality resample ratio of 2.

            * NORMAL:  An output image quality resample ratio of 3.

            * FASTER:  An output image quality resample ratio of 4.

            * FASTEST:  An output image quality resample ratio of 5.

             compress_vector_graphics{Boolean}:
           A Boolean that controls compression of vector and text portions of
           the output file. Image compression is defined separately.

             image_compression{String}:
           A string that defines the compression scheme used to compress image
           or raster data in the output file.

            * ADAPTIVE:   Automatically selects the best compression type for
            each image on the page.   JPEG will be used for large images with
            many unique colors.  DEFLATE will be used for all other images.

            * DEFLATE:   A lossless data compression.

            * JPEG:   A lossy data compression.

            * LZW:   Lempel-Ziv-Welch, a lossless data compression.

            * NONE:   Compression is not applied.

            * RLE:   Run-length encoded compression.

             embed_fonts{Boolean}:
           A Boolean that controls the embedding of fonts in the export file.
           Font embedding allows text and character markers to be displayed
           correctly when the document is viewed on a computer that does not
           have the necessary fonts installed.

             jpeg_compression_quality{Integer}:
           A number that controls compression quality value when
           image_compression is set to ADAPTIVE or JPEG . The valid range is 1
           to 100.    A jpeg_compression_quality of 100 provides the best-
           quality images but creates large export files.   The recommended
           range is between 70 and 90."""

        @constants.maskargs
        def maskArgsWrapper(out_pdf, report_page_range_type, page_range, starting_page_number,
                            total_page_number, resolution, image_quality, compress_vector_graphics,
                            image_compression, embed_fonts, jpeg_compression_quality):
            """Use this method to convert externally exposed page_range_type kwargs to the interal masked arg report_page_range_type"""
            return convertArcObjectToPythonObject(self._arc_object.exportToPDF(*gp_fixargs((out_pdf, report_page_range_type, page_range,
                                                                                            starting_page_number, total_page_number, resolution,
                                                                                            image_quality, compress_vector_graphics, image_compression,
                                                                                            embed_fonts, jpeg_compression_quality), True)))

        try:
            return maskArgsWrapper(out_pdf, page_range_type, page_range,
                                     starting_page_number, total_page_number,
                                     resolution, image_quality, compress_vector_graphics,
                                     image_compression, embed_fonts, jpeg_compression_quality)
        except ValueError as e:
            message = str(e)
            if 'report_page_range_type' in message:
                cleanErr = ValueError(message.replace('report_page_range_type', 'page_range_type'))
                raise cleanErr from cleanErr
            else:
                raise e


class Map(_ObjectWithoutInitCall):
    """The Map is the primary object for referencing and managing layers and
       tables within an ArcGIS Pro project."""
    defaultCamera = passthrough_attr('defaultCamera')
    defaultView = passthrough_attr('defaultView', True)
    mapType = passthrough_attr('mapType')
    name = passthrough_attr('name')
    referenceScale = passthrough_attr('referenceScale')
    mapUnits = passthrough_attr('mapUnits')
    metadata = passthrough_attr('metadata')
    spatialReference = passthrough_attr('spatialReference')
    URI = passthrough_attr('URI')

    @constants.maskargs
    def addLayer(self, add_layer_or_layerfile, add_position='AUTO_ARRANGE'):
        """Map.addLayer(add_layer_or_layerfile, {add_position})

           Provides the ability to add a Layer or LayerFile to a map within a
           project ( .aprx ) using basic placement options.

             add_layer_or_layerfile(Layer):
           A reference to a Layer or LayerFile object representing the layer or
           layers  to be added.

             add_position{String}:
           A constant that determines the placement of the added layer or layers
           in a map.

            * AUTO_ARRANGE: Automatically places the layer or layers based on
            its layer weight rules and geometry.

            * BOTTOM: Places the layer or layers at the bottom of the TOC layer
            stack.

            * TOP: Places the layer or layers at the top of the TOC layer stack."""
        return convertArcObjectToPythonObject(self._arc_object.addLayer(*gp_fixargs((add_layer_or_layerfile, add_position), True)))

    @constants.maskargs
    def addLayerToGroup(self, target_group_layer, add_layer_or_layerfile, add_position='AUTO_ARRANGE'):
        """Map.addLayerToGroup(target_group_layer, add_layer_or_layerfile,
           {add_position})

           Provides the ability to add a Layer or the contents of a LayerFile to
           an existing group layer in a map within a project ( .aprx ) using
           basic placement options.

             target_group_layer(Layer):
           A reference to an existing group Layer object.

             add_layer_or_layerfile(Layer):
           A reference to a Layer or LayerFile object representing the layer or
           layers  to be added.

             add_position{String}:
           A constant that determines the placement of the added layer or layers
           in the target_group_layer .

            * AUTO_ARRANGE: Automatically places the layer based on its layer
            weight rules and geometry.

            * BOTTOM: Places the layer at the bottom of the TOC layer stack.

            * TOP: Places the layer at the top of the TOC layer stack."""
        return convertArcObjectToPythonObject(self._arc_object.addLayerToGroup(*gp_fixargs((target_group_layer, add_layer_or_layerfile, add_position), True)))

    def addTable(self, add_table):
        """Map.addTable(add_table)

           Provides the ability to add a Table to a map within a project ( .aprx
           ).

             add_table(Table):
           A reference to a Table object representing the table  to be added."""
        return convertArcObjectToPythonObject(self._arc_object.addTable(*gp_fixargs((add_table,), True)))

    def clearSelection(self):
        """Map.clearSelection()

           Clears the selection for all layers and tables in a map."""
        return convertArcObjectToPythonObject(self._arc_object.clearSelection(*gp_fixargs((), True)))

    @constants.maskargs
    def insertLayer(self, reference_layer, insert_layer_or_layerfile, insert_position='BEFORE'):
        """Map.insertLayer(reference_layer, insert_layer_or_layerfile,
           {insert_position})

           Provides the ability to add a Layer or LayerFile to a map within a
           project ( .aprx ) by specifying  a specific location.

             reference_layer(Layer):
           A Layer object representing an existing layer that determines the
           location where the new layer will be inserted.

             insert_layer_or_layerfile(Layer):
           A reference to a Layer or LayerFile object representing the layer or
           layers  to be added.

             insert_position{String}:
           A constant that determines the placement of the added layer or layers
           relative to the reference_layer .

            * AFTER: Inserts the new layer after or below the reference layer.

            * BEFORE: Inserts the new layer before or above the reference layer."""
        return convertArcObjectToPythonObject(self._arc_object.insertLayer(*gp_fixargs((reference_layer, insert_layer_or_layerfile, insert_position), True)))

    def listBookmarks(self, wildcard=None):
        """Map.listBookmarks({wildcard})

           Returns a Python list of bookmark objects in a Map .

             wildcard{String}:
           A wildcard is based on the bookmark name and is not case sensitive. A
           combination of asterisks (*) and characters can be used to help
           limit the resulting list."""
        return convertArcObjectToPythonObject(self._arc_object.listBookmarks(*gp_fixargs((wildcard,), True)))

    def listBrokenDataSources(self):
        """Map.listBrokenDataSources()

           Returns a Python list of Layer or Table objects that have broken
           connections to their original source data within a map."""
        return convertArcObjectToPythonObject(self._arc_object.listBrokenDataSources(*gp_fixargs((), True)))

    def listLayers(self, wildcard=None):
        """Map.listLayers({wildcard})

           Returns a Python list of Layer objects that exist within a map.

             wildcard{String}:
           A wildcard is based on the layer name and is not case sensitive. A
           combination of asterisks (*) and characters can be used to help
           limit the resulting list."""
        return convertArcObjectToPythonObject(self._arc_object.listLayers(*gp_fixargs((wildcard,), True)))

    def listTables(self, wildcard=None):
        """Map.listTables({wildcard})

           Returns a Python list of Table objects that exist within a map.

             wildcard{String}:
           A wildcard is based on the layer name and is not case sensitive.  A
           combination of asterisks (*) and characters can be used to help limit
           the resulting list."""
        return convertArcObjectToPythonObject(self._arc_object.listTables(*gp_fixargs((wildcard,), True)))

    def addBasemap(self, basemap_name):
        """Map.addBasemap({basemap_name})

           Add a basemap to the map.

             basemap_name{String}:
           The string representation of the basemap to be added."""
        return convertArcObjectToPythonObject(self._arc_object.addBasemap(*gp_fixargs((basemap_name,), True)))

    def addDataFromPath(self, data_path):
        """Map.addDataFromPath(data_path)

           Provides the ability to add data from a path to a map within a project ( .aprx
           ).

             data_path(URL):
           A reference to a string object representing the path of the layer to be added."""
        return convertArcObjectToPythonObject(self._arc_object.addDataFromPath(*gp_fixargs((data_path,), True)))

    @constants.maskargs
    def moveLayer(self, reference_layer, move_layer, insert_position='BEFORE'):
        """Map.moveLayer(reference_layer, move_layer, {insert_position})

           Provides the ability to move a layer or group layer in a map to  a
           specific location in the layer stack.

             reference_layer(Layer):
           A Layer object representing an existing layer that determines the
           location where the new layer will be moved.

             move_layer(Layer):
           A reference to a Layer object representing the layer to be moved.

             insert_position{String}:
           A constant that determines the placement of the moved layer relative
           to the reference layer.

            * AFTER: Moves the  layer after or below the reference layer.

            * BEFORE: Moves the layer before or above the reference layer."""
        return convertArcObjectToPythonObject(self._arc_object.moveLayer(*gp_fixargs((reference_layer, move_layer, insert_position), True)))

    def removeLayer(self, remove_layer):
        """Map.removeLayer(remove_layer)

           Provides the ability to remove a layer from a map in a project.

             remove_layer(Layer):
           A reference to a Layer object representing the layer to be removed."""
        return convertArcObjectToPythonObject(self._arc_object.removeLayer(*gp_fixargs((remove_layer,), True)))

    def removeTable(self, remove_table):
        """Map.removeTable(remove_table)

           Provides the ability to remove a table from a map in a project.

             remove_table(Table):
           A reference to a Table object representing the layer to be removed."""
        return convertArcObjectToPythonObject(self._arc_object.removeTable(*gp_fixargs((remove_table,), True)))

    def updateConnectionProperties(self, current_connection_info, new_connection_info, auto_update_joins_and_relates=True, validate=True, ignore_case=False):
        """Map.updateConnectionProperties(current_connection_info,
           new_connection_info, {auto_update_joins_and_relates}, {validate}, {ignore_case})

           Replaces connection properties using a dictionary or a path to a
           workspace.

             current_connection_info(String):
           A string that represents the workspace path or a Python dictionary
           that contains connection properties to the source you want to update.

             new_connection_info(String):
           A string that represents the workspace path or a Python dictionary
           that contains connection properties with the new source information.

             auto_update_joins_and_relates{Boolean}:
           If  set to True , the updateConnectionProperties method will also
           update the connections for associated joins or relates.

             validate{Boolean}:
           If  set to True , the connection properties will only be updated if
           the new_connection_info value is a valid connection.  If it is not
           valid, the connection will not be replaced.   If set to False , the
           method will set all connections to match the new_connection_info ,
           regardless of a valid match.  In this case, if a match does not
           exist, then the data sources would be broken.

             ignore_case{Boolean}:
           If set to True, UpdateConnectionProperties will ignore the case of
           current_connection_info. The default value is False, where
           UpdateConnectionProperties will honor the case of current_connection_info.
           The ignore_case parameter doesn't apply to the new_connection_info parameter."""
        return convertArcObjectToPythonObject(self._arc_object.updateConnectionProperties(*gp_fixargs((current_connection_info, new_connection_info, auto_update_joins_and_relates, validate, ignore_case), True)))

    def getWebLayerSharingDraft(self, server_type, service_type, service_name, layers_and_tables=None):
        """Map.getWebLayerSharingDraft(server_type, service_type, service_name, {layers_and_tables})

           Returns a SharingDraft object.
        """
        validation_map = {
            "FEDERATED_SERVER": ["MAP_IMAGE"],
            "MY_HOSTED_SERVICES": ["TILE", "FEATURE"],
            "HOSTING_SERVER": ["TILE", "FEATURE"],
            }
        if service_type in validation_map[server_type]:
          if service_type == "TILE":
            from arcpy.sharing import TileSharingDraft
            tileSharingObject = TileSharingDraft()
            tileSharingObject.server_type = server_type
            tileSharingObject.service_type = service_type
            convertArcObjectToPythonObject(self._arc_object.getWebLayerSharingDraft(tileSharingObject, *gp_fixargs((server_type, service_type, service_name, layers_and_tables), True)))
            return tileSharingObject
          if service_type == "FEATURE":
            from arcpy.sharing import FeatureSharingDraft
            featureSharingObject = FeatureSharingDraft()
            featureSharingObject.serverType = server_type
            featureSharingObject.serviceType = service_type
            convertArcObjectToPythonObject(self._arc_object.getWebLayerSharingDraft(featureSharingObject, *gp_fixargs((server_type, service_type, service_name, layers_and_tables), True)))
            return featureSharingObject
          if service_type == "MAP_IMAGE":
            from arcpy.sharing import MapImageSharingDraft
            mapImageObject = MapImageSharingDraft()
            mapImageObject.serverType = server_type
            mapImageObject.serviceType = service_type
            convertArcObjectToPythonObject(self._arc_object.getWebLayerSharingDraft(mapImageObject, *gp_fixargs(( server_type, service_type, service_name, layers_and_tables), True, pass_arc_object=True)))
            return mapImageObject
        raise ValueError("Incompatible server_type: {} and service_type: {}".format(server_type, service_type))

    def __eq__(self, other):
        if type(self)!= type(other):
            return False
        else:
            return convertArcObjectToPythonObject(self._arc_object.isMapSame(*gp_fixargs((other,), True)))

    @constants.maskargs
    def getDefinition(self, cim_version):
        """Map.getDefinition(cim_version)

        Gets a map's CIM definition.

          cim_version(String):
        A string that represents the major version of the CIM. """
        from .cim.cimloader import GetJSONTypeOBJ
        import json
        return GetJSONTypeOBJ(json.loads(convertArcObjectToPythonObject(self._arc_object.GetCimJSONString(*gp_fixargs((), True)))))

    @constants.maskargs
    def setDefinition(self, definition_object):
        """Map.setDefinition(definition_object)

        Sets a map's CIM definition.

          definition_object(Object):
        A modified CIM defintion object originally retrieved using getDefinition. """
        from .cim.cimloader import  CimJsonEncoder
        import json
        json_data = json.dumps(definition_object, cls=CimJsonEncoder)
        return convertArcObjectToPythonObject(self._arc_object.SetCimJSONString(json_data))

    def exportToMAPX(self, out_mapx):
        return convertArcObjectToPythonObject(self._arc_object.exportToMAPX(*gp_fixargs((out_mapx,), True)))

class MapFrame(_ObjectWithoutInitCall):
    """The MapFrame object is a page layout element that is used to display the
       contents of a map on a layout.      It also provides access to page size
       and positioning, basic navigation methods,  and export options."""
    camera = passthrough_attr('camera')
    elementHeight = passthrough_attr('elementHeight')
    elementPositionX = passthrough_attr('elementPositionX')
    elementPositionY = passthrough_attr('elementPositionY')
    elementRotation = passthrough_attr('elementRotation')
    elementWidth = passthrough_attr('elementWidth')
    locked = passthrough_attr('locked')
    map = passthrough_attr('map')
    name = passthrough_attr('name')
    type = passthrough_attr('type')
    visible = passthrough_attr('visible')
    time = passthrough_attr('time')
    def getLayerExtent(self, layer, selection_only=True, symbolized_extent=True):
        """MapFrame.getLayerExtent(layer, {selection_only}, {symbolized_extent})

           Returns a layer's extent for all features or only the selected
           features in a layer.

             layer(Layer):
           A reference to a Layer object.

             selection_only{Boolean}:
           If True , it returns the extent for selected features; if False , it
           returns the extent for all features.

             symbolized_extent{Boolean}:
           A value of True will return the layer's symbolized extent; otherwise,
           it will return the geometric extent.  The symbolized extent takes
           into account the area the symbology covers so that it does not get
           cut off by the data frame's boundary."""
        return convertArcObjectToPythonObject(self._arc_object.getLayerExtent(*gp_fixargs((layer, selection_only, symbolized_extent), True)))

    def panToExtent(self, extent):
        """MapFrame.panToExtent(extent)

           Pans and centers the MapFrame using a new Extent object without
           changing the map frame's scale.

             extent(Extent):
           A geoprocessing Extent object."""
        return convertArcObjectToPythonObject(self._arc_object.panToExtent(*gp_fixargs((extent,), True)))

    def zoomToAllLayers(self, selection_only=True, symbolized_extent=True):
        """MapFrame.zoomToAllLayers({selection_only}, {symbolized_extent})

           Modifies the MapFrame view to match the extent of all layers or
           selected layers in a map.

             selection_only{Boolean}:
           If True , it sets the extent based on the selected  features; if
           False , it sets the extent for all  features in a map.

             symbolized_extent{Boolean}:
           A value of True will return the layer's symbolized extent; otherwise,
           it will return the geometric extent.  The symbolized extent takes
           into account the area the symbology covers so that it does not get
           cut off by the map frame's boundary."""
        return convertArcObjectToPythonObject(self._arc_object.zoomToAllLayers(*gp_fixargs((selection_only, symbolized_extent), True)))

    def zoomToBookmark(self, bookmark):
        """MapFrame.zoomToBookmark(bookmark)

           Modifies the MapFrame view to match the view information stored with
           a spatial bookmark.

             bookmark(Bookmark):
           A reference to a Bookmark object."""
        return convertArcObjectToPythonObject(self._arc_object.zoomToBookmark(*gp_fixargs((bookmark,), True)))

    @constants.maskargs
    def exportToJPEG(self, out_jpg, resolution=96, world_file=False, jpeg_color_mode='24-BIT_TRUE_COLOR', jpeg_quality=80, embed_color_profile=True):
        """MapFrame.exportToJPEG(out_jpg, {resolution}, {world_file},
           {jpeg_color_mode}, {jpeg_quality}, {embed_color_profile})

           Exports the contents of a MapFrame to the Joint Photographic Experts
           Group format (JPEG).

             out_jpg(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             world_file{Boolean}:
           If set to True , a georeferenced world file is created. The file
           contains pixel scale information and real-world coordinate
           information.  If you export a 3D map frame, this parameter will be
           ignored regardless of the setting because world files are not
           applicable to 3D views.

             jpeg_color_mode{String}:
           This value specifies the number of bits used to describe color.

            * 8-BIT_GRAYSCALE:   8-bit grayscale

            * 24-BIT_TRUE_COLOR:   24-bit true color

             jpeg_quality{Integer}:
           This value (0–100) controls the amount of compression applied to the
           output image. For JPEG, image quality is adversely affected the more
           compression is applied. A higher quality (highest = 100) setting will
           produce sharper images and larger file sizes. A lower quality setting
           will produce more image artifacts and smaller files.

             embed_color_profile{Boolean}:
           If set to True, color profile information is embedded in the image's metadata."""
        return convertArcObjectToPythonObject(self._arc_object.exportToJPEG(*gp_fixargs((out_jpg, resolution, world_file, jpeg_color_mode, jpeg_quality, embed_color_profile), True)))

    @constants.maskargs
    def exportToPNG(self, out_png, resolution=96, world_file=False, color_mode='32-BIT_WITH_ALPHA', embed_color_profile=True):
        """MapFrame.exportToPNG(out_png, {resolution}, {world_file},
           {color_mode}, {embed_color_profile})

           Exports the contents of a MapFrame to Portable Network Graphics
           format (PNG).

             out_png(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             world_file{Boolean}:
           If set to True , a georeferenced world file is created. The file
           contains pixel scale information and real-world coordinate
           information.  If you export a 3D map frame, this parameter will be
           ignored regardless of the setting because world files are not
           applicable to 3D views.

             color_mode{String}:
           This value specifies the number of bits used to describe color.

            * 8-BIT_ADAPTIVE_PALETTE:   8-bit adaptive palette

            * 8-BIT_GRAYSCALE:   8-bit grayscale

            * 24-BIT_TRUE_COLOR:   24-bit true color

            * 32-BIT_WITH_ALPHA:   32-bit with alpha

              embed_color_profile{Boolean}:
            If set to True, color profile information is embedded in the image's metadata."""
        return convertArcObjectToPythonObject(self._arc_object.exportToPNG(*gp_fixargs((out_png, resolution, world_file, color_mode, embed_color_profile), True)))

    @constants.maskargs
    def exportToTIFF(self, out_tif, resolution=96, world_file=False, color_mode='24-BIT_TRUE_COLOR', tiff_compression='LZW', geoTIFF_tags=False,
                    jpeg_compression_quality=80, embed_color_profile=True):
        """MapFrame.exportToTIFF(out_tif, {resolution}, {world_file},
           {color_mode}, {tiff_compression}, {geoTIFF_tags}, {jpeg_compression_quality}, {embed_color_profile})

           Exports the page layout to the Tagged Image File Format (TIFF).

             out_tif(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             world_file{Boolean}:
           If set to True , a georeferenced world file is created. The file
           contains pixel scale information and real-world coordinate
           information.  If you export a 3D map frame, this parameter will be
           ignored regardless of the setting because world files are not
           applicable to 3D views.

             color_mode{String}:
           This value specifies the number of bits used to describe color.

            * 8-BIT_ADAPTIVE_PALETTE:   8-bit adaptive palette

            * 8-BIT_GRAYSCALE:   8-bit grayscale

            * 24-BIT_TRUE_COLOR:   24-bit true color

            * 32-BIT_WITH_ALPHA:   32-bit with alpha
            
            * 32-BIT_CMYK_TRUE_COLOR:    32-bit true color for CMYK

            * 40-BIT_CMYK_WITH_ALPHA:    40-bit with alpha for CMYK

             tiff_compression{String}:
           This value represents a compression scheme.

            * DEFLATE:   A lossless data compression.

            * JPEG: JPEG compression.

            * LZW:   Lempel-Ziv-Welch, a lossless data compression.

            * NONE:   Compression is not applied.

            * PACK_BITS:   Pack bits compression.

             geoTIFF_tags{Boolean}:
           If set to True , georeferencing tags are included in the structure of
           the TIFF export file. The tags contain pixel scale information and
           real-world coordinate information. These tags can be read by
           applications that support GeoTIFF format.

            jpeg_compression_quality{Integer}:
           A number that controls compression quality value when
           image_compression is set to ADAPTIVE or JPEG . The valid range is 1
           to 100.    A jpeg_compression_quality of 100 provides the best-
           quality images but creates large export files.   The recommended
           range is between 70 and 90.

             embed_color_profile{Boolean}:
           If set to True, color profile information is embedded in the image's metadata."""
        return convertArcObjectToPythonObject(self._arc_object.exportToTIFF(*gp_fixargs((out_tif, resolution, world_file, color_mode, tiff_compression, geoTIFF_tags,
                                              jpeg_compression_quality, embed_color_profile), True)))

    @constants.maskargs
    def exportToBMP(self, out_bmp, resolution=96, world_file=False, bmp_color_mode='24-BIT_TRUE_COLOR', bmp_image_compression='NONE', embed_color_profile=True):
        """MapFrame.exportToBMP(out_bmp, {resolution}, {world_file}, {bmp_color_mode}, {bmp_image_compression}, {embed_color_profile})

           Exports the MapFrame to the Microsoft Windows Bitmap format (BMP).

             out_bmp(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

            world_file{Boolean}:
          If set to True, a georeferenced world file is created. The file contains
          pixel scale information and real-world coordinate information. If you export
          a 3D map frame, this parameter will be ignored regardless of the setting because
          world files are not applicable to 3D views.

            bmp_color_mode{String}:
          This value specifies the number of bits used to describe color.

            * 8-BIT_ADAPTIVE_PALETTE:   8-bit adaptive palette

            * 8-BIT_GRAYSCALE:   8-bit grayscale

            * 24-BIT_TRUE_COLOR:    24-bit true color.

            bmp_image_compression{String}:
          A string that specifies the compression scheme used to compress image or raster
          data in the output file. This option only applies to 8-bit bmp_color_mode options.

            * NONE:   Compression is not applied.

            * RLE:   Run-length encoded compression.

            embed_color_profile{Boolean}:
          If set to True, color profile information is embedded in the image's metadata."""
        return convertArcObjectToPythonObject(self._arc_object.exportToBMP(*gp_fixargs((out_bmp, resolution, world_file, bmp_color_mode, bmp_image_compression, embed_color_profile), True)))

    @constants.maskargs
    def exportToEMF(self, out_emf, resolution=96, image_quality='BEST', output_as_image=False):
        """MapFrame.exportToEMF(out_emf, {resolution}, {image_quality}, {output_as_image})

           Exports the map frame to the Enhanced Metafile (EMF) format.

             out_emf(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             image_quality{String}:
           A string that specifies output image quality, the draw resolution of
           map layers that draw as rasters.

             *  BEST —An output image quality resample ratio of 1

             *  BETTER —An output image quality resample ratio of 2

             *  NORMAL —An output image quality resample ratio of 3

             *  FASTER —An output image quality resample ratio of 4

             *  FASTEST —An output image quality resample ratio of 5

             output_as_image{Boolean}:
           If set to True, vector content can be saved as an image. Selecting this option
          for maps or layouts that contain vector layers with a high density of vertices
          can reduce the output file size. When exporting to PDF and this option is set to
          True, you cannot view PDF layers in the output."""
        return convertArcObjectToPythonObject(self._arc_object.exportToEMF(*gp_fixargs((out_emf, resolution, image_quality, output_as_image), True)))

    @constants.maskargs
    def exportToEPS(self, out_eps, resolution=96, image_compression='DEFLATE', image_quality='BEST',
                   embed_fonts=True, output_as_image=False):
        """MapFrame.exportToEPS(out_eps, {resolution}, {image_compression}, {image_quality}, {embed_fonts}, {output_as_image})

           Exports the map frame to an Encapsulated PostScript (EPS) format.

             out_eps(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             image_compression{String}:
           A string that specifies the compression scheme used to compress image
           or raster data in the output file.

             image_quality{String}:
           A string that specifies output image quality, the draw resolution of
           map layers that draw as rasters.

             embed_fonts{Boolean}:
           A Boolean that controls the embedding of fonts in the export file.
           Font embedding allows text and character markers to be displayed correctly
           when the document is viewed on a computer that does not have the necessary
           fonts installed.

             output_as_image{Boolean}:
           If set to True, vector content can be saved as an image. Selecting this option
          for maps or layouts that contain vector layers with a high density of vertices
          can reduce the output file size. When exporting to PDF and this option is set to
          True, you cannot view PDF layers in the output."""
        return convertArcObjectToPythonObject(self._arc_object.exportToEPS(*gp_fixargs((out_eps, resolution, image_compression, image_quality, embed_fonts, output_as_image), True)))

    @constants.maskargs
    def exportToGIF(self, out_gif, resolution=96, world_file=False, gif_color_mode='8-BIT_ADAPTIVE_PALETTE'):
        """MapFrame.exportToGIF(out_gif, {resolution}, {world_file}, {gif_color_mode})

           Exports the map frame to the Graphic Interchange format (GIF).

             out_gif(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

            world_file{Boolean}:
          If set to True, a georeferenced world file is created. The file contains
          pixel scale information and real-world coordinate information. If you export
          a 3D map frame, this parameter will be ignored regardless of the setting because
          world files are not applicable to 3D views.

             gif_color_mode{String}:
          This value specifies the number of bits used to describe color.

            * 8-BIT_ADAPTIVE_PALETTE:   8-bit adaptive palette

            * 8-BIT_GRAYSCALE:   8-bit grayscale."""
        return convertArcObjectToPythonObject(self._arc_object.exportToGIF(*gp_fixargs((out_gif, resolution, world_file, gif_color_mode), True)))

    @constants.maskargs
    def exportToTGA(self, out_tga, resolution=96, world_file=False, color_mode='24-BIT_TRUE_COLOR'):
        """MapFrame.exportToTGA(out_tga, {resolution}, {world_file}, {color_mode})

           Exports the page layout to the Truevision Graphics Adapter format (TGA).

             out_tga(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             world_file{Boolean}:
          If set to True, a georeferenced world file is created. The file contains
          pixel scale information and real-world coordinate information. If you export
          a 3D map frame, this parameter will be ignored regardless of the setting because
          world files are not applicable to 3D views.

            color_mode{String}:
           This value specifies the number of bits used to describe color.

            * 8-BIT_ADAPTIVE_PALETTE:   8-bit adaptive palette

            * 8-BIT_GRAYSCALE:   8-bit grayscale

            * 24-BIT_TRUE_COLOR:   24-bit true color

            * 32-BIT_WITH_ALPHA:   32-bit with alpha."""
        return convertArcObjectToPythonObject(self._arc_object.exportToTGA(*gp_fixargs((out_tga, resolution, world_file, color_mode), True)))

    @constants.maskargs
    def exportToSVG(self, out_svg, resolution=96, compress_to_svgz=False, image_quality='BEST', embed_fonts=True, output_as_image=False):
        """MapFrame.exportToSVG(out_svg, {resolution}, {compress_to_svgz}, {image_quality}, {embed_fonts},
           {output_as_image})

           Exports the map frame to the Scalable Vector Graphics format (SVG).

             out_svg(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             compress_to_svgz{Boolean}:
           If set to True , the output is compressed.

             image_quality{String}:
           A string that specifies output image quality, the draw resolution of map layers that draw as rasters.

             embed_fonts{Boolean}:
           A Boolean that controls the embedding of fonts in the export file. Font embedding allows text
           and character markers to be displayed correctly when the document is viewed on a computer that
           does not have the necessary fonts installed.

            output_as_image{Boolean}:
          If set to True, vector content can be saved as an image. Selecting this option for maps or
         layouts that contain vector layers with a high density of vertices can reduce the output file
         size. When exporting to PDF and this option is set to True, you cannot view PDF layers in the output."""
        return convertArcObjectToPythonObject(self._arc_object.exportToSVG(*gp_fixargs((out_svg, resolution, compress_to_svgz,
            image_quality, embed_fonts, output_as_image), True)))

    @constants.maskargs
    def exportToPDF(self, out_pdf, resolution=96, image_quality='BEST', compress_vector_graphics=True, image_compression='ADAPTIVE', embed_fonts=True, layers_attributes='LAYERS_ONLY', georef_info=True, jpeg_compression_quality=80, output_as_image=False, embed_color_profile=True):
        """MapFrame.exportToPDF(out_pdf, {resolution}, {image_quality},
           {compress_vector_graphics}, {image_compression}, {embed_fonts},
           {layers_attributes}, {georef_info}, {jpeg_compression_quality}, {output_as_image},
           {embed_color_profile})

           Exports the MapFrame to the Portable Document Format (PDF).

             out_pdf(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (DPI).

             image_quality{String}:
           A string that defines output image quality, the draw resolution of
           map layers that draw as rasters.

            * BEST:  An output image quality resample ratio of 1.

            * BETTER:  An output image quality resample ratio of 2.

            * NORMAL:  An output image quality resample ratio of 3.

            * FASTER:  An output image quality resample ratio of 4.

            * FASTEST:  An output image quality resample ratio of 5.

             compress_vector_graphics{Boolean}:
           A Boolean that controls compression of vector and text portions of
           the output file. Image compression is defined separately.

             image_compression{String}:
           A string that defines the compression scheme used to compress image
           or raster data in the output file.

            * ADAPTIVE:   Automatically selects the best compression type for
            each image on the page.   JPEG will be used for large images with
            many unique colors.  DEFLATE will be used for all other images.

            * DEFLATE:   A lossless data compression.

            * JPEG:   A lossy data compression.

            * LZW:   Lempel-Ziv-Welch, a lossless data compression.

            * NONE:   Compression is not applied.

            * RLE:   Run-length encoded compression.

             embed_fonts{Boolean}:
           A Boolean that controls the embedding of fonts in the export file.
           Font embedding allows text and character markers to be displayed
           correctly when the document is viewed on a computer that does not
           have the necessary fonts installed.

             layers_attributes{String}:
           A string that controls inclusion of PDF layer and PDF object data
           (attributes) in the export file.

            * LAYERS_ONLY:  Export PDF layers only

            * LAYERS_AND_ATTRIBUTES:  Export PDF layers and feature attributes

            * NONE:  None

             georef_info{Boolean}:
           A Boolean that enables the export of coordinate system information
           for each data frame into the output PDF file.

             jpeg_compression_quality{Integer}:
           A number that controls compression quality value when
           image_compression is set to ADAPTIVE or JPEG . The valid range is 1
           to 100.    A jpeg_compression_quality of 100 provides the best-
           quality images but creates large export files.   The recommended
           range is between 70 and 90.

             output_as_image{Boolean}:
           If set to True to vector content will be saved as an image.
           Selecting this option for maps or layouts that contain vector layers
           with a high density of vertices can drastically reduce the output file
           size. If exporting to PDF and this option set to True, you will not be
           able to view PDF layers in the output.

             embed_color_profile{Boolean}:
           If set to True, color profile information is embedded in the image's metadata."""
        return convertArcObjectToPythonObject(self._arc_object.exportToPDF(*gp_fixargs((out_pdf, resolution, image_quality, compress_vector_graphics, image_compression, embed_fonts, layers_attributes, georef_info, jpeg_compression_quality, False, output_as_image, embed_color_profile), True)))

    def exportToAIX(self, out_aix, resolution=300, image_quality='BEST', compress_vector_graphics=True, image_compression='ADAPTIVE', jpeg_compression_quality=80, embed_fonts=True, embed_color_profile=True):
        """MapFrame.exportToAIX(out_pdf, {resolution}, {image_quality},
           {compress_vector_graphics}, {image_compression},
           {jpeg_compression_quality}, {embed_fonts},
           {embed_color_profile})

           Exports the map frame  to the Adobe Illustrator Format (AIX).

             out_aix(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (DPI).

             image_quality{String}:
           A string that defines output image quality, the draw resolution of
           map layers that draw as rasters.

            * BEST:  An output image quality resample ratio of 1.

            * BETTER:  An output image quality resample ratio of 2.

            * NORMAL:  An output image quality resample ratio of 3.

            * FASTER:  An output image quality resample ratio of 4.

            * FASTEST:  An output image quality resample ratio of 5.

             compress_vector_graphics{Boolean}:
           A Boolean that controls compression of vector and text portions of
           the output file. Image compression is defined separately.

             image_compression{String}:
           A string that defines the compression scheme used to compress image
           or raster data in the output file.

            * ADAPTIVE:   Automatically selects the best compression type for
            each image on the page.   JPEG will be used for large images with
            many unique colors.  DEFLATE will be used for all other images.

            * DEFLATE:   A lossless data compression.

            * JPEG:   A lossy data compression.

            * LZW:   Lempel-Ziv-Welch, a lossless data compression.

            * NONE:   Compression is not applied.

            * RLE:   Run-length encoded compression.

             jpeg_compression_quality{Integer}:
           A number that controls compression quality value when
           image_compression is set to ADAPTIVE or JPEG . The valid range is 1
           to 100.    A jpeg_compression_quality of 100 provides the best-
           quality images but creates large export files.   The recommended
           range is between 70 and 90.

             embed_fonts{Boolean}:
           A Boolean that controls the embedding of fonts in the export file.
           Font embedding allows text and character markers to be displayed
           correctly when the document is viewed on a computer that does not
           have the necessary fonts installed.

             embed_color_profile{Boolean}:
           If set to True, color profile information is embedded in the image's metadata."""
        return convertArcObjectToPythonObject(self._arc_object.exportToAIX(*gp_fixargs((out_aix, resolution, image_quality, compress_vector_graphics, image_compression, jpeg_compression_quality, embed_fonts, embed_color_profile), True)))

    def __eq__(self, other):
        if type(self)!= type(other):
            return False
        else:
            return convertArcObjectToPythonObject(self._arc_object.isMapFrameSame(*gp_fixargs((other,), True)))

class MapSurroundElement(_ObjectWithoutInitCall):
    elementPositionX = passthrough_attr('elementPositionX')
    elementPositionY = passthrough_attr('elementPositionY')
    elementHeight = passthrough_attr('elementHeight')
    elementWidth = passthrough_attr('elementWidth')
    locked = passthrough_attr('locked')
    name = passthrough_attr('name')
    mapFrame = passthrough_attr('mapFrame')
    type = passthrough_attr('type')
    visible = passthrough_attr('visible')

class MapTime(_ObjectWithoutInitCall):
    """The MapTime object is a Map object with time settings."""
    currentTimeStart = passthrough_attr('currentTimeStart')
    currentTimeEnd = passthrough_attr('currentTimeEnd')
    currentTimeSpan = passthrough_attr('currentTimeSpan')
    currentTimeSpanUnits = passthrough_attr('currentTimeSpanUnits')
    timeStepInterval = passthrough_attr('timeStepInterval')
    timeStepIntervalUnits = passthrough_attr('timeStepIntervalUnits')
    isTimeEnabled = passthrough_attr('isTimeEnabled')
    timeInclusion = passthrough_attr('timeInclusion')
 
    def timeStep(self, reference_time, interval, interval_units):
        """MapTime.timeStep(reference_time, interval, interval_units)

           Uses interval and interval_units to step forward or back from reference_time and returns the new datetime."""
        return convertArcObjectToPythonObject(self._arc_object.timeStep(*gp_fixargs((reference_time, interval, interval_units), True)))

    @constants.maskargs
    def setTimeInclusion(self, time_inclusion):
        """MapTime.setTimeInclusion(time_inclusion)

           Sets the timeInclusion property to the timeInclusion argument.
           
             timeInclusion{String}:
           A string that defines timeInclusion property for time filtering.

            * INCLUDE_START_AND_END:  Include start and end time.

            * INCLUDE_ONLY_START:  Include only start time.

            * INCLUDE_ONLY_END:  Include only end time.

            * EXCLUDE_START_AND_END:  Exclude start and end time."""
        return convertArcObjectToPythonObject(self._arc_object.setTimeInclusion(*gp_fixargs((time_inclusion,), True)))

class PictureElement(_ObjectWithoutInitCall):
    """Provides access to picture properties that enable the repositioning of a
       picture on the page layout as well as getting and setting its data
       source."""
    elementHeight = passthrough_attr('elementHeight')
    elementPositionX = passthrough_attr('elementPositionX')
    elementPositionY = passthrough_attr('elementPositionY')
    elementRotation = passthrough_attr('elementRotation')
    elementWidth = passthrough_attr('elementWidth')
    locked = passthrough_attr('locked')
    name = passthrough_attr('name')
    sourceImage = passthrough_attr('sourceImage')
    type = passthrough_attr('type')
    visible = passthrough_attr('visible')
class Table(_ObjectWithoutInitCall):
    """Table(table_data_source)

       Enables you to reference a table in a workspace so that it can be added
       to a Map .

         table_data_source(String):
       A string that includes the full workspace path, including the name of the
       table.  For SDE tables, the workspace path is the path to an SDE
       connection file."""
    connectionProperties = passthrough_attr('connectionProperties', True)
    dataSource = passthrough_attr('dataSource', True)
    definitionQuery = passthrough_attr('definitionQuery')
    isBroken = passthrough_attr('isBroken')
    name = passthrough_attr('name')
    metadata = passthrough_attr('metadata')
    URI = passthrough_attr('URI')

    def getSelectionSet(self):
        """Table.getSelectionSet()

           Returns a table's selection as a Python set of Object IDs."""
        return convertArcObjectToPythonObject(self._arc_object.getSelectionSet(*gp_fixargs((), True)))

    @constants.maskargs
    def setSelectionSet(self, oidList=None, method='NEW'):
        """Table.setSelectionSet({oidList}, {method})

           Sets a table's selection using a Python set of Object IDs.

             oidList{Integer}:
           A Python set of Object IDs to use along with the appropriate
           selection method.

             method{String}:
           A string that specifies which selection method to use.

            * NEW: Creates a new record selection from the oidList .

            * DIFFERENCE: Selects the records that are not in the current
            selection but are in the oidList .

            * INTERSECT: Selects the records that are in the current selection
            and the oidList .

            * SYMDIFFERENCE: Selects the records that are in the current
            selection or the oidList but not both.

            * UNION: Selects all the records in both the current selection and
            those in the oidList ."""
        return convertArcObjectToPythonObject(self._arc_object.setSelectionSet(*gp_fixargs((oidList, method), True)))

    def updateConnectionProperties(self, current_connection_info, new_connection_info, auto_update_joins_and_relates=True, validate=True, ignore_case=False):
        """updateConnectionProperties(current_connection_info,
           new_connection_info, {auto_update_joins_and_relates}, {validate}, {ignore_case})

           Replaces connection properties using a dictionary or a path to a
           workspace.

             current_connection_info(String):
           A string that represents the workspace path or a Python dictionary
           that contains connection properties to the source you want to update.

             new_connection_info(String):
           A string that represents the workspace path or a Python dictionary
           that contains connection properties with the new source information.

             auto_update_joins_and_relates{Boolean}:
           If  set to True , the updateConnectionProperties method will also
           update the connections for associated joins or relates.

             validate{Boolean}:
           If  set to True , the connection properties will only be updated if
           the new_connection_info value is a valid connection.  If it is not
           valid, the connection will not be replaced.   If set to False , the
           method will set all connections to match the new_connection_info ,
           regardless of a valid match.  In this case, if a match does not
           exist, then the data sources would be broken.

             ignore_case{Boolean}:
           If set to True, UpdateConnectionProperties will ignore the case of
           current_connection_info. The default value is False, where
           UpdateConnectionProperties will honor the case of current_connection_info.
           The ignore_case parameter doesn't apply to the new_connection_info parameter."""
        return convertArcObjectToPythonObject(self._arc_object.updateConnectionProperties(*gp_fixargs((current_connection_info, new_connection_info, auto_update_joins_and_relates, validate, ignore_case), True)))

    def updateDefinitionQueries(self, definitionQueries):
        """
        Table.updateDefinitionQueries(definitionQueries)

        """
        return convertArcObjectToPythonObject(self._arc_object.updateDefinitionQueries(*gp_fixargs((definitionQueries,), True)))

    def listDefinitionQueries(self, wildcard=None):
        """Table.listDefinitionQueries({wildcard})

           Returns a Python list of DefinitionQueries that exist within a map.

             wildcard{String}:
           A wildcard is based on the defQuery name and is not case sensitive. A
           combination of asterisks (*) and characters can be used to help
           limit the resulting list."""
        return convertArcObjectToPythonObject(self._arc_object.listDefinitionQueries(*gp_fixargs((wildcard,), True)))

    def __init__(self, table_data_source):
        """Table(table_data_source)

           Enables you to reference a table in a workspace so that it can be added to a Map .

             table_data_source(String):
           A string that includes the full workspace path, including the name of the table.  For SDE tables, the workspace path is the path to an SDE connection file."""
        import arcgisscripting
        self._arc_object = arcgisscripting._mapping.Table(*gp_fixargs((table_data_source,), True))

    def __str__(self):
        return self.name

    def __eq__(self, other):
        if type(self)!= type(other):
            return False
        else:
            return convertArcObjectToPythonObject(self._arc_object.isTableSame(*gp_fixargs((other,), True)))

    @constants.maskargs
    def getDefinition(self, cim_version):
        """Table.getDefinition(cim_version)

        Gets a table's CIM definition.

          cim_version(String):
        A string that represents the major version of the CIM. """
        from .cim.cimloader import GetJSONTypeOBJ
        import json
        return GetJSONTypeOBJ(json.loads(convertArcObjectToPythonObject(self._arc_object.GetCimJSONString(*gp_fixargs((), True)))))

    @constants.maskargs
    def setDefinition(self, definition_object):
        """Table.setDefinition(definition_object)

        Sets a table's CIM definition.

          definition_object(Object):
        A modified CIM defintion object originally retrieved using getDefinition. """
        from .cim.cimloader import  CimJsonEncoder
        import json
        json_data = json.dumps(definition_object, cls=CimJsonEncoder)
        return convertArcObjectToPythonObject(self._arc_object.SetCimJSONString(json_data))

class TextElement(_ObjectWithoutInitCall):
    """The TextElement object provides access to properties that enable its
       repositioning on the page layout as well as modifying the text string and
       font size."""
    elementHeight = passthrough_attr('elementHeight')
    elementPositionX = passthrough_attr('elementPositionX')
    elementPositionY = passthrough_attr('elementPositionY')
    elementRotation = passthrough_attr('elementRotation')
    elementWidth = passthrough_attr('elementWidth')
    locked = passthrough_attr('locked')
    textAngle = passthrough_attr('textAngle')
    textSize = passthrough_attr('textSize')
    name = passthrough_attr('name')
    text = passthrough_attr('text')
    type = passthrough_attr('type')
    visible = passthrough_attr('visible')
    def clone(self, suffix=None):
        """TextElement.clone({suffix})

           Provides a mechanism to clone an existing  text element on a page
           layout.

             suffix{String}:
           An optional string that is used to tag each newly created text
           element.  The new element gets the same element name as the parent
           text element, plus the suffix value, plus a numeric sequencer.  For
           example, if the parent element name is FieldLabel and the suffix
           value is _copy , the newly cloned elements are named FieldLabel_copy
           , FieldLabel_copy_1 , FieldLabel_copy_2 , and so on.  If a suffix is
           not provided, the results resemble FieldLabel_1 , FieldLabel_2 ,
           FieldLabel_3 , and so on."""
        return convertArcObjectToPythonObject(self._arc_object.clone(*gp_fixargs((suffix,), True)))

    def delete(self):
        """TextElement.delete()

           Provides a mechanism to delete an existing text element on a page
           layout."""
        return convertArcObjectToPythonObject(self._arc_object.delete(*gp_fixargs((), True)))

class MapView(_ObjectWithoutInitCall):
    """The MapView."""
    camera = passthrough_attr('camera')
    map = passthrough_attr('map')

    @constants.maskargs
    def exportToPDF(self, out_pdf, width, height, resolution=96, image_quality='BEST', compress_vector_graphics=True, image_compression='ADAPTIVE', embed_fonts=True, layers_attributes='LAYERS_ONLY', georef_info=True, jpeg_compression_quality=80, output_as_image=False, embed_color_profile=True):
        """MapView.exportToPDF(out_pdf, width, height, {resolution}, {image_quality}, {compress_vector_graphics},
           {image_compression}, {embed_fonts}, {layers_attributes}, {georef_info}, {jpeg_compression_quality},
           {output_as_image}, {embed_color_profile})

           Exports the contents of a MapView to a Portable Document Format (PDF) file.

             out_pdf(String):
           A string that represents the path and file name of the output export file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             image_quality{String}:
           A string that defines output image quality.

             *  BEST —An output image quality resample ratio of 1

             *  BETTER —An output image quality resample ratio of 2

             *  NORMAL —An output image quality resample ratio of 3

             *  FASTER —An output image quality resample ratio of 4

             *  FASTEST —An output image quality resample ratio of 5

             compress_vector_graphics{Boolean}:
           A Boolean that controls compression of vector and text portions of the output file.
            Image compression is defined separately. The default value is True.

             image_compression{String}:
           A string that defines the compression scheme used to compress image or raster data in the output file.
           The default value is ADAPTIVE.

             *   ADAPTIVE —Automatically selects the best compression type for each image on the page. JPEG will be used for large images with many unique colors. DEFLATE will be used for all other images.

             *   JPEG —A lossy data compression.

             *   DEFLATE —A lossless data compression

             *   LZW —Lempel-Ziv-Welch, a lossless data compression

             *   NONE —Compression is not applied

             *   RLE —Run-length encoded compression

             embed_fonts{Boolean}:
           A Boolean that controls the embedding of fonts in an export file.
            Font embedding allows text and character markers to be displayed correctly when the document is viewed on a computer that does not have the necessary fonts installed.

             layers_attributes{String}:
           A string that controls inclusion of PDF layers and PDF object data (attributes) in the export file.
           The default value is LAYERS_ONLY.

             *    LAYERS_ONLY —Export PDF layers only.

             *    LAYERS_AND_ATTRIBUTES —Export PDF layers and feature attributes.

             *    NONE —No setting is applied.

             georef_info{Boolean}:
           A Boolean that enables the export of coordinate system information for each map frame into the output PDF file.

             jpeg_compression_quality{Integer}:
           A number that controls compression quality value when image_compression is set to ADAPTIVE or JPEG.
           The valid range is 1 through 100. A jpeg_compression_quality of 100 provides the best quality images but creates large export files.
           The recommended range is 70 through 90.
           The default value is 80.

             clip_to_elements{Boolean}:
           If set to True, the layout is clipped to the smallest bounding box that includes all layout elements.
           The default value is False.

             output_as_image{Boolean}:
           If set to True to vector content will be saved as an image.
           Selecting this option for maps or layouts that contain vector layers
           with a high density of vertices can drastically reduce the output file
           size. If exporting to PDF and this option set to True, you will not be
           able to view PDF layers in the output.

             embed_color_profile{Boolean}:
           If set to True, color profile information is embedded in the image's metadata."""
        return convertArcObjectToPythonObject(self._arc_object.exportToPDF(*gp_fixargs((out_pdf, width, height, resolution, image_quality, compress_vector_graphics, image_compression, embed_fonts, layers_attributes, georef_info, jpeg_compression_quality, False, output_as_image, embed_color_profile), True)))

    @constants.maskargs
    def exportToPNG(self, out_png, width, height, resolution=96, world_file=False, color_mode='32-BIT_WITH_ALPHA',
                    embed_color_profile=True):
        """MapView.exportToPNG(out_png, width, height, {resolution}, {world_file},
           {color_mode}, {embed_color_profile})

           Exports the contents of a MapView to Portable Network Graphics
           format (PNG).

             out_png(String):
           A string that represents the path and file name for the output export
           file.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             world_file{Boolean}:
           If set to True , a georeferenced world file is created. The file
           contains pixel scale information and real-world coordinate
           information.  If you export a 3D map frame, this parameter will be
           ignored regardless of the setting because world files are not
           applicable to 3D views.

             color_mode{String}:
           This value specifies the number of bits used to describe color.

            * 8-BIT_ADAPTIVE_PALETTE:   8-bit adaptive palette

            * 8-BIT_GRAYSCALE:   8-bit grayscale

            * 24-BIT_TRUE_COLOR:   24-bit true color

            * 32-BIT_WITH_ALPHA:   32-bit with alpha

              embed_color_profile{Boolean}:
            If set to True, color profile information is embedded in the image's metadata."""
        return convertArcObjectToPythonObject(self._arc_object.exportToPNG(*gp_fixargs((out_png, width, height, resolution, world_file, color_mode, embed_color_profile), True)))

    @constants.maskargs
    def exportToJPEG(self, out_jpg, width, height, resolution=96, world_file=False, jpeg_color_mode='24-BIT_TRUE_COLOR', jpeg_quality=80, embed_color_profile=True):
        """MapView.exportToJPEG(out_jpg, width, height, {resolution}, {world_file},
           {jpeg_color_mode}, {jpeg_quality}, {embed_color_profile})

           Exports the contents of a MapView to the Joint Photographic Experts
           Group format (JPEG).

             out_jpg(String):
           A string that represents the path and file name for the output export
           file.

             width(Integer):
           A number that defines the width of the export in pixels.

             height(Integer):
           A number that defines the height of the export in pixels.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             world_file{Boolean}:
           If set to True , a georeferenced world file is created. The file
           contains pixel scale information and real-world coordinate
           information.  If you export a 3D map frame, this parameter will be
           ignored regardless of the setting because world files are not
           applicable to 3D views.

             jpeg_color_mode{String}:
           This value specifies the number of bits used to describe color.

            * 8-BIT_GRAYSCALE:   8-bit grayscale

            * 24-BIT_TRUE_COLOR:   24-bit true color

             jpeg_quality{Integer}:
           This value (0–100) controls the amount of compression applied to the
           output image. For JPEG, image quality is adversely affected the more
           compression is applied. A higher quality (highest = 100) setting will
           produce sharper images and larger file sizes. A lower quality setting
           will produce more image artifacts and smaller files.

             embed_color_profile{Boolean}:
           If set to True, color profile information is embedded in the image's metadata."""
        return convertArcObjectToPythonObject(self._arc_object.exportToJPEG(*gp_fixargs((out_jpg, width, height, resolution, world_file, jpeg_color_mode, jpeg_quality, embed_color_profile), True)))

    @constants.maskargs
    def exportToTIFF(self, out_tif, width, height, resolution=96, world_file=False, color_mode='24-BIT_TRUE_COLOR', tiff_compression='LZW', geoTIFF_tags=False,
                     jpeg_compression_quality=80, embed_color_profile=True):
        """MapView.exportToTIFF(out_tif, width, height, {resolution}, {world_file},
           {color_mode}, {tiff_compression}, {geoTIFF_tags}, {jpeg_compression_quality}, {embed_color_profile})

           Exports the map view to the Tagged Image File Format (TIFF).

             out_tif(String):
           A string that represents the path and file name for the output export
           file.

             width(Integer):
           A number that defines the width of the export in pixels.

             height(Integer):
           A number that defines the height of the export in pixels.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             world_file{Boolean}:
           If set to True , a georeferenced world file is created. The file
           contains pixel scale information and real-world coordinate
           information.  If you export a 3D map frame, this parameter will be
           ignored regardless of the setting because world files are not
           applicable to 3D views.

             color_mode{String}:
           This value specifies the number of bits used to describe color.

            * 8-BIT_ADAPTIVE_PALETTE:   8-bit adaptive palette

            * 8-BIT_GRAYSCALE:   8-bit grayscale

            * 24-BIT_TRUE_COLOR:   24-bit true color

            * 32-BIT_WITH_ALPHA:   32-bit with alpha
            
            * 32-BIT_CMYK_TRUE_COLOR:    32-bit true color for CMYK

            * 40-BIT_CMYK_WITH_ALPHA:    40-bit with alpha for CMYK

             tiff_compression{String}:
           This value represents a compression scheme.

            * DEFLATE:   A lossless data compression.

            * JPEG: JPEG compression.

            * LZW:   Lempel-Ziv-Welch, a lossless data compression.

            * NONE:   Compression is not applied.

            * PACK_BITS:   Pack bits compression.

             geoTIFF_tags{Boolean}:
           If set to True , georeferencing tags are included in the structure of
           the TIFF export file. The tags contain pixel scale information and
           real-world coordinate information. These tags can be read by
           applications that support GeoTIFF format.

             jpeg_compression_quality{Integer}:
           A number that controls compression quality value when
           image_compression is set to ADAPTIVE or JPEG . The valid range is 1
           to 100.    A jpeg_compression_quality of 100 provides the best-
           quality images but creates large export files.   The recommended
           range is between 70 and 90.

             embed_color_profile{Boolean}:
           If set to True, color profile information is embedded in the image's metadata."""
        return convertArcObjectToPythonObject(self._arc_object.exportToTIFF(*gp_fixargs((out_tif, width, height, resolution, world_file, color_mode, tiff_compression, geoTIFF_tags,
                                              jpeg_compression_quality, embed_color_profile), True)))

    @constants.maskargs
    def exportToSVG(self, out_svg, width, height, resolution=96, compress_to_svgz=False, image_quality='BEST', embed_fonts=True, output_as_image=False):
        """MapView.exportToSVG(out_svg, width, height, {resolution}, {compress_to_svgz}, {image_quality},
           {embed_fonts}, {output_as_image})

           Exports the map view to the Scalable Vector Graphics format (SVG).

             out_svg(String):
           A string that represents the path and file name for the output export
           file.

             width(Integer):
           A number that defines the width of the export in pixels.

             height(Integer):
           A number that defines the height of the export in pixels.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             compress_to_svgz{Boolean}:
           If set to True , the output is compressed.

             image_quality{String}:
           A string that specifies output image quality, the draw resolution of map layers that draw as rasters.

             embed_fonts{Boolean}:
           A Boolean that controls the embedding of fonts in the export file. Font embedding allows text
           and character markers to be displayed correctly when the document is viewed on a computer that
           does not have the necessary fonts installed.

            output_as_image{Boolean}:
          If set to True, vector content can be saved as an image. Selecting this option for maps or
         layouts that contain vector layers with a high density of vertices can reduce the output file
         size. When exporting to PDF and this option is set to True, you cannot view PDF layers in the output."""
        return convertArcObjectToPythonObject(self._arc_object.exportToSVG(*gp_fixargs((out_svg, width, height, resolution, compress_to_svgz, image_quality, embed_fonts, output_as_image), True)))

    @constants.maskargs
    def exportToEPS(self, out_eps, width, height, resolution=96, image_compression='DEFLATE', image_quality='BEST',
                   embed_fonts=True, output_as_image=False):
        """MapView.exportToEPS(out_eps, width, height, {resolution}, {image_compression}, {image_quality}, {embed_fonts}, {output_as_image})

           Exports the map view to an Encapsulated PostScript (EPS) format.

             out_eps(String):
           A string that represents the system path and file name for the output
           export file.

             width(Integer):
           A number that defines the width of the export in pixels.

             height(Integer):
           A number that defines the height of the export in pixels.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             image_compression{String}:
           A string that specifies the compression scheme used to compress image
           or raster data in the output file.

             image_quality{String}:
           A string that specifies output image quality, the draw resolution of
           map layers that draw as rasters.

             embed_fonts{Boolean}:
           A Boolean that controls the embedding of fonts in the export file.
           Font embedding allows text and character markers to be displayed correctly
           when the document is viewed on a computer that does not have the necessary
           fonts installed.

             output_as_image{Boolean}:
           If set to True, vector content can be saved as an image. Selecting this option
          for maps or layouts that contain vector layers with a high density of vertices
          can reduce the output file size. When exporting to PDF and this option is set to
          True, you cannot view PDF layers in the output."""
        return convertArcObjectToPythonObject(self._arc_object.exportToEPS(*gp_fixargs((out_eps, width, height, resolution, image_compression, image_quality, embed_fonts, output_as_image), True)))

    @constants.maskargs
    def exportToGIF(self, out_gif, width, height, resolution=96, world_file=False, gif_color_mode='8-BIT_ADAPTIVE_PALETTE'):
        """MapView.exportToGIF(out_gif, width, height, {resolution}, {world_file}, {gif_color_mode})

           Exports the map viwe to the Graphic Interchange format (GIF).

             out_gif(String):
           A string that represents the system path and file name for the output
           export file.

             width(Integer):
           A number that defines the width of the export in pixels.

             height(Integer):
           A number that defines the height of the export in pixels.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             world_file{Boolean}:
          If set to True, a georeferenced world file is created. The file contains
          pixel scale information and real-world coordinate information. If you export
          a 3D map frame, this parameter will be ignored regardless of the setting because
          world files are not applicable to 3D views.

             gif_color_mode{String}:
          This value specifies the number of bits used to describe color.

            * 8-BIT_ADAPTIVE_PALETTE:   8-bit adaptive palette

            * 8-BIT_GRAYSCALE:   8-bit grayscale."""
        return convertArcObjectToPythonObject(self._arc_object.exportToGIF(*gp_fixargs((out_gif, width, height, resolution, world_file, gif_color_mode), True)))

    @constants.maskargs
    def exportToBMP(self, out_bmp, width, height, resolution=96, world_file=False,
                    bmp_color_mode='24-BIT_TRUE_COLOR', bmp_image_compression='NONE', embed_color_profile=True):
        """MapView.exportToBMP(out_gif, width, height, {resolution}, {world_file}, {bmp_color_mode}, {bmp_image_compression}, {embed_color_profile})

           Exports the map view to the Microsoft Windows Bitmap format (BMP).

             out_gif(String):
           A string that represents the system path and file name for the output
           export file.

             width(Integer):
           A number that defines the width of the export in pixels.

             height(Integer):
           A number that defines the height of the export in pixels.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             world_file{Boolean}:
          If set to True, a georeferenced world file is created. The file contains
          pixel scale information and real-world coordinate information. If you export
          a 3D map frame, this parameter will be ignored regardless of the setting because
          world files are not applicable to 3D views.

            bmp_color_mode{String}:
          This value specifies the number of bits used to describe color.

            * 8-BIT_ADAPTIVE_PALETTE:   8-bit adaptive palette

            * 8-BIT_GRAYSCALE:   8-bit grayscale

            * 24-BIT_TRUE_COLOR:    24-bit true color.

            bmp_image_compression{String}:
          A string that specifies the compression scheme used to compress image or raster
          data in the output file. This option only applies to 8-bit bmp_color_mode options.

            * NONE:   Compression is not applied.

            * RLE:   Run-length encoded compression.

             embed_color_profile{Boolean}:
          If set to True, color profile information is embedded in the image's metadata."""
        return convertArcObjectToPythonObject(self._arc_object.exportToBMP(*gp_fixargs((out_bmp, width, height, resolution, world_file, bmp_color_mode, bmp_image_compression, embed_color_profile), True)))

    @constants.maskargs
    def exportToEMF(self, out_emf, width, height, resolution=96, image_quality='BEST', output_as_image=False):
        """MapView.exportToEMF(out_emf, width, height, {resolution}, {image_quality}, {output_as_image})

           Exports the map view to the Enhanced Metafile (EMF) format.

             out_emf(String):
           A string that represents the path and file name for the output export
           file.

             width(Integer):
           A number that defines the width of the export in pixels.

             height(Integer):
           A number that defines the height of the export in pixels.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             image_quality{String}:
           A string that specifies output image quality, the draw resolution of
           map layers that draw as rasters.

             *  BEST —An output image quality resample ratio of 1

             *  BETTER —An output image quality resample ratio of 2

             *  NORMAL —An output image quality resample ratio of 3

             *  FASTER —An output image quality resample ratio of 4

             *  FASTEST —An output image quality resample ratio of 5

             output_as_image{Boolean}:
           If set to True, vector content can be saved as an image. Selecting this option
          for maps or layouts that contain vector layers with a high density of vertices
          can reduce the output file size. When exporting to PDF and this option is set to
          True, you cannot view PDF layers in the output."""
        return convertArcObjectToPythonObject(self._arc_object.exportToEMF(*gp_fixargs((out_emf, width, height, resolution, image_quality, output_as_image), True)))

    def exportToTGA(self, out_tga, width, height, resolution=96, world_file=False, color_mode='24-BIT_TRUE_COLOR'):
        """MapView.exportToTGA(out_tga, width, height, {resolution}, {world_file}, {color_mode})

           Exports the map view to the Enhanced Metafile (EMF) format.

             out_tga(String):
           A string that represents the path and file name for the output export
           file.

             width(Integer):
           A number that defines the width of the export in pixels.

             height(Integer):
           A number that defines the height of the export in pixels.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             world_file{Boolean}:
          If set to True, a georeferenced world file is created. The file contains
          pixel scale information and real-world coordinate information. If you export
          a 3D map frame, this parameter will be ignored regardless of the setting because
          world files are not applicable to 3D views.

            color_mode{String}:
           This value specifies the number of bits used to describe color.

            * 8-BIT_ADAPTIVE_PALETTE:   8-bit adaptive palette

            * 8-BIT_GRAYSCALE:   8-bit grayscale

            * 24-BIT_TRUE_COLOR:   24-bit true color

            * 32-BIT_WITH_ALPHA:   32-bit with alpha."""
        return convertArcObjectToPythonObject(self._arc_object.exportToTGA(*gp_fixargs((out_tga, width, height, resolution, world_file, color_mode), True)))

    def exportToAIX(self, out_aix, width, height, resolution=300, image_quality='BEST', compress_vector_graphics=True, image_compression='ADAPTIVE', jpeg_compression_quality=80, embed_fonts=True, embed_color_profile=True):
        """MapView.exportToAIX(out_pdf, width, height, {resolution}, {image_quality},
           {compress_vector_graphics}, {image_compression},
           {jpeg_compression_quality}, {embed_fonts},
           {embed_color_profile})

           Exports the map view  to the Adobe Illustrator Format (AIX).

             out_aix(String):
           A string that represents the path and file name for the output export
           file.

             width(Integer):
           A number that defines the width of the export in pixels.

             height(Integer):
           A number that defines the height of the export in pixels.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (DPI).

             image_quality{String}:
           A string that defines output image quality, the draw resolution of
           map layers that draw as rasters.

            * BEST:  An output image quality resample ratio of 1.

            * BETTER:  An output image quality resample ratio of 2.

            * NORMAL:  An output image quality resample ratio of 3.

            * FASTER:  An output image quality resample ratio of 4.

            * FASTEST:  An output image quality resample ratio of 5.

             compress_vector_graphics{Boolean}:
           A Boolean that controls compression of vector and text portions of
           the output file. Image compression is defined separately.

             image_compression{String}:
           A string that defines the compression scheme used to compress image
           or raster data in the output file.

            * ADAPTIVE:   Automatically selects the best compression type for
            each image on the page.   JPEG will be used for large images with
            many unique colors.  DEFLATE will be used for all other images.

            * DEFLATE:   A lossless data compression.

            * JPEG:   A lossy data compression.

            * LZW:   Lempel-Ziv-Welch, a lossless data compression.

            * NONE:   Compression is not applied.

            * RLE:   Run-length encoded compression.

             jpeg_compression_quality{Integer}:
           A number that controls compression quality value when
           image_compression is set to ADAPTIVE or JPEG . The valid range is 1
           to 100.    A jpeg_compression_quality of 100 provides the best-
           quality images but creates large export files.   The recommended
           range is between 70 and 90.

             embed_fonts{Boolean}:
           A Boolean that controls the embedding of fonts in the export file.
           Font embedding allows text and character markers to be displayed
           correctly when the document is viewed on a computer that does not
           have the necessary fonts installed.

             embed_color_profile{Boolean}:
           If set to True, color profile information is embedded in the image's metadata."""
        return convertArcObjectToPythonObject(self._arc_object.exportToAIX(*gp_fixargs((out_aix, width, height, resolution, image_quality, compress_vector_graphics, image_compression, jpeg_compression_quality, embed_fonts, embed_color_profile), True)))

    def getLayerExtent(self, layer, selection_only=True, symbolized_extent=True):
        """MapView.getLayerExtent(layer, {selection_only}, {symbolized_extent})

           Returns a layer's extent for all features or only the selected
           features in a layer.

             layer(Layer):
           A reference to a Layer object.

             selection_only{Boolean}:
           If True , it returns the extent for selected features; if False , it
           returns the extent for all features.

             symbolized_extent{Boolean}:
           A value of True will return the layer's symbolized extent; otherwise,
           it will return the geometric extent.  The symbolized extent takes
           into account the area the symbology covers so that it does not get
           cut off by the data frame's boundary."""
        return convertArcObjectToPythonObject(self._arc_object.getLayerExtent(*gp_fixargs((layer, selection_only, symbolized_extent), True)))

    def panToExtent(self, extent):
        """MapView.panToExtent(extent)

           Pans and centers the MapView using a new Extent object without
           changing the map view's scale.

             extent(Extent):
           A geoprocessing Extent object."""
        return convertArcObjectToPythonObject(self._arc_object.panToExtent(*gp_fixargs((extent,), True)))

    def zoomToBookmark(self, bookmark):
        """MapView.zoomToBookmark(bookmark)

           Modifies the MapView's view to match the view information stored with
           a spatial bookmark.

             bookmark(Bookmark):
           A reference to a Bookmark object."""
        return convertArcObjectToPythonObject(self._arc_object.zoomToBookmark(*gp_fixargs((bookmark,), True)))

    def zoomToAllLayers(self, selection_only=True, symbolized_extent=True):
        """MapView.zoomToAllLayers({selection_only}, {symbolized_extent})

           Modifies the MapView's view to match the extent of all layers or
           selected layers in a map.

             selection_only{Boolean}:
           If True , it sets the extent based on the selected  features; if
           False , it sets the extent for all  features in a map.

             symbolized_extent{Boolean}:
           A value of True will return the layer's symbolized extent; otherwise,
           it will return the geometric extent.  The symbolized extent takes
           into account the area the symbology covers so that it does not get
           cut off by the map views's boundary."""
        return convertArcObjectToPythonObject(self._arc_object.zoomToAllLayers(*gp_fixargs((selection_only, symbolized_extent), True)))

class MapSeries(_ObjectWithoutInitCall):
    """ MapSeries object provides access to properties."""
    currentPageNumber = passthrough_attr('currentPageNumber')
    mapFrame = passthrough_attr('mapFrame')
    indexLayer = passthrough_attr('indexLayer')
    pageCount = passthrough_attr('pageCount')
    pageNameField = passthrough_attr('pageNameField')
    selectedIndexFeatures = passthrough_attr('selectedIndexFeatures')
    enabled = passthrough_attr('enabled')

    def _convert(self, dictionary):
      from collections import namedtuple
      #replace the special characters ( . ) in spatial fields names with _
      newDict = {key.replace('(', '_').replace(')', '_').replace('.', '_') : value for key, value in dictionary.items()}
      return namedtuple('pageRow', newDict.keys())(**newDict)

    @property
    def pageRow(self):
      return self._convert(convertArcObjectToPythonObject(getattr(self._arc_object, "pageRow")))

    @constants.maskargs
    def exportToPDF(self, out_pdf, page_range_type="ALL", page_range_string="", multiple_files="PDF_SINGLE_FILE", resolution=96, image_quality='BEST', compress_vector_graphics=True, image_compression='ADAPTIVE', embed_fonts=True, layers_attributes='LAYERS_ONLY', georef_info=True, jpeg_compression_quality=80, clip_to_elements=False, show_selection_symbology=False, output_as_image=False, embed_color_profile=True, pdf_accessibility=False):
        """MapSeries.exportToPDF(out_pdf, {page_range_type}, {page_range_string}, {multiple_files}, {resolution}, {image_quality}, {compress_vector_graphics}, {image_compression}, {embed_fonts}, {layers_attributes},
          {georef_info}, {jpeg_compression_quality}, {clip_to_elements}, {show_selection_symbology},
          {output_as_image}, {embed_color_profile}, {pdf_accessibility})

           Exports a specified set of pages to a Portable Document Format (PDF) file for a layout that has map series enabled.

             out_pdf(String):
           A string that represents the path and file name of the output export file.

             page_range_type{String}:
           The string value that designates how the pages will be printed. The default value is ALL.

            *  ALL: All pages are exported.

            *  CURRENT: The active or current page is exported.

            *  RANGE: Only pages listed in the page_range_string parameter will be exported.

            *  SELECTED: Selected index layer features/pages are exported.

             page_range_string{String}:
           A string that identifies the pages to be exported if the RANGE option in the page_range_type parameter is used (for example, 1, 3, 5-12).
           If any other page_range_type value is used, the page_range_string value will be ignored.

             multiple_files{String}:
           An option to control how the output PDF file is created. By default, all pages are exported into a single, multi-page document.
           The default is PDF_SINGLE_FILE.

            * PDF_MULTIPLE_FILES_PAGE_NAME —Export each map series page to an individual file and append the page name to the file name.

            * PDF_MULTIPLE_FILES_PAGE_NUMBER —Export each map series page to an individual file and append the page number to the file name.

            * PDF_SINGLE_FILE —Export into a multi-page, single file document.

             resolution{Integer}:
           A number that defines the resolution of the export file in dots per
           inch (dpi).

             image_quality{String}:
           A string that defines output image quality.

             *  BEST —An output image quality resample ratio of 1

             *  BETTER —An output image quality resample ratio of 2

             *  NORMAL —An output image quality resample ratio of 3

             *  FASTER —An output image quality resample ratio of 4

             *  FASTEST —An output image quality resample ratio of 5

             compress_vector_graphics{Boolean}:
           A Boolean that controls compression of vector and text portions of the output file.
            Image compression is defined separately. The default value is True.

             image_compression{String}:
           A string that defines the compression scheme used to compress image or raster data in the output file.
           The default value is ADAPTIVE.

             *   ADAPTIVE —Automatically selects the best compression type for each image on the page. JPEG will be used for large images with many unique colors. DEFLATE will be used for all other images.

             *   JPEG —A lossy data compression.

             *   DEFLATE —A lossless data compression

             *   LZW —Lempel-Ziv-Welch, a lossless data compression

             *   NONE —Compression is not applied

             *   RLE —Run-length encoded compression

             embed_fonts{Boolean}:
           A Boolean that controls the embedding of fonts in an export file.
            Font embedding allows text and character markers to be displayed correctly when the document is viewed on a computer that does not have the necessary fonts installed.

             layers_attributes{String}:
           A string that controls inclusion of PDF layers and PDF object data (attributes) in the export file.
           The default value is LAYERS_ONLY.

             *    LAYERS_ONLY —Export PDF layers only.

             *    LAYERS_AND_ATTRIBUTES —Export PDF layers and feature attributes.

             *    NONE —No setting is applied.

             georef_info{Boolean}:
           A Boolean that enables the export of coordinate system information for each map frame into the output PDF file.

             jpeg_compression_quality{Integer}:
           A number that controls compression quality value when image_compression is set to ADAPTIVE or JPEG.
           The valid range is 1 through 100. A jpeg_compression_quality of 100 provides the best quality images but creates large export files.
           The recommended range is 70 through 90.
           The default value is 80.

             clip_to_elements{Boolean}:
           If set to True, the layout is clipped to the smallest bounding box that includes all layout elements.
           The default value is False.

             show_selection_symbology{Boolean}:
           A Boolean that controls whether the selection symbology should be displayed in the output.
           The default value is False.

             output_as_image{Boolean}:
           If set to True to vector content will be saved as an image.
           Selecting this option for maps or layouts that contain vector layers
           with a high density of vertices can drastically reduce the output file
           size. If exporting to PDF and this option set to True, you will not be
           able to view PDF layers in the output.

             embed_color_profile{Boolean}:
           If set to True, color profile information is embedded in the image's metadata.
           
             pdf_accessibility{Boolean}:
           If set to True, enhanced PDF accessibility will occur."""
        return convertArcObjectToPythonObject(self._arc_object.exportToPDF(*gp_fixargs((out_pdf, page_range_type, page_range_string, multiple_files ,resolution, image_quality, compress_vector_graphics, image_compression, embed_fonts, layers_attributes, georef_info, jpeg_compression_quality, clip_to_elements, show_selection_symbology, output_as_image, embed_color_profile, pdf_accessibility), True)))

    def getPageNumberFromName(self, page_name):
        return convertArcObjectToPythonObject(self._arc_object.getPageNumberFromName(*gp_fixargs((page_name,), True)))

    def refresh(self):
        return convertArcObjectToPythonObject(self._arc_object.refresh(*gp_fixargs((), True)))

# Decorate PDFDocument methods with constants lists for Python window
PDFDocument.updateDocProperties.__esri_toolinfo__ = constants.maskargs(PDFDocument.updateDocProperties).__esri_toolinfo__
PDFDocument.updateDocSecurity.__esri_toolinfo__ = constants.maskargs(PDFDocument.updateDocSecurity).__esri_toolinfo__

ob_conversion = (
    ('MappingArcGISProjectObject', ArcGISProject),
    ('MappingBookmarkObject', Bookmark),
    ('MappingCameraObject', Camera),
    ('MappingGraphicElementObject', GraphicElement),
    ('MappingLabelClassObject', LabelClass),
    ('MappingLayerObject', Layer),
    ('MappingLayerFileObject', LayerFile),
    ('MappingLayoutObject', Layout),
    ('MappingLegendElementObject', LegendElement),
    ('MappingReportObject', Report),
    ('MappingMapObject', Map),
    ('MappingMapFrameObject', MapFrame),
    ('MappingMapSurroundElementObject', MapSurroundElement),
    ('MappingPictureElementObject', PictureElement),
    ('MappingTableObject', Table),
    ('MappingTextElementObject', TextElement),
    ('MappingMapSeriesObject', MapSeries),
    ('MappingMapViewObject', MapView),
    ('MappingSymbologyObject', Symbology),
    ('MappingColorMapObject', ColorRamp),
    ('MappingSymbolObject', Symbol),
    ('MappingClassBreakObject', ClassBreak),
    ('MappingRasterClassBreakObject', RasterClassBreak),
    ('MappingItemGroupObject', ItemGroup),
    ('MappingItemObject', Item),
    ('MappingRasterItemObject', RasterItem),
    ('MappingLayerTimeObject', LayerTime),
    ('MetadataObject', metadata.Metadata),
    ('MappingMapTimeObject', MapTime),
)
