# -*- coding: utf-8 -*-
# COPYRIGHT 2020 ESRI
#
# TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
# Unpublished material - all rights reserved under the
# Copyright Laws of the United States.
#
# For additional information, contact:
# Environmental Systems Research Institute, Inc.
# Attn: Contracts Dept
# 380 New York Street
# Redlands, California, USA 92373
#
# email: contracts@esri.com
#
# Warning: This module is automatically generated, changes will be overwritten.
from arcgisscripting import _wrapToolRaster, _wrapLocalFunctionRaster
import arcpy
from ..sa import ParameterClasses
from ..sa import Utils

try:
    unicode
except NameError:
    unicode = str


__all__ = [
    "Abs",
    "ACos",
    "ACosH",
    "AggregateMultidimensionalRaster",
    "AnalyzeChangesUsingCCDC",
    "AnalyzeChangesUsingLandTrendr",
    "ASin",
    "ASinH",
    "ATan",
    "ATan2",
    "ATanH",
    "BitwiseAnd",
    "BitwiseLeftShift",
    "BitwiseNot",
    "BitwiseOr",
    "BitwiseRightShift",
    "BitwiseXOr",
    "BooleanAnd",
    "BooleanNot",
    "BooleanOr",
    "BooleanXOr",
    "CellStatistics",
    "ClassifyObjectsUsingDeepLearning",
    "ClassifyPixelsUsingDeepLearning",
    "ClassifyRaster",
    "CombinatorialAnd",
    "CombinatorialOr",
    "CombinatorialXOr",
    "ComputeAccuracyForObjectDetection",
    "ComputeChangeRaster",
    "ComputeConfusionMatrix",
    "ComputeSegmentAttributes",
    "Con",
    "Cos",
    "CosH",
    "CreateAccuracyAssessmentPoints",
    "DeepLearningModelToEcd",
    "DetectChangeUsingChangeAnalysisRaster",
    "DetectChangeUsingDeepLearning",
    "DetectObjectsUsingDeepLearning",
    "Diff",
    "DimensionalMovingStatistics",
    "Divide",
    "EqualTo",
    "Exp",
    "Exp10",
    "Exp2",
    "ExportTrainingDataForDeepLearning",
    "ExtractVideoFramesToImages",
    "FindArgumentStatistics",
    "Float",
    "FocalStatistics",
    "GenerateMultidimensionalAnomaly",
    "GenerateTrainingSamplesFromSeedPoints",
    "GenerateTrendRaster",
    "GreaterThan",
    "GreaterThanEqual",
    "InList",
    "InspectTrainingSamples",
    "Int",
    "IsNull",
    "LessThan",
    "LessThanEqual",
    "LinearSpectralUnmixing",
    "Ln",
    "Log10",
    "Log2",
    "Minus",
    "Mod",
    "MultidimensionalPrincipalComponents",
    "Negate",
    "NonMaximumSuppression",
    "NotEqual",
    "Over",
    "Pick",
    "Plus",
    "Power",
    "PredictUsingRegressionModel",
    "PredictUsingTrendRaster",
    "RemoveRasterSegmentTilingArtifacts",
    "RoundDown",
    "RoundUp",
    "Sample",
    "SegmentMeanShift",
    "SetNull",
    "Sin",
    "SinH",
    "Square",
    "SquareRoot",
    "SummarizeCategoricalRaster",
    "Tan",
    "TanH",
    "Test",
    "Times",
    "TrainDeepLearningModel",
    "TrainIsoClusterClassifier",
    "TrainKNearestNeighborClassifier",
    "TrainMaximumLikelihoodClassifier",
    "TrainRandomTreesClassifier",
    "TrainRandomTreesRegressionModel",
    "TrainSupportVectorMachineClassifier",
    "UpdateAccuracyAssessmentPoints",
    "VideoMetadataToFeatureClass",
    "VideoMultiplexer",
    "WeightedSum",
    "ZonalStatistics",
    "ZonalStatisticsAsTable",
    "ApplyEnvironment",
    "FloatDivide",
    "FloorDivide"
]


def Abs(
        in_raster_or_constant):
    """Abs_ia(in_raster_or_constant)

    Calculates the absolute value of the cells in a raster.

    Arguments:
    in_raster_or_constant -- The input raster for which to calculate the absolute values.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"Abs_sa",
            ["Abs", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
Abs.__esri_toolname__ = "Abs_ia"
Abs.__esri_toolinfo__ = [
    "::::1"
]


def ACos(
        in_raster_or_constant):
    """ACos_ia(in_raster_or_constant)

    Calculates the inverse cosine of cells in a raster.

    Arguments:
    in_raster_or_constant -- The input for which to calculate the inverse cosine values.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"ACos_sa",
            ["ACos", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
ACos.__esri_toolname__ = "ACos_ia"
ACos.__esri_toolinfo__ = [
    "::::1"
]


def ACosH(
        in_raster_or_constant):
    """ACosH_ia(in_raster_or_constant)

    Calculates the inverse hyperbolic cosine of cells in a raster.

    Arguments:
    in_raster_or_constant -- The input for which to calculate the inverse hyperbolic cosine values.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"ACosH_sa",
            ["ACosH", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
ACosH.__esri_toolname__ = "ACosH_ia"
ACosH.__esri_toolinfo__ = [
    "::::1"
]


def AggregateMultidimensionalRaster(
        in_multidimensional_raster,
        dimension,
        aggregation_method="#",
        variables="#",
        aggregation_def="#",
        interval_keyword="#",
        interval_value="#",
        interval_unit="#",
        interval_ranges="#",
        aggregation_function="#",
        ignore_nodata="#",
        dimensionless="#",
        percentile_value="#",
        percentile_interpolation_type="#"):
    """AggregateMultidimensionalRaster_ia(in_multidimensional_raster, dimension, {aggregation_method}, {[variable,...]}, {aggregation_def}, {interval_keyword}, {interval_value}, {interval_unit}, {interval_ranges}, {aggregation_function}, {ignore_nodata}, {dimensionless}, {percentile_value}, {percentile_interpolation_type})

    Generates a multidimensional raster dataset by combining existing multidimensional raster variables along a dimension.

    Arguments:
    in_multidimensional_raster -- The input multidimensional raster dataset.
    dimension -- The aggregation dimension. This is the dimension along which the variables will be aggregated.
    aggregation_method -- Specifies the mathematical method that will be used to combine the aggregated slices in an interval.
    variable -- The variable or variables that will be aggregated along the given dimension. If no variable is specified, all variables with the selected dimension will be aggregated.
    aggregation_def -- Specifies the dimension interval for which the data will be aggregated.
    interval_keyword -- Specifies the keyword interval that will be used when aggregating along the dimension. This parameter is required when the Aggregation Definition parameter is set to Interval Keyword and the aggregation must be across time.
    interval_value -- The size of the interval that will be used for the aggregation. This parameter is required when the Aggregation Definition parameter is set to Interval Value.
    interval_unit -- The unit that will be used for the Value Interval parameter. This parameter is required when the Dimension parameter is a time field and the Aggregation Definition parameter is set to Interval Value.
    interval_ranges -- Interval ranges specified in a value table will be used to aggregate groups of values. The value table consists of pairs of minimum and maximum range values, with data type Double or Date.
    aggregation_function -- A custom raster function that will be used to compute the pixel values of the aggregated rasters. The input is a raster function JSON object or an .rft.xml file created from a function chain or a custom Python raster function.
    ignore_nodata -- Specifies whether NoData values are ignored in the analysis.
    dimensionless -- Specifies whether the layer will have dimension values. This parameter is only active if a single slice is selected to create a layer.
    percentile_value -- The percentile to calculate. The default is 90, indicating the 90th percentile.
    percentile_interpolation_type -- Specifies the method of percentile interpolation that will be used when there is an even number of values from the input raster to be calculated.

    Results:
    out_multidimensional_raster -- Output Multidimensional Raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_multidimensional_raster,
            dimension,
            aggregation_method,
            variables,
            aggregation_def,
            interval_keyword,
            interval_value,
            interval_unit,
            interval_ranges,
            aggregation_function,
            ignore_nodata,
            dimensionless,
            percentile_value,
            percentile_interpolation_type):
        out_multidimensional_raster = "#"
        result = arcpy.gp.AggregateMultidimensionalRaster_ia(
            in_multidimensional_raster,
            dimension,
            out_multidimensional_raster,
            aggregation_method,
            variables,
            aggregation_def,
            interval_keyword,
            interval_value,
            interval_unit,
            interval_ranges,
            aggregation_function,
            ignore_nodata,
            dimensionless,
            percentile_value,
            percentile_interpolation_type)
        return _wrapToolRaster(u"AggregateMultidimensionalRaster_sa", unicode(result.getOutput(0)))
    return Wrapper(
        in_multidimensional_raster,
        dimension,
        aggregation_method,
        variables,
        aggregation_def,
        interval_keyword,
        interval_value,
        interval_unit,
        interval_ranges,
        aggregation_function,
        ignore_nodata,
        dimensionless,
        percentile_value,
        percentile_interpolation_type)
AggregateMultidimensionalRaster.__esri_toolname__ = "AggregateMultidimensionalRaster_ia"
AggregateMultidimensionalRaster.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::4",
    "::::5",
    "::::6",
    "::::7",
    "::::8",
    "::::9",
    "::::10",
    "::::11",
    "::::12",
    "::::13",
    "::::14",
    "::::15"
]


def AnalyzeChangesUsingCCDC(
        in_multidimensional_raster,
        bands="#",
        tmask_bands="#",
        chi_squared_threshold="#",
        min_anomaly_observations="#",
        update_frequency="#"):
    """AnalyzeChangesUsingCCDC_ia(in_multidimensional_raster, {[band,...]}, {[tmask_band,...]}, {chi_squared_threshold}, {min_anomaly_observations}, {update_frequency})

    Evaluates changes in pixel values over time using the Continuous Change Detection and Classification (CCDC) method and generates a change analysis raster containing the model results.

    Arguments:
    in_multidimensional_raster -- The input multidimensional raster dataset.
    band -- The band IDs to use for change detection. If no band IDs are provided, all the bands from the input raster dataset will be used.
    tmask_band -- The band IDs to be used in the temporal mask (Tmask). It is recommended that you use the green band and the SWIR band. If no band IDs are provided, no masking will occur.
    chi_squared_threshold -- The chi-square statistic change probability threshold. If an observation has a calculated change probability that is above this threshold, it is flagged as an anomaly, which is a potential change event. The default value is 0.99.
    min_anomaly_observations -- The minimum number of consecutive anomaly observations that must occur before an event is considered a change. A pixel must be flagged as an anomaly for the specified number of consecutive time slices before it is considered a true change. The default value is 6.
    update_frequency -- The frequency, in years, at which to update the time series model with new observations. The default value is 1.

    Results:
    out_ccdc_result -- Output CCDC Analysis Raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_multidimensional_raster,
            bands,
            tmask_bands,
            chi_squared_threshold,
            min_anomaly_observations,
            update_frequency):
        out_ccdc_result = "#"
        result = arcpy.gp.AnalyzeChangesUsingCCDC_ia(
            in_multidimensional_raster,
            out_ccdc_result,
            bands,
            tmask_bands,
            chi_squared_threshold,
            min_anomaly_observations,
            update_frequency)
        return _wrapToolRaster(u"AnalyzeChangesUsingCCDC_sa", unicode(result.getOutput(0)))
    return Wrapper(
        in_multidimensional_raster,
        bands,
        tmask_bands,
        chi_squared_threshold,
        min_anomaly_observations,
        update_frequency)
AnalyzeChangesUsingCCDC.__esri_toolname__ = "AnalyzeChangesUsingCCDC_ia"
AnalyzeChangesUsingCCDC.__esri_toolinfo__ = [
    "::::1",
    "::::3",
    "::::4",
    "::::5",
    "::::6",
    "::::7"
]


def AnalyzeChangesUsingLandTrendr(
        in_multidimensional_raster,
        processing_band="#",
        snapping_date="#",
        max_num_segments="#",
        vertex_count_overshoot="#",
        spike_threshold="#",
        recovery_threshold="#",
        prevent_one_year_recovery="#",
        recovery_trend="#",
        min_num_observations="#",
        best_model_proportion="#",
        pvalue_threshold="#",
        output_other_bands="#"):
    """AnalyzeChangesUsingLandTrendr_ia(in_multidimensional_raster, {processing_band}, {snapping_date}, {max_num_segments}, {vertex_count_overshoot}, {spike_threshold}, {recovery_threshold}, {prevent_one_year_recovery}, {recovery_trend}, {min_num_observations}, {best_model_proportion}, {pvalue_threshold}, {output_other_bands})

    Evaluates changes in pixel values over time using the Landsat-based detection of trends in disturbance and recovery (LandTrendr) method and generates a change analysis raster containing the model results.

    Arguments:
    in_multidimensional_raster -- The input multidimensional raster dataset.
    processing_band -- The image band name to use for segmenting the pixel value trajectories over time. Choose the band name that will best capture the changes in the feature you want to observe.
    snapping_date -- The date used to identify a slice for each year in the input multidimensional dataset. The slice with the date closest to the snapping date will be used. This parameter is required if the input dataset contains sub-yearly data.
    max_num_segments -- The maximum number of segments to be fitted to the time series for each pixel. The default is 5.
    vertex_count_overshoot -- The number of additional vertices beyond max_num_segments + 1 that can be used to fit the model during the initial stage of identifying vertices. Later in the modeling process, the number of additional vertices will be reduced to max_num_segments + 1. The default is 2.
    spike_threshold -- The threshold to use for dampening spikes or anomalies in the pixel value trajectory. The value must range between 0 and 1 in which 1 means no dampening. The default is 0.9.
    recovery_threshold -- The recovery threshold value in years. If a segment has a recovery rate that is faster than 1/recovery threshold, the segment is discarded and not included in the time series model. The value must range between 0 and 1. The default is 0.25.
    prevent_one_year_recovery -- Specifies whether segments that exhibit a one year recovery will be excluded.
    recovery_trend -- Specifies whether the recovery has an increasing (positive) trend.
    min_num_observations -- The minimum number of valid observations required to perform fitting. The number of years in the input multidimensional dataset must be equal to or greater than this value. The default is 6.
    best_model_proportion -- The best model proportion value. During the model selection process, the tool will calculate the p-value for each model and identify a model that has the most vertices while maintaining the smallest (most significant) p-value based on this proportion value. A value of 1 means the model has the lowest p-value but may not have a high number of vertices. The default is 1.25.
    pvalue_threshold -- The p-value threshold for a model to be selected. After the vertices are detected in the initial stage of the model fitting, the tool will fit each segment and calculate the p-value to determine the significance of the model. On the next iteration, the model will decrease the number of segments by one and recalculate the p-value. This will continue and, if the p-value is smaller than the value specified in this parameter, the model will be selected and the tool will stop searching for a better model. If no such model is selected, the tool will select a model with a p-value smaller than the lowest p-value  best model proportion value. The default is 0.01.
    output_other_bands -- Specifies whether other bands will be included in the results.

    Results:
    out_multidimensional_raster -- Output Multidimensional Raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_multidimensional_raster,
            processing_band,
            snapping_date,
            max_num_segments,
            vertex_count_overshoot,
            spike_threshold,
            recovery_threshold,
            prevent_one_year_recovery,
            recovery_trend,
            min_num_observations,
            best_model_proportion,
            pvalue_threshold,
            output_other_bands):
        out_multidimensional_raster = "#"
        result = arcpy.gp.AnalyzeChangesUsingLandTrendr_ia(
            in_multidimensional_raster,
            out_multidimensional_raster,
            processing_band,
            snapping_date,
            max_num_segments,
            vertex_count_overshoot,
            spike_threshold,
            recovery_threshold,
            prevent_one_year_recovery,
            recovery_trend,
            min_num_observations,
            best_model_proportion,
            pvalue_threshold,
            output_other_bands)
        return _wrapToolRaster(u"AnalyzeChangesUsingLandTrendr_sa", unicode(result.getOutput(0)))
    return Wrapper(
        in_multidimensional_raster,
        processing_band,
        snapping_date,
        max_num_segments,
        vertex_count_overshoot,
        spike_threshold,
        recovery_threshold,
        prevent_one_year_recovery,
        recovery_trend,
        min_num_observations,
        best_model_proportion,
        pvalue_threshold,
        output_other_bands)
AnalyzeChangesUsingLandTrendr.__esri_toolname__ = "AnalyzeChangesUsingLandTrendr_ia"
AnalyzeChangesUsingLandTrendr.__esri_toolinfo__ = [
    "::::1",
    "::::3",
    "::::4",
    "::::5",
    "::::6",
    "::::7",
    "::::8",
    "::::9",
    "::::10",
    "::::11",
    "::::12",
    "::::13",
    "::::14"
]


def ASin(
        in_raster_or_constant):
    """ASin_ia(in_raster_or_constant)

    Calculates the inverse sine of cells in a raster.

    Arguments:
    in_raster_or_constant -- The input for which to calculate the inverse sine values.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"ASin_sa",
            ["ASin", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
ASin.__esri_toolname__ = "ASin_ia"
ASin.__esri_toolinfo__ = [
    "::::1"
]


def ASinH(
        in_raster_or_constant):
    """ASinH_ia(in_raster_or_constant)

    Calculates the inverse hyperbolic sine of cells in a raster.

    Arguments:
    in_raster_or_constant -- The input for which to calculate the inverse hyperbolic sine values.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"ASinH_sa",
            ["ASinH", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
ASinH.__esri_toolname__ = "ASinH_ia"
ASinH.__esri_toolinfo__ = [
    "::::1"
]


def ATan(
        in_raster_or_constant):
    """ATan_ia(in_raster_or_constant)

    Calculates the inverse tangent of cells in a raster.

    Arguments:
    in_raster_or_constant -- The input for which to calculate the inverse tangent values.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"ATan_sa",
            ["ATan", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
ATan.__esri_toolname__ = "ATan_ia"
ATan.__esri_toolinfo__ = [
    "::::1"
]


def ATan2(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """ATan2_ia(in_raster_or_constant1, in_raster_or_constant2)

    Calculates the inverse tangent (based on x,y) of cells in a raster.

    Arguments:
    in_raster_or_constant1 -- The input that specifies the numerator, or y value, to use when calculating the inverse tangent.
    in_raster_or_constant2 -- The input that specifies the denominator, or x value, to use when calculating the inverse tangent.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant1,
            in_raster_or_constant2):
        return _wrapLocalFunctionRaster(u"ATan2_sa",
            ["ATan2", in_raster_or_constant1, in_raster_or_constant2])
    return Wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)
ATan2.__esri_toolname__ = "ATan2_ia"
ATan2.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def ATanH(
        in_raster_or_constant):
    """ATanH_ia(in_raster_or_constant)

    Calculates the inverse hyperbolic tangent of cells in a raster.

    Arguments:
    in_raster_or_constant -- The input for which to calculate the inverse hyperbolic tangent values.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"ATanH_sa",
            ["ATanH", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
ATanH.__esri_toolname__ = "ATanH_ia"
ATanH.__esri_toolinfo__ = [
    "::::1"
]


def BitwiseAnd(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """BitwiseAnd_ia(in_raster_or_constant1, in_raster_or_constant2)

    Performs a Bitwise And operation on the binary values of two input rasters.

    Arguments:
    in_raster_or_constant1 -- The first input to use in this bitwise operation.
    in_raster_or_constant2 -- The second input to use in this bitwise operation.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant1,
            in_raster_or_constant2):
        return _wrapLocalFunctionRaster(u"BitwiseAnd_sa",
            ["BitwiseAnd", in_raster_or_constant1, in_raster_or_constant2])
    return Wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)
BitwiseAnd.__esri_toolname__ = "BitwiseAnd_ia"
BitwiseAnd.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def BitwiseLeftShift(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """BitwiseLeftShift_ia(in_raster_or_constant1, in_raster_or_constant2)

    Performs a Bitwise Left Shift operation on the binary values of two input rasters.

    Arguments:
    in_raster_or_constant1 -- The input on which to perform the shift.
    in_raster_or_constant2 -- The input defining the number of positions to shift the bits.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant1,
            in_raster_or_constant2):
        return _wrapLocalFunctionRaster(u"BitwiseLeftShift_sa",
            ["BitwiseLeftShift", in_raster_or_constant1, in_raster_or_constant2])
    return Wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)
BitwiseLeftShift.__esri_toolname__ = "BitwiseLeftShift_ia"
BitwiseLeftShift.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def BitwiseNot(
        in_raster_or_constant):
    """BitwiseNot_ia(in_raster_or_constant)

    Performs a Bitwise Not (complement) operation on the binary value of an input raster.

    Arguments:
    in_raster_or_constant -- The input raster on which to perform the Bitwise Not (complement) operation.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"BitwiseNot_sa",
            ["BitwiseNot", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
BitwiseNot.__esri_toolname__ = "BitwiseNot_ia"
BitwiseNot.__esri_toolinfo__ = [
    "::::1"
]


def BitwiseOr(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """BitwiseOr_ia(in_raster_or_constant1, in_raster_or_constant2)

    Performs a Bitwise Or operation on the binary values of two input rasters.

    Arguments:
    in_raster_or_constant1 -- The first input to use in this bitwise operation.
    in_raster_or_constant2 -- The second input to use in this bitwise operation.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant1,
            in_raster_or_constant2):
        return _wrapLocalFunctionRaster(u"BitwiseOr_sa",
            ["BitwiseOr", in_raster_or_constant1, in_raster_or_constant2])
    return Wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)
BitwiseOr.__esri_toolname__ = "BitwiseOr_ia"
BitwiseOr.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def BitwiseRightShift(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """BitwiseRightShift_ia(in_raster_or_constant1, in_raster_or_constant2)

    Performs a Bitwise Right Shift operation on the binary values of two input rasters.

    Arguments:
    in_raster_or_constant1 -- The input on which to perform the shift.
    in_raster_or_constant2 -- The input defining the number of positions to shift the bits.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant1,
            in_raster_or_constant2):
        return _wrapLocalFunctionRaster(u"BitwiseRightShift_sa",
            ["BitwiseRightShift", in_raster_or_constant1, in_raster_or_constant2])
    return Wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)
BitwiseRightShift.__esri_toolname__ = "BitwiseRightShift_ia"
BitwiseRightShift.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def BitwiseXOr(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """BitwiseXOr_ia(in_raster_or_constant1, in_raster_or_constant2)

    Performs a Bitwise eXclusive Or operation on the binary values of two input rasters.

    Arguments:
    in_raster_or_constant1 -- The first input to use in this bitwise operation.
    in_raster_or_constant2 -- The second input to use in this bitwise operation.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant1,
            in_raster_or_constant2):
        return _wrapLocalFunctionRaster(u"BitwiseXOr_sa",
            ["BitwiseXOr", in_raster_or_constant1, in_raster_or_constant2])
    return Wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)
BitwiseXOr.__esri_toolname__ = "BitwiseXOr_ia"
BitwiseXOr.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def BooleanAnd(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """BooleanAnd_ia(in_raster_or_constant1, in_raster_or_constant2)

    Performs a Boolean And operation on the cell values of two input rasters.

    Arguments:
    in_raster_or_constant1 -- The first input to use in this Boolean operation.
    in_raster_or_constant2 -- The second input to use in this Boolean operation.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant1,
            in_raster_or_constant2):
        return _wrapLocalFunctionRaster(u"BooleanAnd_sa",
            ["BooleanAnd", in_raster_or_constant1, in_raster_or_constant2])
    return Wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)
BooleanAnd.__esri_toolname__ = "BooleanAnd_ia"
BooleanAnd.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def BooleanNot(
        in_raster_or_constant):
    """BooleanNot_ia(in_raster_or_constant)

    Performs a Boolean Not (complement) operation on the cell values of the input raster.

    Arguments:
    in_raster_or_constant -- The input to use in this Boolean operation.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"BooleanNot_sa",
            ["BooleanNot", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
BooleanNot.__esri_toolname__ = "BooleanNot_ia"
BooleanNot.__esri_toolinfo__ = [
    "::::1"
]


def BooleanOr(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """BooleanOr_ia(in_raster_or_constant1, in_raster_or_constant2)

    Performs a Boolean Or operation on the cell values of two input rasters.

    Arguments:
    in_raster_or_constant1 -- The first input to use in this Boolean operation.
    in_raster_or_constant2 -- The second input to use in this Boolean operation.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant1,
            in_raster_or_constant2):
        return _wrapLocalFunctionRaster(u"BooleanOr_sa",
            ["BooleanOr", in_raster_or_constant1, in_raster_or_constant2])
    return Wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)
BooleanOr.__esri_toolname__ = "BooleanOr_ia"
BooleanOr.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def BooleanXOr(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """BooleanXOr_ia(in_raster_or_constant1, in_raster_or_constant2)

    Performs a Boolean eXclusive Or operation on the cell values of two input rasters.

    Arguments:
    in_raster_or_constant1 -- The first input to use in this Boolean operation.
    in_raster_or_constant2 -- The second input to use in this Boolean operation.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant1,
            in_raster_or_constant2):
        return _wrapLocalFunctionRaster(u"BooleanXOr_sa",
            ["BooleanXOr", in_raster_or_constant1, in_raster_or_constant2])
    return Wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)
BooleanXOr.__esri_toolname__ = "BooleanXOr_ia"
BooleanXOr.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def CellStatistics(
        in_rasters_or_constants,
        statistics_type="#",
        ignore_nodata="#",
        process_as_multiband="#",
        percentile_value="#",
        percentile_interpolation_type="#"):
    """CellStatistics_ia([in_rasters_or_constant,...], {statistics_type}, {ignore_nodata}, {process_as_multiband}, {percentile_value}, {percentile_interpolation_type})

    Calculates a per-cell statistic from multiple rasters.

    Arguments:
    in_rasters_or_constant -- A list of input rasters for which a statistic will be calculated for each cell in the Analysis window.
    statistics_type -- Specifies the statistic type to be calculated.
    ignore_nodata -- Specifies whether NoData values will be ignored by the statistic calculation.
    process_as_multiband -- Specifies how the input multiband raster bands will be processed.
    percentile_value -- The percentile to calculate. The default is 90, indicating the 90th percentile.
    percentile_interpolation_type -- Specifies the method of interpolation to be used when the specified percentile value lies between two input cell values.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_rasters_or_constants,
            statistics_type,
            ignore_nodata,
            process_as_multiband,
            percentile_value,
            percentile_interpolation_type):
        statisticsTypes = {
            "MAJORITY": "Majority",
            "MAXIMUM": "Max",
            "MEAN": "Mean",
            "MEDIAN": "Med",
            "MINIMUM": "Min",
            "MINORITY": "Minority",
            "PERCENTILE": "Percentile",
            "RANGE": "Range",
            "STD": "Std",
            "SUM": "Sum",
            "VARIETY": "Variety"
        }
        interpolationTypes = {
            "AUTO_DETECT" : 1,
            "NEAREST" : 2,
            "LINEAR" : 3,
        }
        if Utils.useDefaultArgumentValue(statistics_type):
            statistics_type = "MEAN"
        if not statistics_type in statisticsTypes:
            raise arcpy.ExecuteError("ERROR 000864: Overlay statistic: The input is not within the defined domain.\nERROR 000800: The value is not a member of MEAN | MAJORITY | MAXIMUM | MEDIAN | MINIMUM | MINORITY | PERCENTILE | RANGE | STD | SUM | VARIETY.\n")
        function = statisticsTypes[statistics_type]
        if Utils.useDefaultArgumentValue(ignore_nodata):
            ignore_nodata = "DATA"
        if ignore_nodata not in ["DATA", "NODATA"]:
            raise arcpy.ExecuteError("ERROR 000622: Failed to execute (CellStatistics). Parameters are not valid.\nERROR 000621: Input to parameter ignore_nodata not within domain.\n")
        if Utils.useDefaultArgumentValue(process_as_multiband):
            process_as_multiband = "SINGLE_BAND"
        if process_as_multiband not in ["SINGLE_BAND", "MULTI_BAND"]:
            raise arcpy.ExecuteError("ERROR 000622: Failed to execute (CellStatistics). Parameters are not valid.\nERROR 000621: Input to parameter process_as_multiband not within domain.\n")
        if Utils.argumentValueEqualsString(ignore_nodata, "DATA"):
            function += "ContinueOnNoData"
        if Utils.useDefaultArgumentValue(percentile_value):
            percentile_value = 90.0
        if Utils.useDefaultArgumentValue(percentile_interpolation_type):
            percentile_interpolation_type = "AUTO_DETECT"
        if percentile_interpolation_type.upper() not in interpolationTypes:
            raise arcpy.ExecuteError("ERROR 000622: Failed to execute (CellStatistics). Parameters are not valid.\nERROR 000621: Input to parameter percentile_interpolation_type not within domain.\n")
        return _wrapLocalFunctionRaster(
            u"CellStatistics_sa",
            [function] + Utils.flattenLists(in_rasters_or_constants),
            {
                "flattenBands" : process_as_multiband.upper() == "SINGLE_BAND",
                "PercentileValue" : float(percentile_value),
                "PercentileInterpolationType" : int(interpolationTypes[percentile_interpolation_type]),
            })
    return Wrapper(
        in_rasters_or_constants,
        statistics_type,
        ignore_nodata,
        process_as_multiband,
        percentile_value,
        percentile_interpolation_type)
CellStatistics.__esri_toolname__ = "CellStatistics_ia"
CellStatistics.__esri_toolinfo__ = [
    "::::1",
    "::::3",
    "::::4",
    "::::5",
    "::::6",
    "::::7"
]


def ClassifyObjectsUsingDeepLearning(
        in_raster,
        out_feature_class,
        in_model_definition,
        in_features="#",
        class_label_field="#",
        processing_mode="#",
        model_arguments="#",
        caption_field="#"):
    """ClassifyObjectsUsingDeepLearning_ia(in_raster, out_feature_class, in_model_definition, {in_features}, {class_label_field}, {processing_mode}, {model_arguments}, {caption_field})

    Runs a trained deep learning model on an input raster and an optional feature class to produce a feature class or table in which each input object or feature has an assigned class or category label.

    Arguments:
    in_raster -- The input image that will be used to detect objects. The input can be a single raster or multiple rasters in a mosaic dataset, image service, or folder of images. A feature class with image attachments is also supported.
    out_feature_class -- The output feature class that will contain geometries surrounding the objects or feature from the input feature class, as well as a field to store the categorization label.
    in_model_definition -- The Esri model definition parameter value can be an Esri model definition JSON file (.emd), a JSON string, or a deep learning model package (.dlpk). A JSON string is useful when this tool is used on the server so you can paste the JSON string rather than upload the .emd file. The .dlpk file must be stored locally.
    in_features -- The point, line, or polygon input feature class that identifies the location of each object or feature to be classified and labelled. Each row in the input feature class represents a single object or feature.
    class_label_field -- The name of the field that will contain the class or category label in the output feature class.
    processing_mode -- Specifies how all raster items in a mosaic dataset or an image service will be processed. This parameter is applied when the input raster is a mosaic dataset or an image service.
    model_arguments -- The function arguments defined in the Python raster function class. This is where additional deep learning parameters and arguments for experiments and refinement are listed, such as a confidence threshold for adjusting the sensitivity. The names of the arguments are populated from the Python module.
    caption_field -- The name of the field that will contain the text or caption in the output feature class. This parameter is only supported when an Image Captioner model is used."""
    @Utils.StateSwapper(Utils.StateSwapper.NoSingleRasterResult)
    def Wrapper(
            in_raster,
            out_feature_class,
            in_model_definition,
            in_features,
            class_label_field,
            processing_mode,
            model_arguments,
            caption_field):
        result = arcpy.gp.ClassifyObjectsUsingDeepLearning_ia(
            in_raster,
            out_feature_class,
            in_model_definition,
            in_features,
            class_label_field,
            processing_mode,
            model_arguments,
            caption_field)
        return result
    return Wrapper(
        in_raster,
        out_feature_class,
        in_model_definition,
        in_features,
        class_label_field,
        processing_mode,
        model_arguments,
        caption_field)
ClassifyObjectsUsingDeepLearning.__esri_toolname__ = "ClassifyObjectsUsingDeepLearning_ia"
ClassifyObjectsUsingDeepLearning.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::3",
    "::::4",
    "::::5",
    "::::6",
    "::::7",
    "::::8"
]


def ClassifyPixelsUsingDeepLearning(
        in_raster,
        in_model_definition,
        arguments="#",
        processing_mode="#",
        out_classified_folder="#"):
    """ClassifyPixelsUsingDeepLearning_ia(in_raster, in_model_definition, {arguments}, {processing_mode}, {out_classified_folder})

    Runs a trained deep learning model on an input raster to produce a classified raster, with each valid pixel having an assigned class label.

    Arguments:
    in_raster -- The input raster dataset to classify. The input can be a single raster or multiple rasters in a mosaic dataset, an image service, or a folder of images.
    in_model_definition -- The Esri model definition parameter value can be an Esri model definition JSON file (.emd), a JSON string, or a deep learning model package (.dlpk). A JSON string is useful when this tool is used on the server so you can paste the JSON string rather than upload the .emd file. The .dlpk file must be stored locally.
    arguments -- The function arguments are defined in the Python raster function class. This is where you list additional deep learning parameters and arguments for experiments and refinement, such as a confidence threshold for adjusting sensitivity. The names of the arguments are populated from reading the Python module.
    processing_mode -- Specifies how all raster items in a mosaic dataset or an image service will be processed. This parameter is applied when the input raster is a mosaic dataset or an image service.
    out_classified_folder -- The folder where the output classified rasters will be stored. A mosaic dataset will be generated using the classified rasters in this folder.

    Results:
    out_classified_raster -- Output Classified Raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster,
            in_model_definition,
            arguments,
            processing_mode,
            out_classified_folder):
        out_classified_raster = "#"
        result = arcpy.gp.ClassifyPixelsUsingDeepLearning_ia(
            in_raster,
            out_classified_raster,
            in_model_definition,
            arguments,
            processing_mode,
            out_classified_folder)
        return _wrapToolRaster(u"ClassifyPixelsUsingDeepLearning_sa", unicode(result.getOutput(0)))
    return Wrapper(
        in_raster,
        in_model_definition,
        arguments,
        processing_mode,
        out_classified_folder)
ClassifyPixelsUsingDeepLearning.__esri_toolname__ = "ClassifyPixelsUsingDeepLearning_ia"
ClassifyPixelsUsingDeepLearning.__esri_toolinfo__ = [
    "::::1",
    "::::3",
    "::::4",
    "::::5",
    "::::6"
]


def ClassifyRaster(
        in_raster,
        in_classifier_definition,
        in_additional_raster="#"):
    """ClassifyRaster_ia(in_raster, in_classifier_definition, {in_additional_raster})

    Classifies a raster dataset based on an Esri classifier definition file (.ecd) and raster dataset inputs.

    Arguments:
    in_raster -- The raster dataset to classify.
    in_classifier_definition -- The input Esri classifier definition file (.ecd) containing the statistics for the chosen attributes for the classifier.
    in_additional_raster -- Ancillary raster datasets, such as a multispectral image or a DEM, will be incorporated to generate attributes and other required information for the classifier. This raster is necessary when calculating attributes such as mean or standard deviation. This parameter is optional.

    Results:
    out_raster_dataset -- Output Classified Raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster,
            in_classifier_definition,
            in_additional_raster):
        out_raster_dataset = "#"
        result = arcpy.gp.ClassifyRaster_ia(
            in_raster,
            in_classifier_definition,
            out_raster_dataset,
            in_additional_raster)
        return _wrapToolRaster(u"ClassifyRaster_sa", unicode(result.getOutput(0)))
    return Wrapper(
        in_raster,
        in_classifier_definition,
        in_additional_raster)
ClassifyRaster.__esri_toolname__ = "ClassifyRaster_ia"
ClassifyRaster.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::4"
]


def CombinatorialAnd(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """CombinatorialAnd_ia(in_raster_or_constant1, in_raster_or_constant2)

    Performs a Combinatorial And operation on the cell values of two input rasters.

    Arguments:
    in_raster_or_constant1 -- The first input to use in this combinatorial operation.
    in_raster_or_constant2 -- The second input to use in this combinatorial operation.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant1,
            in_raster_or_constant2):
        out_raster = "#"
        result = arcpy.gp.CombinatorialAnd_ia(
            in_raster_or_constant1,
            in_raster_or_constant2,
            out_raster)
        return _wrapToolRaster(u"CombinatorialAnd_sa", unicode(result.getOutput(0)))
    return Wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)
CombinatorialAnd.__esri_toolname__ = "CombinatorialAnd_ia"
CombinatorialAnd.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def CombinatorialOr(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """CombinatorialOr_ia(in_raster_or_constant1, in_raster_or_constant2)

    Performs a Combinatorial Or operation on the cell values of two input rasters.

    Arguments:
    in_raster_or_constant1 -- The first input to use in this combinatorial operation.
    in_raster_or_constant2 -- The second input to use in this combinatorial operation.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant1,
            in_raster_or_constant2):
        out_raster = "#"
        result = arcpy.gp.CombinatorialOr_ia(
            in_raster_or_constant1,
            in_raster_or_constant2,
            out_raster)
        return _wrapToolRaster(u"CombinatorialOr_sa", unicode(result.getOutput(0)))
    return Wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)
CombinatorialOr.__esri_toolname__ = "CombinatorialOr_ia"
CombinatorialOr.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def CombinatorialXOr(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """CombinatorialXOr_ia(in_raster_or_constant1, in_raster_or_constant2)

    Performs a Combinatorial eXclusive Or operation on the cell values of two input rasters.

    Arguments:
    in_raster_or_constant1 -- The first input to use in this combinatorial operation.
    in_raster_or_constant2 -- The second input to use in this combinatorial operation.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant1,
            in_raster_or_constant2):
        out_raster = "#"
        result = arcpy.gp.CombinatorialXOr_ia(
            in_raster_or_constant1,
            in_raster_or_constant2,
            out_raster)
        return _wrapToolRaster(u"CombinatorialXOr_sa", unicode(result.getOutput(0)))
    return Wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)
CombinatorialXOr.__esri_toolname__ = "CombinatorialXOr_ia"
CombinatorialXOr.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def ComputeAccuracyForObjectDetection(
        detected_features,
        ground_truth_features,
        out_accuracy_table,
        out_accuracy_report="#",
        detected_class_value_field="#",
        ground_truth_class_value_field="#",
        min_iou="#",
        mask_features="#"):
    """ComputeAccuracyForObjectDetection_ia(detected_features, ground_truth_features, out_accuracy_table, {out_accuracy_report}, {detected_class_value_field}, {ground_truth_class_value_field}, {min_iou}, {mask_features})

    Calculates the accuracy of a deep learning model by comparing the detected objects from the Detect Objects Using Deep Learning tool to ground truth data.

    Arguments:
    detected_features -- The polygon feature class containing the objects detected from the Detect Objects Using Deep Learning tool.
    ground_truth_features -- The polygon feature class containing ground truth data.
    out_accuracy_table -- The output accuracy table.
    out_accuracy_report -- The name of the output accuracy report. The report is a PDF document containing accuracy metrics and charts.
    detected_class_value_field -- The field in the detected objects feature class that contains the class values or class names.
    ground_truth_class_value_field -- The field in the ground truth feature class that contains the class values.
    min_iou -- The IoU ratio to use as a threshold to evaluate the accuracy of the object-detection model. The numerator is the area of overlap between the predicted bounding box and the ground reference bounding box. The denominator is the area of union or the area encompassed by both bounding boxes. The IoU ranges from 0 to 1.
    mask_features -- A polygon feature class that delineates the area or areas where accuracy will be computed. Only the features that intersect the mask will be assessed for accuracy."""
    @Utils.StateSwapper(Utils.StateSwapper.NoSingleRasterResult)
    def Wrapper(
            detected_features,
            ground_truth_features,
            out_accuracy_table,
            out_accuracy_report,
            detected_class_value_field,
            ground_truth_class_value_field,
            min_iou,
            mask_features):
        result = arcpy.gp.ComputeAccuracyForObjectDetection_ia(
            detected_features,
            ground_truth_features,
            out_accuracy_table,
            out_accuracy_report,
            detected_class_value_field,
            ground_truth_class_value_field,
            min_iou,
            mask_features)
        return result
    return Wrapper(
        detected_features,
        ground_truth_features,
        out_accuracy_table,
        out_accuracy_report,
        detected_class_value_field,
        ground_truth_class_value_field,
        min_iou,
        mask_features)
ComputeAccuracyForObjectDetection.__esri_toolname__ = "ComputeAccuracyForObjectDetection_ia"
ComputeAccuracyForObjectDetection.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::3",
    "::::4",
    "::::5",
    "::::6",
    "::::7",
    "::::8"
]


def ComputeChangeRaster(
        from_raster,
        to_raster,
        compute_change_method="#",
        from_classes="#",
        to_classes="#",
        filter_method="#",
        define_transition_colors="#",
        from_classname_field="#",
        to_classname_field="#"):
    """ComputeChangeRaster_ia(from_raster, to_raster, {compute_change_method}, {[from_classe,...]}, {[to_classe,...]}, {filter_method}, {define_transition_colors}, {from_classname_field}, {to_classname_field})

    Calculates the absolute, relative, or categorical difference between two raster datasets.

    Arguments:
    from_raster -- The initial or earlier raster to be analyzed.
    to_raster -- The final or later raster to be analyzed. This is the raster that will be compared to the initial raster.
    compute_change_method -- Specifies the type of calculation that will be performed between the two rasters.
    from_classe -- The list of class names from the From Raster parameter that will be included in the computation. If no classes are provided, all classes will be included.
    to_classe -- The list of class names from the To Raster parameter that will be included in the computation. If no classes are provided, all classes will be included.
    filter_method -- Specifies the pixels that will be categorized in the output raster. This parameter is active when the Compute Change Method parameter is set to Categorical difference.
    define_transition_colors -- Specifies the color that will be used to symbolize the output classes. When a pixel changes from one class type to another, the output pixel color represents the initial class type, the final class type, or a blend of the two.
    from_classname_field -- The field that will store class names in the From Raster parameter value. The tool automatically searches for the ClassName field or Class_Name field to use.
    to_classname_field -- The field that will store class names in the To Raster parameter value. The tool will automatically search for the ClassName field or Class_Name field to use.

    Results:
    out_raster_dataset -- Output Raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            from_raster,
            to_raster,
            compute_change_method,
            from_classes,
            to_classes,
            filter_method,
            define_transition_colors,
            from_classname_field,
            to_classname_field):
        out_raster_dataset = "#"
        result = arcpy.gp.ComputeChangeRaster_ia(
            from_raster,
            to_raster,
            out_raster_dataset,
            compute_change_method,
            from_classes,
            to_classes,
            filter_method,
            define_transition_colors,
            from_classname_field,
            to_classname_field)
        return _wrapToolRaster(u"ComputeChangeRaster_sa", unicode(result.getOutput(0)))
    return Wrapper(
        from_raster,
        to_raster,
        compute_change_method,
        from_classes,
        to_classes,
        filter_method,
        define_transition_colors,
        from_classname_field,
        to_classname_field)
ComputeChangeRaster.__esri_toolname__ = "ComputeChangeRaster_ia"
ComputeChangeRaster.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::4",
    "::::5",
    "::::6",
    "::::7",
    "::::8",
    "::::9",
    "::::10"
]


def ComputeConfusionMatrix(
        in_accuracy_assessment_points,
        out_confusion_matrix):
    """ComputeConfusionMatrix_ia(in_accuracy_assessment_points, out_confusion_matrix)

    Computes a confusion matrix with errors of omission and commission and derives a kappa index of agreement and an overall accuracy between the classified map and the reference data.

    Arguments:
    in_accuracy_assessment_points -- The accuracy assessment point feature class, created from the Create Accuracy Assessment Points tool, containing the CLASSIFIED and GROUND_TRUTH fields.
    out_confusion_matrix -- The output file name of the confusion matrix in table format."""
    @Utils.StateSwapper(Utils.StateSwapper.NoSingleRasterResult)
    def Wrapper(
            in_accuracy_assessment_points,
            out_confusion_matrix):
        result = arcpy.gp.ComputeConfusionMatrix_ia(
            in_accuracy_assessment_points,
            out_confusion_matrix)
        return result
    return Wrapper(
        in_accuracy_assessment_points,
        out_confusion_matrix)
ComputeConfusionMatrix.__esri_toolname__ = "ComputeConfusionMatrix_ia"
ComputeConfusionMatrix.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def ComputeSegmentAttributes(
        in_segmented_raster,
        in_additional_raster="#",
        used_attributes="#"):
    """ComputeSegmentAttributes_ia(in_segmented_raster, {in_additional_raster}, {[used_attribute,...]})

    Computes a set of attributes associated with the segmented image. The input raster can be a single-band or 3-band, 8-bit segmented image.

    Arguments:
    in_segmented_raster -- The input segmented raster dataset, where all the pixels belonging to a segment have the same converged RGB color. Usually, it is an 8-bit, 3-band RGB raster, but it can also be a 1-band grayscale raster.
    in_additional_raster -- Ancillary raster datasets, such as a multispectral image or a DEM, will be incorporated to generate attributes and other required information for the classifier. This raster is necessary when calculating attributes such as mean or standard deviation. This parameter is optional.
    used_attribute -- Specifies the attributes that will be included in the attribute table associated with the output raster.

    Results:
    out_index_raster_dataset -- Output Segment Index Raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_segmented_raster,
            in_additional_raster,
            used_attributes):
        out_index_raster_dataset = "#"
        result = arcpy.gp.ComputeSegmentAttributes_ia(
            in_segmented_raster,
            out_index_raster_dataset,
            in_additional_raster,
            used_attributes)
        return _wrapToolRaster(u"ComputeSegmentAttributes_sa", unicode(result.getOutput(0)))
    return Wrapper(
        in_segmented_raster,
        in_additional_raster,
        used_attributes)
ComputeSegmentAttributes.__esri_toolname__ = "ComputeSegmentAttributes_ia"
ComputeSegmentAttributes.__esri_toolinfo__ = [
    "::::1",
    "::::3",
    "::::4"
]


def Con(
        in_conditional_raster,
        in_true_raster_or_constant,
        in_false_raster_or_constant="#",
        where_clause="#"):
    """Con_ia(in_conditional_raster, in_true_raster_or_constant, {in_false_raster_or_constant}, {where_clause})

    Performs a conditional if/else evaluation on each of the input cells of an input raster.

    Arguments:
    in_conditional_raster -- Input raster representing the true or false result of the desired condition.
    in_true_raster_or_constant -- The input whose values will be used as the output cell values if the condition is true.
    in_false_raster_or_constant -- The input whose values will be used as the output cell values if the condition is false.
    where_clause -- A logical expression that determines which of the input cells are to be true or false.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_conditional_raster,
            in_true_raster_or_constant,
            in_false_raster_or_constant,
            where_clause):
        if Utils.useDefaultArgumentValue(where_clause):
            if Utils.useDefaultArgumentValue(in_false_raster_or_constant):
                return _wrapLocalFunctionRaster(u"Con_sa",
                    ["IfThen", in_conditional_raster, in_true_raster_or_constant])
            else:
                return _wrapLocalFunctionRaster(u"Con_sa",
                    ["IfThenElse", in_conditional_raster, in_true_raster_or_constant, in_false_raster_or_constant])
        out_raster = "#"
        result = arcpy.gp.Con_ia(
            in_conditional_raster,
            in_true_raster_or_constant,
            out_raster,
            in_false_raster_or_constant,
            where_clause)
        return _wrapToolRaster(u"Con_sa", unicode(result.getOutput(0)))
    return Wrapper(
        in_conditional_raster,
        in_true_raster_or_constant,
        in_false_raster_or_constant,
        where_clause)
Con.__esri_toolname__ = "Con_ia"
Con.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::4",
    "::::5"
]


def Cos(
        in_raster_or_constant):
    """Cos_ia(in_raster_or_constant)

    Calculates the cosine of cells in a raster.

    Arguments:
    in_raster_or_constant -- The input for which to calculate the cosine values.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"Cos_sa",
            ["Cos", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
Cos.__esri_toolname__ = "Cos_ia"
Cos.__esri_toolinfo__ = [
    "::::1"
]


def CosH(
        in_raster_or_constant):
    """CosH_ia(in_raster_or_constant)

    Calculates the hyperbolic cosine of cells in a raster.

    Arguments:
    in_raster_or_constant -- The input for which to calculate the hyperbolic cosine values.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"CosH_sa",
            ["CosH", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
CosH.__esri_toolname__ = "CosH_ia"
CosH.__esri_toolinfo__ = [
    "::::1"
]


def CreateAccuracyAssessmentPoints(
        in_class_data,
        out_points,
        target_field="#",
        num_random_points="#",
        sampling="#",
        polygon_dimension_field="#"):
    """CreateAccuracyAssessmentPoints_ia(in_class_data, out_points, {target_field}, {num_random_points}, {sampling}, {polygon_dimension_field})

    Creates randomly sampled points for post-classification accuracy assessment.

    Arguments:
    in_class_data -- The input classification image or other thematic GIS reference data. The input can be a raster or feature class.
    out_points -- The output point shapefile or feature class that contains the random points to be used for accuracy assessment.
    target_field -- Specifies whether the input data is a classified image or ground truth data.
    num_random_points -- The total number of random points that will be generated.
    sampling -- Specifies the sampling scheme that will be used.
    polygon_dimension_field -- A field that defines the dimension (time) of the features. This parameter is used only if the classification result is multidimensional raster and you want to generate assessment points from a feature class, such as land classification polygons for multiple years."""
    @Utils.StateSwapper(Utils.StateSwapper.NoSingleRasterResult)
    def Wrapper(
            in_class_data,
            out_points,
            target_field,
            num_random_points,
            sampling,
            polygon_dimension_field):
        result = arcpy.gp.CreateAccuracyAssessmentPoints_ia(
            in_class_data,
            out_points,
            target_field,
            num_random_points,
            sampling,
            polygon_dimension_field)
        return result
    return Wrapper(
        in_class_data,
        out_points,
        target_field,
        num_random_points,
        sampling,
        polygon_dimension_field)
CreateAccuracyAssessmentPoints.__esri_toolname__ = "CreateAccuracyAssessmentPoints_ia"
CreateAccuracyAssessmentPoints.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::3",
    "::::4",
    "::::5",
    "::::6"
]


def DeepLearningModelToEcd(
        in_deep_learning_model,
        in_classification_info_json,
        out_classifier_definition):
    """DeepLearningModelToEcd_ia(in_deep_learning_model, in_classification_info_json, out_classifier_definition)

    Converts a deep learning model to an Esri classifier definition file (.ecd).

    Arguments:
    in_deep_learning_model -- The binary model file generated by a deep learning package such as Google TensorFlow, Microsoft CNTK, or similar application.
    in_classification_info_json -- The class information JSON file. See the JSON file example above.
    out_classifier_definition -- The .ecd file that can be used in the Classify function and Classify Raster tool."""
    @Utils.StateSwapper(Utils.StateSwapper.NoSingleRasterResult)
    def Wrapper(
            in_deep_learning_model,
            in_classification_info_json,
            out_classifier_definition):
        result = arcpy.gp.DeepLearningModelToEcd_ia(
            in_deep_learning_model,
            in_classification_info_json,
            out_classifier_definition)
        return result
    return Wrapper(
        in_deep_learning_model,
        in_classification_info_json,
        out_classifier_definition)
DeepLearningModelToEcd.__esri_toolname__ = "DeepLearningModelToEcd_ia"
DeepLearningModelToEcd.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::3"
]


def DetectChangeUsingChangeAnalysisRaster(
        in_change_analysis_raster,
        change_type,
        max_number_changes="#",
        segment_date="#",
        change_direction="#",
        filter_by_year="#",
        min_year="#",
        max_year="#",
        filter_by_duration="#",
        min_duration="#",
        max_duration="#",
        filter_by_magnitude="#",
        min_magnitude="#",
        max_magnitude="#",
        filter_by_start_value="#",
        min_start_value="#",
        max_start_value="#",
        filter_by_end_value="#",
        min_end_value="#",
        max_end_value="#"):
    """DetectChangeUsingChangeAnalysisRaster_ia(in_change_analysis_raster, change_type, {max_number_changes}, {segment_date}, {change_direction}, {filter_by_year}, {min_year}, {max_year}, {filter_by_duration}, {min_duration}, {max_duration}, {filter_by_magnitude}, {min_magnitude}, {max_magnitude}, {filter_by_start_value}, {min_start_value}, {max_start_value}, {filter_by_end_value}, {min_end_value}, {max_end_value})

    Generates a raster containing pixel change information using the output change analysis raster from the Analyze Changes Using CCDC tool or the Analyze Changes Using LandTrendr tool.

    Arguments:
    in_change_analysis_raster -- The change analysis raster generated from the Analyze Changes Using CCDC tool or the Analyze Changes Using LandTrendr tool.
    change_type -- Specifies the change information that will be calculated for each pixel.
    max_number_changes -- The maximum number of changes per pixel that will be calculated. This number corresponds to the number of bands in the output raster. The default is 1, meaning only one change date will be calculated, and the output raster will contain only one band.
    segment_date -- Specifies whether the date at the beginning of a change segment will be extracted or at the end.
    change_direction -- Specifies the direction of change that will be included in the analysis.
    filter_by_year -- Specifies whether the output will be filtered by a range of years.
    min_year -- The earliest year that will be used to filter results. This parameter is required if the Filter by Year parameter is checked.
    max_year -- The latest year that will be used to filter results.
    filter_by_duration -- Specifies whether results will be filtered by the change duration.
    min_duration -- The minimum number of consecutive years that will be included in the results.
    max_duration -- The maximum number of consecutive years that will be included in the results.
    filter_by_magnitude -- Specifies whether results will be filtered by change magnitude.
    min_magnitude -- The minimum magnitude that will be included in the results.
    max_magnitude -- The maximum magnitude that will be included in the results.
    filter_by_start_value -- Specifies whether results will be filtered by start value.
    min_start_value -- The minimum start value that will be included in the results.
    max_start_value -- The maximum start value that will be included in the results.
    filter_by_end_value -- Specifies whether results will be filtered by end value.
    min_end_value -- The minimum end value that will be included in the results.
    max_end_value -- The maximum end value that will be included in the results.

    Results:
    out_raster -- Output Raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_change_analysis_raster,
            change_type,
            max_number_changes,
            segment_date,
            change_direction,
            filter_by_year,
            min_year,
            max_year,
            filter_by_duration,
            min_duration,
            max_duration,
            filter_by_magnitude,
            min_magnitude,
            max_magnitude,
            filter_by_start_value,
            min_start_value,
            max_start_value,
            filter_by_end_value,
            min_end_value,
            max_end_value):
        out_raster = "#"
        result = arcpy.gp.DetectChangeUsingChangeAnalysisRaster_ia(
            in_change_analysis_raster,
            out_raster,
            change_type,
            max_number_changes,
            segment_date,
            change_direction,
            filter_by_year,
            min_year,
            max_year,
            filter_by_duration,
            min_duration,
            max_duration,
            filter_by_magnitude,
            min_magnitude,
            max_magnitude,
            filter_by_start_value,
            min_start_value,
            max_start_value,
            filter_by_end_value,
            min_end_value,
            max_end_value)
        return _wrapToolRaster(u"DetectChangeUsingChangeAnalysisRaster_sa", unicode(result.getOutput(0)))
    return Wrapper(
        in_change_analysis_raster,
        change_type,
        max_number_changes,
        segment_date,
        change_direction,
        filter_by_year,
        min_year,
        max_year,
        filter_by_duration,
        min_duration,
        max_duration,
        filter_by_magnitude,
        min_magnitude,
        max_magnitude,
        filter_by_start_value,
        min_start_value,
        max_start_value,
        filter_by_end_value,
        min_end_value,
        max_end_value)
DetectChangeUsingChangeAnalysisRaster.__esri_toolname__ = "DetectChangeUsingChangeAnalysisRaster_ia"
DetectChangeUsingChangeAnalysisRaster.__esri_toolinfo__ = [
    "::::1",
    "::::3",
    "::::4",
    "::::5",
    "::::6",
    "::::7",
    "::::8",
    "::::9",
    "::::10",
    "::::11",
    "::::12",
    "::::13",
    "::::14",
    "::::15",
    "::::16",
    "::::17",
    "::::18",
    "::::19",
    "::::20",
    "::::21"
]


def DetectChangeUsingDeepLearning(
        from_raster,
        to_raster,
        in_model_definition,
        arguments="#"):
    """DetectChangeUsingDeepLearning_ia(from_raster, to_raster, in_model_definition, {arguments})

    Runs a trained deep learning model to detect change between two rasters.

    Arguments:
    from_raster -- The input images of the previous raster.
    to_raster -- The input images of the recent raster.
    in_model_definition -- The Esri model definition parameter value can be an Esri model definition JSON file (.emd), a JSON string, or a deep learning model package (.dlpk). A JSON string is useful when this tool is used on the server so you can paste the JSON string rather than upload the .emd file. The .dlpk file must be stored locally.
    arguments -- The function arguments are defined in the Python raster function class. This is where you list additional deep learning parameters and arguments for experiments and refinement, such as a confidence threshold for adjusting sensitivity. The names of the arguments are populated from reading the Python module.

    Results:
    out_classified_raster -- Output Classified Raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            from_raster,
            to_raster,
            in_model_definition,
            arguments):
        out_classified_raster = "#"
        result = arcpy.gp.DetectChangeUsingDeepLearning_ia(
            from_raster,
            to_raster,
            out_classified_raster,
            in_model_definition,
            arguments)
        return _wrapToolRaster(u"DetectChangeUsingDeepLearning_sa", unicode(result.getOutput(0)))
    return Wrapper(
        from_raster,
        to_raster,
        in_model_definition,
        arguments)
DetectChangeUsingDeepLearning.__esri_toolname__ = "DetectChangeUsingDeepLearning_ia"
DetectChangeUsingDeepLearning.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::4",
    "::::5"
]


def DetectObjectsUsingDeepLearning(
        in_raster,
        out_detected_objects,
        in_model_definition,
        arguments="#",
        run_nms="#",
        confidence_score_field="#",
        class_value_field="#",
        max_overlap_ratio="#",
        processing_mode="#"):
    """DetectObjectsUsingDeepLearning_ia(in_raster, out_detected_objects, in_model_definition, {arguments}, {run_nms}, {confidence_score_field}, {class_value_field}, {max_overlap_ratio}, {processing_mode})

    Runs a trained deep learning model on an input raster to produce a feature class containing the objects it finds. The features can be bounding boxes or polygons around the objects found or points at the centers of the objects.

    Arguments:
    in_raster -- The input image used to detect objects. The input can be a single raster or multiple rasters in a mosaic dataset, image service, or folder of images. A feature class with image attachments is also supported.
    out_detected_objects -- The output feature class that will contain geometries circling the object or objects detected in the input image.
    in_model_definition -- This parameter can be an Esri model definition JSON file (.emd), a JSON string, or a deep learning model package (.dlpk). A JSON string is useful when this tool is used on the server so you can paste the JSON string rather than upload the .emd file. The .dlpk file must be stored locally.
    arguments -- The function arguments defined in the Python raster function class. This is where additional deep learning parameters and arguments for experiments and refinement are listed, such as a confidence threshold for adjusting the sensitivity. The names of the arguments are populated from the Python module.
    run_nms -- Specifies whether nonmaximum suppression will be performed in which duplicate objects are identified and the duplicate features with lower confidence value are removed.
    confidence_score_field -- The name of the field in the feature class that will contain the confidence scores as output by the object detection method.
    class_value_field -- The name of the class value field in the input feature class.
    max_overlap_ratio -- The maximum overlap ratio for two overlapping features, which is defined as the ratio of intersection area over union area. The default is 0.
    processing_mode -- Specifies how all raster items in a mosaic dataset or an image service will be processed. This parameter is applied when the input raster is a mosaic dataset or an image service."""
    @Utils.StateSwapper(Utils.StateSwapper.NoSingleRasterResult)
    def Wrapper(
            in_raster,
            out_detected_objects,
            in_model_definition,
            arguments,
            run_nms,
            confidence_score_field,
            class_value_field,
            max_overlap_ratio,
            processing_mode):
        result = arcpy.gp.DetectObjectsUsingDeepLearning_ia(
            in_raster,
            out_detected_objects,
            in_model_definition,
            arguments,
            run_nms,
            confidence_score_field,
            class_value_field,
            max_overlap_ratio,
            processing_mode)
        return result
    return Wrapper(
        in_raster,
        out_detected_objects,
        in_model_definition,
        arguments,
        run_nms,
        confidence_score_field,
        class_value_field,
        max_overlap_ratio,
        processing_mode)
DetectObjectsUsingDeepLearning.__esri_toolname__ = "DetectObjectsUsingDeepLearning_ia"
DetectObjectsUsingDeepLearning.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::3",
    "::::4",
    "::::5",
    "::::6",
    "::::7",
    "::::8",
    "::::9"
]


def Diff(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """Diff_ia(in_raster_or_constant1, in_raster_or_constant2)

    Determines which values from the first input are logically different from the values of the second input on a cell-by-cell basis.

    Arguments:
    in_raster_or_constant1 -- The input to which the second input will be compared.
    in_raster_or_constant2 -- The input to which the first input will be compared.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant1,
            in_raster_or_constant2):
        return _wrapLocalFunctionRaster(u"Diff_sa",
            ["Diff", in_raster_or_constant1, in_raster_or_constant2])
    return Wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)
Diff.__esri_toolname__ = "Diff_ia"
Diff.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def DimensionalMovingStatistics(
        in_raster,
        dimension="#",
        backward_window="#",
        forward_window="#",
        nodata_handling="#",
        statistics_type="#",
        percentile_value="#",
        percentile_interpolation_type="#",
        circular_wrap_value="#"):
    """DimensionalMovingStatistics_ia(in_raster, {dimension}, {backward_window}, {forward_window}, {nodata_handling}, {statistics_type}, {percentile_value}, {percentile_interpolation_type}, {circular_wrap_value})

    Calculates statistics over a moving window on multidimensional data along a specified dimension.

    Arguments:
    in_raster -- The input raster can only be a multidimensional raster in Cloud Raster Format (.crf file).
    dimension -- The name of the dimension along which the window will move.
    backward_window -- The value of how many slices before or above to be included in the defined window. The value must be a positive integer from 1 to 100. The default value is 1.
    forward_window -- The value of how many slices after or below to be included in the defined window. The value must be a positive integer from 1 to 100. The default value is 1.
    nodata_handling -- Specifies how NoData values will be handled by the statistic calculation.
    statistics_type -- Specifies the statistic type to be calculated.
    percentile_value -- The percentile value that will be calculated. The default is 90, for the 90th percentile.
    percentile_interpolation_type -- Specifies the method of interpolation that will be used when the percentile value falls between two cell values.
    circular_wrap_value -- The value that will be used to round a linear value to the range of a given circular mean. Its value must be positive. The default value is 360 degrees.

    Results:
    out_raster -- Output Multidimensional Raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster,
            dimension,
            backward_window,
            forward_window,
            nodata_handling,
            statistics_type,
            percentile_value,
            percentile_interpolation_type,
            circular_wrap_value):
        out_raster = Utils.UNEVALUATED_RASTER_FUNCTION_SIGNAL
        result = arcpy.gp.DimensionalMovingStatistics_ia(
            in_raster,
            out_raster,
            dimension,
            backward_window,
            forward_window,
            nodata_handling,
            statistics_type,
            percentile_value,
            percentile_interpolation_type,
            circular_wrap_value)
        import json
        rfx_args = json.loads(result.getOutput(1))
        in_raster = arcpy.Raster(in_raster)
        in_raster = ApplyEnvironment(in_raster)
        out_raster_afr = arcpy.ia.Apply(in_raster, "DimensionalMovingStatistics", rfx_args)
        out_raster_afr = ApplyEnvironment(out_raster_afr)
        # Return an unevaluated raster function chain
        return out_raster_afr
    return Wrapper(
        in_raster,
        dimension,
        backward_window,
        forward_window,
        nodata_handling,
        statistics_type,
        percentile_value,
        percentile_interpolation_type,
        circular_wrap_value)
DimensionalMovingStatistics.__esri_toolname__ = "DimensionalMovingStatistics_ia"
DimensionalMovingStatistics.__esri_toolinfo__ = [
    "::::1",
    "::::3",
    "::::4",
    "::::5",
    "::::6",
    "::::7",
    "::::8",
    "::::9",
    "::::10"
]


def Divide(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """Divide_ia(in_raster_or_constant1, in_raster_or_constant2)

    Divides the values of two rasters on a cell-by-cell basis.

    Arguments:
    in_raster_or_constant1 -- The input whose values will be divided by the second input.
    in_raster_or_constant2 -- The input whose values the first input are to be divided by.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant1,
            in_raster_or_constant2):
        return _wrapLocalFunctionRaster(u"Divide_sa",
            ["Divide", in_raster_or_constant1, in_raster_or_constant2])
    return Wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)
Divide.__esri_toolname__ = "Divide_ia"
Divide.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def EqualTo(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """EqualTo_ia(in_raster_or_constant1, in_raster_or_constant2)

    Performs a Relational equal-to operation on two inputs on a cell-by-cell basis.

    Arguments:
    in_raster_or_constant1 -- The input that will be compared to for equality by the second input.
    in_raster_or_constant2 -- The input that will be compared from for equality by the first input.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant1,
            in_raster_or_constant2):
        return _wrapLocalFunctionRaster(u"EqualTo_sa",
            ["EqualTo", in_raster_or_constant1, in_raster_or_constant2])
    return Wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)
EqualTo.__esri_toolname__ = "EqualTo_ia"
EqualTo.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def Exp(
        in_raster_or_constant):
    """Exp_ia(in_raster_or_constant)

    Calculates the base e exponential of the cells in a raster.

    Arguments:
    in_raster_or_constant -- The input values for which to find the base e exponential.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"Exp_sa",
            ["Exp", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
Exp.__esri_toolname__ = "Exp_ia"
Exp.__esri_toolinfo__ = [
    "::::1"
]


def Exp10(
        in_raster_or_constant):
    """Exp10_ia(in_raster_or_constant)

    Calculates the base 10 exponential of the cells in a raster.

    Arguments:
    in_raster_or_constant -- The input values for which to find the base 10 exponential.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"Exp10_sa",
            ["Exp10", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
Exp10.__esri_toolname__ = "Exp10_ia"
Exp10.__esri_toolinfo__ = [
    "::::1"
]


def Exp2(
        in_raster_or_constant):
    """Exp2_ia(in_raster_or_constant)

    Calculates the base 2 exponential of the cells in a raster.

    Arguments:
    in_raster_or_constant -- The input values for which to find the base 2 exponential.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"Exp2_sa",
            ["Exp2", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
Exp2.__esri_toolname__ = "Exp2_ia"
Exp2.__esri_toolinfo__ = [
    "::::1"
]


def ExportTrainingDataForDeepLearning(
        in_raster,
        out_folder,
        in_class_data="#",
        image_chip_format="#",
        tile_size_x="#",
        tile_size_y="#",
        stride_x="#",
        stride_y="#",
        output_nofeature_tiles="#",
        metadata_format="#",
        start_index="#",
        class_value_field="#",
        buffer_radius="#",
        in_mask_polygons="#",
        rotation_angle="#",
        reference_system="#",
        processing_mode="#",
        blacken_around_feature="#",
        crop_mode="#",
        in_raster2="#"):
    """ExportTrainingDataForDeepLearning_ia(in_raster, out_folder, {in_class_data}, {image_chip_format}, {tile_size_x}, {tile_size_y}, {stride_x}, {stride_y}, {output_nofeature_tiles}, {metadata_format}, {start_index}, {class_value_field}, {buffer_radius}, {in_mask_polygons}, {rotation_angle}, {reference_system}, {processing_mode}, {blacken_around_feature}, {crop_mode}, {in_raster2})

    Converts labeled vector or raster data into deep learning training datasets using a remote sensing image. The output will be a folder of image chips and a folder of metadata files in the specified format.

    Arguments:
    in_raster -- The input source imagery, typically multispectral imagery.
    out_folder -- The folder where the output image chips and metadata will be stored.
    in_class_data -- The training sample data in either vector or raster form.
    image_chip_format -- Specifies the raster format that will be used for the image chip outputs.
    tile_size_x -- The size of the image chips for the x dimension.
    tile_size_y -- The size of the image chips for the y dimension.
    stride_x -- The distance to move in the x direction when creating the next image chips.
    stride_y -- The distance to move in the y direction when creating the next image chips.
    output_nofeature_tiles -- Specifies whether image chips that do not capture training samples will be exported.
    metadata_format -- Specifies the format that will be used for the output metadata labels.
    start_index -- This parameter has been deprecated.
    class_value_field -- The field that contains the class values. If no field is specified, the system searches for a value or classvalue field. If the feature does not contain a class field, the system determines that all records belong to one class.
    buffer_radius -- The radius of a buffer around each training sample that will be used to delineate a training sample area. This allows you to create circular polygon training samples from points.
    in_mask_polygons -- A polygon feature class that delineates the area where image chips will be created.
    rotation_angle -- The rotation angle that will be used to generate additional image chips.
    reference_system -- Specifies the type of reference system that will be used to interpret the input image. The reference system specified must match the reference system used to train the deep learning model.
    processing_mode -- Specifies how all raster items in a mosaic dataset or an image service will be processed. This parameter is applied when the input raster is a mosaic dataset or an image service.
    blacken_around_feature -- Specifies whether the pixels around each object or feature in each image tile will be masked out.
    crop_mode -- Specifies whether the exported tiles will be cropped so that they are all the same size.
    in_raster2 -- An additional input imagery source that will be used for image translation methods."""
    @Utils.StateSwapper(Utils.StateSwapper.NoSingleRasterResult)
    def Wrapper(
            in_raster,
            out_folder,
            in_class_data,
            image_chip_format,
            tile_size_x,
            tile_size_y,
            stride_x,
            stride_y,
            output_nofeature_tiles,
            metadata_format,
            start_index,
            class_value_field,
            buffer_radius,
            in_mask_polygons,
            rotation_angle,
            reference_system,
            processing_mode,
            blacken_around_feature,
            crop_mode,
            in_raster2):
        result = arcpy.gp.ExportTrainingDataForDeepLearning_ia(
            in_raster,
            out_folder,
            in_class_data,
            image_chip_format,
            tile_size_x,
            tile_size_y,
            stride_x,
            stride_y,
            output_nofeature_tiles,
            metadata_format,
            start_index,
            class_value_field,
            buffer_radius,
            in_mask_polygons,
            rotation_angle,
            reference_system,
            processing_mode,
            blacken_around_feature,
            crop_mode,
            in_raster2)
        return result
    return Wrapper(
        in_raster,
        out_folder,
        in_class_data,
        image_chip_format,
        tile_size_x,
        tile_size_y,
        stride_x,
        stride_y,
        output_nofeature_tiles,
        metadata_format,
        start_index,
        class_value_field,
        buffer_radius,
        in_mask_polygons,
        rotation_angle,
        reference_system,
        processing_mode,
        blacken_around_feature,
        crop_mode,
        in_raster2)
ExportTrainingDataForDeepLearning.__esri_toolname__ = "ExportTrainingDataForDeepLearning_ia"
ExportTrainingDataForDeepLearning.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::3",
    "::::4",
    "::::5",
    "::::6",
    "::::7",
    "::::8",
    "::::9",
    "::::10",
    "::::11",
    "::::12",
    "::::13",
    "::::14",
    "::::15",
    "::::16",
    "::::17",
    "::::18",
    "::::19",
    "::::20"
]


def ExtractVideoFramesToImages(
        in_video,
        out_folder,
        image_type="#",
        image_overlap="#",
        require_fresh_metadata="#",
        min_time="#"):
    """ExtractVideoFramesToImages_ia(in_video, out_folder, {image_type}, {image_overlap}, {require_fresh_metadata}, {min_time})

    Extracts video frame images and associated metadata from a FMV-compliant video stream. The extracted images can be added to a mosaic dataset or other tools and functions for further analysis.

    Arguments:
    in_video -- The input video file in any of the supported video file formats, including PS, TS, MPG, MPEG, MP2, MPG2, MPEG2, MP4, MPG4, MPEG4, H264, VOB, and M2TS.
    out_folder -- The file directory where the output images and metadata will be saved.
    image_type -- Specifies the output image format.
    image_overlap -- The maximum overlap percentage between two images. If the overlap between a candidate image and the last image written to disk is greater than this value, the candidate image will be ignored. The default percentage is 100 percent, which writes all images to disk.
    require_fresh_metadata -- Specifies whether video frames with associated metadata will be extracted and saved.
    min_time -- The minimum time interval between video frames to be saved. If this is not specified, all video frames will be saved as images."""
    @Utils.StateSwapper(Utils.StateSwapper.NoSingleRasterResult)
    def Wrapper(
            in_video,
            out_folder,
            image_type,
            image_overlap,
            require_fresh_metadata,
            min_time):
        result = arcpy.gp.ExtractVideoFramesToImages_ia(
            in_video,
            out_folder,
            image_type,
            image_overlap,
            require_fresh_metadata,
            min_time)
        return result
    return Wrapper(
        in_video,
        out_folder,
        image_type,
        image_overlap,
        require_fresh_metadata,
        min_time)
ExtractVideoFramesToImages.__esri_toolname__ = "ExtractVideoFramesToImages_ia"
ExtractVideoFramesToImages.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::3",
    "::::4",
    "::::5",
    "::::6"
]


def FindArgumentStatistics(
        in_raster,
        dimension="#",
        dimension_def="#",
        interval_keyword="#",
        variables="#",
        statistics_type="#",
        min="#",
        max="#",
        multiple_occurrence="#",
        ignore_nodata="#"):
    """FindArgumentStatistics_ia(in_raster, {dimension}, {dimension_def}, {interval_keyword}, {[variable,...]}, {statistics_type}, {min}, {max}, {multiple_occurrence}, {ignore_nodata})

    Extracts the dimension value or band index at which a given statistic is attained for each pixel in a multidimensional or multiband raster.

    Arguments:
    in_raster -- The input multidimensional or multiband raster to be analyzed.
    dimension -- The dimension from which the statistic will be extracted. If the input raster is not a multidimensional raster, this parameter is not required.
    dimension_def -- Specifies how the statistic will be extracted from the dimension.
    interval_keyword -- The unit of time for which the statistic will be extracted.
    variable -- The variable or variables to be analyzed. If the input raster is not multidimensional, the pixel values of the multiband raster are considered the variable. If the input raster is multidimensional and no variable is specified, all variables with the selected dimension will be analyzed.
    statistics_type -- Specifies the statistic to extract from the variable or variables along the given dimension.
    min -- The minimum variable value to be used to extract the duration.
    max -- The maximum variable value to be used to extract the duration.
    multiple_occurrence -- The pixel value to use to indicate that a given argument statistic was reached more than once in the input raster dataset. If not specified, the pixel value will be the value of the dimension the first time the argument statistic is reached.
    ignore_nodata -- Specifies whether NoData values are ignored in the analysis.

    Results:
    out_raster -- Output Raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster,
            dimension,
            dimension_def,
            interval_keyword,
            variables,
            statistics_type,
            min,
            max,
            multiple_occurrence,
            ignore_nodata):
        out_raster = "#"
        result = arcpy.gp.FindArgumentStatistics_ia(
            in_raster,
            out_raster,
            dimension,
            dimension_def,
            interval_keyword,
            variables,
            statistics_type,
            min,
            max,
            multiple_occurrence,
            ignore_nodata)
        return _wrapToolRaster(u"FindArgumentStatistics_sa", unicode(result.getOutput(0)))
    return Wrapper(
        in_raster,
        dimension,
        dimension_def,
        interval_keyword,
        variables,
        statistics_type,
        min,
        max,
        multiple_occurrence,
        ignore_nodata)
FindArgumentStatistics.__esri_toolname__ = "FindArgumentStatistics_ia"
FindArgumentStatistics.__esri_toolinfo__ = [
    "::::1",
    "::::3",
    "::::4",
    "::::5",
    "::::6",
    "::::7",
    "::::8",
    "::::9",
    "::::10",
    "::::11"
]


def Float(
        in_raster_or_constant):
    """Float_ia(in_raster_or_constant)

    Converts each cell value of a raster into a floating-point representation.

    Arguments:
    in_raster_or_constant -- The input raster to be converted to floating point.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"Float_sa",
            ["Float", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
Float.__esri_toolname__ = "Float_ia"
Float.__esri_toolinfo__ = [
    "::::1"
]


def FocalStatistics(
        in_raster,
        neighborhood="#",
        statistics_type="#",
        ignore_nodata="#",
        percentile_value="#"):
    """FocalStatistics_ia(in_raster, {neighborhood}, {statistics_type}, {ignore_nodata}, {percentile_value})

    Calculates for each input cell location a statistic of the values within a specified neighborhood around it.

    Arguments:
    in_raster -- The raster for which the focal statistics for each input cell will be calculated.
    neighborhood -- The cells surrounding a processing cell that will be used in the statistic calculation. There are several predefined neighborhood types to choose from, or a custom kernel can be defined.
    statistics_type -- Specifies the statistic type to be calculated.
    ignore_nodata -- Specifies whether NoData values will be ignored by the statistic calculation.
    percentile_value -- The percentile value that will be calculated. The default is 90, for the 90th percentile.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster,
            neighborhood,
            statistics_type,
            ignore_nodata,
            percentile_value):
        neighborhood = Utils.compoundParameterToString(neighborhood, ParameterClasses._Neighborhood)
        args = {}
        # Neighborhood parameter
        nbr_types = {
            # values from esriRasterNeighborhoodEnum
            "RECTANGLE": 1,
            "CIRCLE": 2,
            "ANNULUS": 3,
            "WEDGE": 4,
            "IRREGULAR": 5,
            "WEIGHT": 6,
        }
        # Set defaults
        nbr_index = nbr_types["RECTANGLE"]  # Default neighborhood type
        args["Width"] = 3
        args["Height"] = 3
        in_raster = ApplyEnvironment(in_raster)
        # Parse and validate parameters
        msgs = Utils.ParameterErrors()
        # Neighborhood type
        nbr_fields = [f for f in neighborhood.split() if f]  # discard empty fields
        cell_scale = 1.0
        def _parse_float(f):
            try:
                from locale import atof as _atof
                return _atof(f)  # localized string
            except AttributeError:
                return float(f)  # number
        if len(nbr_fields) > 0:
            nbr_string = nbr_fields[0].upper()
            if nbr_string in nbr_types.keys():
                nbr_index = nbr_types[nbr_fields[0].upper()]
            if nbr_fields[-1].upper() == "MAP":
                cell_scale = _parse_float(arcpy.GetRasterProperties_management(in_raster, "CELLSIZEX").getOutput(0))
        def _cs(field: str, scale: float = cell_scale) -> int:  # convert MAP units to CELL units
            raw = _parse_float(field)
            if raw <= 0:
                msgs.add_id_message("ERROR", 622, "FocalStatistics")
                msgs.add_id_message("ERROR", 628, "neighborhood")
                raise arcpy.ExecuteError(msgs.combine())
            result = int(0.5 + raw / float(scale))
            if result <= 0:
                msgs.add_id_message("ERROR", 10176)  # Invalid neighborhood mask
                msgs.add_id_message("INFO", 952, "FocalStatistics")  # Failed to execute (tool_name).
                raise arcpy.ExecuteError(msgs.combine())
            return result
        args["NeighborhoodType"] = nbr_index
        if nbr_index == nbr_types["ANNULUS"]:
            if len(nbr_fields) >= 3:
                args["InnerRadius"] = _cs(nbr_fields[1])
                args["OuterRadius"] = _cs(nbr_fields[2])
            else:
                args["InnerRadius"] = 1
                args["OuterRadius"] = 3
        elif nbr_index == nbr_types["CIRCLE"]:
            if len(nbr_fields) > 1:
                args["Radius"] = _cs(nbr_fields[1])
            else:
                args["Radius"] = 3
        elif nbr_index == nbr_types["RECTANGLE"]:
            if len(nbr_fields) >= 3:
                args["Width"] = _cs(nbr_fields[1])
                args["Height"] = _cs(nbr_fields[2])
            else:
                args["Width"] = 3
                args["Height"] = 3
        elif nbr_index == nbr_types["WEDGE"]:
            if len(nbr_fields) >= 4:
                args["Radius"] = _cs(nbr_fields[1])
                args["StartAngle"] = _parse_float(nbr_fields[2])
                args["EndAngle"] = _parse_float(nbr_fields[3])
            else:
                args["Radius"] = 3
                args["StartAngle"] = 0
                args["EndAngle"] = 90
        elif nbr_index in (nbr_types["WEIGHT"], nbr_types["IRREGULAR"]):
            # Parse kernel file
            assert len(nbr_fields) == 2
            file_name = nbr_fields[1].strip("\"'")
            values = []
            with open(file_name, "r") as kernel_file:
                w, h = [int(s) for s in next(kernel_file).split()]
                for row in kernel_file:
                    for col in row.split():
                        values.append(_parse_float(col))
                assert len(values) == w * h
                args["Width"] = w
                args["Height"] = h
                args["NeighborhoodValues"] = values
        # Statistics type parameter
        stat_types = {
            # values from esriGeoAnalysisStatisticsEnum
            "MAJORITY": 1,
            "MAXIMUM": 2,
            "MEAN": 3,
            "MEDIAN": 4,
            "MINIMUM": 5,
            "MINORITY": 6,
            "RANGE": 7,
            "STANDARD_DEVIATION": 8,
            "STD": 8,
            "SUM": 9,
            "VARIETY": 10,
            "PERCENTILE": 12,
        }
        args["StatisticType"] = stat_types.get(str(statistics_type).upper(), stat_types["MEAN"])
        #
        args["NoDataPolicy"] = 0 if ignore_nodata.upper() == "NODATA" else -1
        try:
            args["Percentile"] = _parse_float(percentile_value)
        except ValueError:
            args["Percentile"] = 90.0
        result = arcpy.sa.Apply(in_raster, "Focal", args)
        result = ApplyEnvironment(result)
        return result
    return Wrapper(
        in_raster,
        neighborhood,
        statistics_type,
        ignore_nodata,
        percentile_value)
FocalStatistics.__esri_toolname__ = "FocalStatistics_ia"
FocalStatistics.__esri_toolinfo__ = [
    "::::1",
    "Python::NbrAnnulus|NbrCircle|NbrIrregular|NbrRectangle|NbrWedge|NbrWeight::",
    "::::4",
    "::::5",
    "::::6"
]


def GenerateMultidimensionalAnomaly(
        in_multidimensional_raster,
        variables="#",
        method="#",
        calculation_interval="#",
        ignore_nodata="#",
        reference_mean_raster="#"):
    """GenerateMultidimensionalAnomaly_ia(in_multidimensional_raster, {[variable,...]}, {method}, {calculation_interval}, {ignore_nodata}, {reference_mean_raster})

    Computes the anomaly for each slice in an existing multidimensional raster to generate a new multidimensional raster.

    Arguments:
    in_multidimensional_raster -- The input multidimensional raster dataset.
    variable -- The variable or variables for which anomalies will be calculated. If no variable is specified, all variables with a time dimension will be analyzed.
    method -- Specifies the method that will be used to calculate the anomaly.
    calculation_interval -- Specifies the temporal interval that will be used to calculate the mean.
    ignore_nodata -- Specifies whether NoData values are ignored in the analysis.
    reference_mean_raster -- The reference raster dataset that contains a previously calculated mean for each pixel. The anomalies will be calculated in comparison to this mean.

    Results:
    out_multidimensional_raster -- Output Multidimensional Raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_multidimensional_raster,
            variables,
            method,
            calculation_interval,
            ignore_nodata,
            reference_mean_raster):
        out_multidimensional_raster = "#"
        result = arcpy.gp.GenerateMultidimensionalAnomaly_ia(
            in_multidimensional_raster,
            out_multidimensional_raster,
            variables,
            method,
            calculation_interval,
            ignore_nodata,
            reference_mean_raster)
        return _wrapToolRaster(u"GenerateMultidimensionalAnomaly_sa", unicode(result.getOutput(0)))
    return Wrapper(
        in_multidimensional_raster,
        variables,
        method,
        calculation_interval,
        ignore_nodata,
        reference_mean_raster)
GenerateMultidimensionalAnomaly.__esri_toolname__ = "GenerateMultidimensionalAnomaly_ia"
GenerateMultidimensionalAnomaly.__esri_toolinfo__ = [
    "::::1",
    "::::3",
    "::::4",
    "::::5",
    "::::6",
    "::::7"
]


def GenerateTrainingSamplesFromSeedPoints(
        in_class_data,
        in_seed_points,
        out_training_feature_class,
        min_sample_area="#",
        max_sample_radius="#"):
    """GenerateTrainingSamplesFromSeedPoints_ia(in_class_data, in_seed_points, out_training_feature_class, {min_sample_area}, {max_sample_radius})

    Generates training samples from seed points, such as accuracy assessment points or training sample points. A typical use case is generating training samples from an existing source, such as a thematic raster or a feature class.

    Arguments:
    in_class_data -- The data source that labels the training samples.
    in_seed_points -- A point shapefile or feature class to provide the centers of training sample polygons.
    out_training_feature_class -- The output training sample feature class in the format that can be used in training tools, including shapefiles. The output feature class can be either a polygon feature class or a point feature class.
    min_sample_area -- The minimum area needed for each training sample, in square meters. The minimum value must be greater than or equal to 0.
    max_sample_radius -- The longest distance (in meters) from any point within the training sample to its center seed point. If set to 0, the output training sample will be points instead of polygons. The minimum value must be greater than or equal to 0."""
    @Utils.StateSwapper(Utils.StateSwapper.NoSingleRasterResult)
    def Wrapper(
            in_class_data,
            in_seed_points,
            out_training_feature_class,
            min_sample_area,
            max_sample_radius):
        result = arcpy.gp.GenerateTrainingSamplesFromSeedPoints_ia(
            in_class_data,
            in_seed_points,
            out_training_feature_class,
            min_sample_area,
            max_sample_radius)
        return result
    return Wrapper(
        in_class_data,
        in_seed_points,
        out_training_feature_class,
        min_sample_area,
        max_sample_radius)
GenerateTrainingSamplesFromSeedPoints.__esri_toolname__ = "GenerateTrainingSamplesFromSeedPoints_ia"
GenerateTrainingSamplesFromSeedPoints.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::3",
    "::::4",
    "::::5"
]


def GenerateTrendRaster(
        in_multidimensional_raster,
        dimension,
        variables="#",
        line_type="#",
        frequency="#",
        ignore_nodata="#",
        cycle_length="#",
        cycle_unit="#",
        rmse="#",
        r2="#",
        slope_p_value="#",
        seasonal_period="#"):
    """GenerateTrendRaster_ia(in_multidimensional_raster, dimension, {[variable,...]}, {line_type}, {frequency}, {ignore_nodata}, {cycle_length}, {cycle_unit}, {rmse}, {r2}, {slope_p_value}, {seasonal_period})

    Estimates the trend for each pixel along a dimension for one or more variables in a multidimensional raster.

    Arguments:
    in_multidimensional_raster -- The input multidimensional raster dataset.
    dimension -- The dimension along which a trend will be extracted for the variable or variables selected in the analysis.
    variable -- The variable or variables for which trends will be calculated. If no variable is specified, the first variable in the multidimensional raster will be analyzed.
    line_type -- Specifies the type of trend analysis to perform to pixel values along a dimension.
    frequency -- The frequency or the polynomial order number to use in the trend fitting. If the trend type is polynomial, this parameter specifies the polynomial order. If the trend type is harmonic, this parameter specifies the number of models to use to fit the trend.
    ignore_nodata -- Specifies whether NoData values are ignored in the analysis.
    cycle_length -- The length of periodic variation to model. This parameter is required when Trend Type is set to Harmonic. For example, leaf greenness often has one strong cycle of variation in a single year, so the cycle length is 1 year. Hourly temperature data has one strong cycle of variation throughout a single day, so the cycle length is 1 day.
    cycle_unit -- Specifies the time unit to be used for the length of a harmonic cycle.
    rmse -- Specifies whether the root mean square error (RMSE) of the trend fit line will be calculated.
    r2 -- Specifies whether the R-squared goodness-of-fit statistic for the trend fit line will be calculated.
    slope_p_value -- Specifies whether the p-value statistic for the slope coefficient of the trend line will be calculated.
    seasonal_period -- Specifies the time unit to be used for the length of a seasonal period when performing the Seasonal-Kendall test.

    Results:
    out_multidimensional_raster -- Output Multidimensional Raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_multidimensional_raster,
            dimension,
            variables,
            line_type,
            frequency,
            ignore_nodata,
            cycle_length,
            cycle_unit,
            rmse,
            r2,
            slope_p_value,
            seasonal_period):
        out_multidimensional_raster = "#"
        result = arcpy.gp.GenerateTrendRaster_ia(
            in_multidimensional_raster,
            out_multidimensional_raster,
            dimension,
            variables,
            line_type,
            frequency,
            ignore_nodata,
            cycle_length,
            cycle_unit,
            rmse,
            r2,
            slope_p_value,
            seasonal_period)
        return _wrapToolRaster(u"GenerateTrendRaster_sa", unicode(result.getOutput(0)))
    return Wrapper(
        in_multidimensional_raster,
        dimension,
        variables,
        line_type,
        frequency,
        ignore_nodata,
        cycle_length,
        cycle_unit,
        rmse,
        r2,
        slope_p_value,
        seasonal_period)
GenerateTrendRaster.__esri_toolname__ = "GenerateTrendRaster_ia"
GenerateTrendRaster.__esri_toolinfo__ = [
    "::::1",
    "::::3",
    "::::4",
    "::::5",
    "::::6",
    "::::7",
    "::::8",
    "::::9",
    "::::10",
    "::::11",
    "::::12",
    "::::13"
]


def GreaterThan(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """GreaterThan_ia(in_raster_or_constant1, in_raster_or_constant2)

    Performs a Relational greater-than operation on two inputs on a cell-by-cell basis.

    Arguments:
    in_raster_or_constant1 -- The input being tested to determine if it is greater than the second input.
    in_raster_or_constant2 -- The input against which the first input is tested to be greater than.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant1,
            in_raster_or_constant2):
        return _wrapLocalFunctionRaster(u"GreaterThan_sa",
            ["GreaterThan", in_raster_or_constant1, in_raster_or_constant2])
    return Wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)
GreaterThan.__esri_toolname__ = "GreaterThan_ia"
GreaterThan.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def GreaterThanEqual(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """GreaterThanEqual_ia(in_raster_or_constant1, in_raster_or_constant2)

    Performs a Relational greater-than-or-equal-to operation on two inputs on a cell-by-cell basis.

    Arguments:
    in_raster_or_constant1 -- The input being tested to determine if it is greater than or equal to the second input.
    in_raster_or_constant2 -- The input against which the first input is tested to be greater than or equal to.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant1,
            in_raster_or_constant2):
        return _wrapLocalFunctionRaster(u"GreaterThanEqual_sa",
            ["GreaterThanEqual", in_raster_or_constant1, in_raster_or_constant2])
    return Wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)
GreaterThanEqual.__esri_toolname__ = "GreaterThanEqual_ia"
GreaterThanEqual.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def InList(
        in_raster_or_constant,
        in_raster_or_constants,
        process_as_multiband="#"):
    """InList_ia(in_raster_or_constant, [in_raster_or_constant,...], {process_as_multiband})

    Determines which values from the first input are contained in a set of other inputs, on a cell-by-cell basis.

    Arguments:
    in_raster_or_constant -- The input that defines the value that will be looked for in a list of rasters on a cell-by-cell basis.
    in_raster_or_constant -- A list of input rasters that the first input will be evaluated against. For each location, if the cell value from the first input exists in any of the other rasters, that value will be assigned to the output raster. If the value does not exist in any of the other rasters, the output value at that location will be NoData.
    process_as_multiband -- Specifies how the input multiband raster bands will be processed.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant,
            in_raster_or_constants,
            process_as_multiband):
        if Utils.useDefaultArgumentValue(process_as_multiband):
            process_as_multiband = "SINGLE_BAND"
        if process_as_multiband not in ["SINGLE_BAND", "MULTI_BAND"]:
            raise arcpy.ExecuteError("ERROR 000622: Failed to execute (InList). Parameters are not valid.\nERROR 000621: Input to parameter process_as_multiband not within domain.\n")
        return _wrapLocalFunctionRaster(u"InList_ia", ["InList", in_raster_or_constant] + Utils.flattenLists(in_raster_or_constants), {"flattenBands" : process_as_multiband.upper() == "SINGLE_BAND"})
    return Wrapper(
        in_raster_or_constant,
        in_raster_or_constants,
        process_as_multiband)
InList.__esri_toolname__ = "InList_ia"
InList.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::4"
]


def InspectTrainingSamples(
        in_raster,
        in_training_features,
        in_classifier_definition,
        out_training_feature_class,
        in_additional_raster="#"):
    """InspectTrainingSamples_ia(in_raster, in_training_features, in_classifier_definition, out_training_feature_class, {in_additional_raster})

    Estimates the accuracy of individual training samples. The cross validation accuracy is computed using the previously generated classification training result in an .ecd file and the training samples. Outputs include a raster dataset containing the misclassified class values and a training sample dataset with the accuracy score for each training sample.

    Arguments:
    in_raster -- The input raster to be classified.
    in_training_features -- A training sample feature class created in the Training Samples Manager pane.
    in_classifier_definition -- The .ecd output classifier file from any of the train classifier tools. The .ecd file is a JSON file that contains attribute information, statistics, or other information needed for the classifier.
    out_training_feature_class -- The output individual training samples saved as a feature class. The associated attribute table contains an addition field listing the accuracy score.
    in_additional_raster -- Ancillary raster datasets, such as a multispectral image or a DEM, will be incorporated to generate attributes and other required information for the classifier. This raster is necessary when calculating attributes such as mean or standard deviation. This parameter is optional.

    Results:
    out_misclassified_raster -- Output Misclassified Raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster,
            in_training_features,
            in_classifier_definition,
            out_training_feature_class,
            in_additional_raster):
        out_misclassified_raster = "#"
        result = arcpy.gp.InspectTrainingSamples_ia(
            in_raster,
            in_training_features,
            in_classifier_definition,
            out_training_feature_class,
            out_misclassified_raster,
            in_additional_raster)
        return _wrapToolRaster(u"InspectTrainingSamples_sa", unicode(result.getOutput(0)))
    return Wrapper(
        in_raster,
        in_training_features,
        in_classifier_definition,
        out_training_feature_class,
        in_additional_raster)
InspectTrainingSamples.__esri_toolname__ = "InspectTrainingSamples_ia"
InspectTrainingSamples.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::3",
    "::::4",
    "::::6"
]


def Int(
        in_raster_or_constant):
    """Int_ia(in_raster_or_constant)

    Converts each cell value of a raster to an integer by truncation.

    Arguments:
    in_raster_or_constant -- The input raster to be converted to integer.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"Int_sa",
            ["Int", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
Int.__esri_toolname__ = "Int_ia"
Int.__esri_toolinfo__ = [
    "::::1"
]


def IsNull(
        in_raster):
    """IsNull_ia(in_raster)

    Determines which values from the input raster are NoData on a cell-by-cell basis.

    Arguments:
    in_raster -- The input raster being tested to identify the cells that are NoData (null).

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster):
        return _wrapLocalFunctionRaster(u"IsNull_sa",
            ["IsNull", in_raster])
    return Wrapper(
        in_raster)
IsNull.__esri_toolname__ = "IsNull_ia"
IsNull.__esri_toolinfo__ = [
    "::::1"
]


def LessThan(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """LessThan_ia(in_raster_or_constant1, in_raster_or_constant2)

    Performs a Relational less-than operation on two inputs on a cell-by-cell basis.

    Arguments:
    in_raster_or_constant1 -- The input being tested to determine if it is less than the second input.
    in_raster_or_constant2 -- The input against which the first input is tested to be less than.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant1,
            in_raster_or_constant2):
        return _wrapLocalFunctionRaster(u"LessThan_sa",
            ["LessThan", in_raster_or_constant1, in_raster_or_constant2])
    return Wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)
LessThan.__esri_toolname__ = "LessThan_ia"
LessThan.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def LessThanEqual(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """LessThanEqual_ia(in_raster_or_constant1, in_raster_or_constant2)

    Performs a Relational less-than-or-equal-to operation on two inputs on a cell-by-cell basis.

    Arguments:
    in_raster_or_constant1 -- The input being tested to determine if it is less than or equal to the second input.
    in_raster_or_constant2 -- The input against which the first input is tested to be less than or equal to.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant1,
            in_raster_or_constant2):
        return _wrapLocalFunctionRaster(u"LessThanEqual_sa",
            ["LessThanEqual", in_raster_or_constant1, in_raster_or_constant2])
    return Wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)
LessThanEqual.__esri_toolname__ = "LessThanEqual_ia"
LessThanEqual.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def LinearSpectralUnmixing(
        in_raster,
        in_spectral_profile_file,
        value_option="#"):
    """LinearSpectralUnmixing_ia(in_raster, in_spectral_profile_file, {[value_option,...]})

    Performs subpixel classification and calculates the fractional abundance of different land cover types for individual pixels.

    Arguments:
    in_raster -- The input raster dataset.
    in_spectral_profile_file -- The spectral information for the different land cover classes.
    value_option -- Specifies how the output pixel values will be defined.

    Results:
    out_raster -- Output Raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster,
            in_spectral_profile_file,
            value_option):
        out_raster = "#"
        result = arcpy.gp.LinearSpectralUnmixing_ia(
            in_raster,
            out_raster,
            in_spectral_profile_file,
            value_option)
        return _wrapToolRaster(u"LinearSpectralUnmixing_sa", unicode(result.getOutput(0)))
    return Wrapper(
        in_raster,
        in_spectral_profile_file,
        value_option)
LinearSpectralUnmixing.__esri_toolname__ = "LinearSpectralUnmixing_ia"
LinearSpectralUnmixing.__esri_toolinfo__ = [
    "::::1",
    "::::3",
    "::::4"
]


def Ln(
        in_raster_or_constant):
    """Ln_ia(in_raster_or_constant)

    Calculates the natural logarithm (base e) of cells in a raster.

    Arguments:
    in_raster_or_constant -- Input values for which to find the natural logarithm (Ln).

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"Ln_sa",
            ["Ln", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
Ln.__esri_toolname__ = "Ln_ia"
Ln.__esri_toolinfo__ = [
    "::::1"
]


def Log10(
        in_raster_or_constant):
    """Log10_ia(in_raster_or_constant)

    Calculates the base 10 logarithm of cells in a raster.

    Arguments:
    in_raster_or_constant -- Input values for which to find the base 10 logarithm.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"Log10_sa",
            ["Log10", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
Log10.__esri_toolname__ = "Log10_ia"
Log10.__esri_toolinfo__ = [
    "::::1"
]


def Log2(
        in_raster_or_constant):
    """Log2_ia(in_raster_or_constant)

    Calculates the base 2 logarithm of cells in a raster.

    Arguments:
    in_raster_or_constant -- Input values for which to find the base 2 logarithm.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"Log2_sa",
            ["Log2", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
Log2.__esri_toolname__ = "Log2_ia"
Log2.__esri_toolinfo__ = [
    "::::1"
]


def Minus(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """Minus_ia(in_raster_or_constant1, in_raster_or_constant2)

    Subtracts the value of the second input raster from the value of the first input raster on a cell-by-cell basis.

    Arguments:
    in_raster_or_constant1 -- The input from which to subtract the values in the second input.
    in_raster_or_constant2 -- The input values to subtract from the values in the first input.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant1,
            in_raster_or_constant2):
        return _wrapLocalFunctionRaster(u"Minus_sa",
            ["Minus", in_raster_or_constant1, in_raster_or_constant2])
    return Wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)
Minus.__esri_toolname__ = "Minus_ia"
Minus.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def Mod(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """Mod_ia(in_raster_or_constant1, in_raster_or_constant2)

    Finds the remainder (modulo) of the first raster when divided by the second raster on a cell-by-cell basis.

    Arguments:
    in_raster_or_constant1 -- The numerator input.
    in_raster_or_constant2 -- The denominator input.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant1,
            in_raster_or_constant2):
        return _wrapLocalFunctionRaster(u"Mod_sa",
            ["Mod", in_raster_or_constant1, in_raster_or_constant2])
    return Wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)
Mod.__esri_toolname__ = "Mod_ia"
Mod.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def MultidimensionalPrincipalComponents(
        in_multidimensional_raster,
        mode,
        dimension,
        out_pc,
        out_loadings,
        out_eigenvalues="#",
        variable="#",
        number_of_pc="#"):
    """MultidimensionalPrincipalComponents_ia(in_multidimensional_raster, mode, dimension, out_pc, out_loadings, {out_eigenvalues}, {variable}, {number_of_pc})

    Transforms multidimensional rasters into their principal components, loadings, and eigenvalues. It transforms the data into a reduced number of components that account for the variance of the data, so that spatial and temporal patterns can be readily identified.

    Arguments:
    in_multidimensional_raster -- The input multidimensional raster.
    mode -- Specifies the method that will be used to perform principal component analysis.
    dimension -- The dimension name used to process the principal components.
    out_pc -- The name of the output raster dataset. The output is a multiband raster with the components as bands. The first band is the first principal component with the largest eigenvalue, the second band has the principal component with the second largest eigenvalue, and so on.
    out_loadings -- The output table containing weights for each input raster contributing to the principal components. It is the correlation of the input data and output principal components. Use the .csv file extension to output the loadings as a comma-separated values file.
    out_eigenvalues -- The output Eigenvalues table. Eigenvalues are values indicating the variance percentage of each component. Eigenvalues help you define the number of principal components that are needed to represent the dataset.
    variable -- The variable of the input multidimensional raster used in computation. If the input raster is multidimensional and no variable is specified, only the first variable will be analyzed, by default.
    number_of_pc -- The number of principal components to compute, usually fewer than the number of input rasters."""
    @Utils.StateSwapper(Utils.StateSwapper.NoSingleRasterResult)
    def Wrapper(
            in_multidimensional_raster,
            mode,
            dimension,
            out_pc,
            out_loadings,
            out_eigenvalues,
            variable,
            number_of_pc):
        result = arcpy.gp.MultidimensionalPrincipalComponents_ia(
            in_multidimensional_raster,
            mode,
            dimension,
            out_pc,
            out_loadings,
            out_eigenvalues,
            variable,
            number_of_pc)
        return result
    return Wrapper(
        in_multidimensional_raster,
        mode,
        dimension,
        out_pc,
        out_loadings,
        out_eigenvalues,
        variable,
        number_of_pc)
MultidimensionalPrincipalComponents.__esri_toolname__ = "MultidimensionalPrincipalComponents_ia"
MultidimensionalPrincipalComponents.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::3",
    "::::4",
    "::::5",
    "::::6",
    "::::7",
    "::::8"
]


def Negate(
        in_raster_or_constant):
    """Negate_ia(in_raster_or_constant)

    Changes the sign (multiplies by -1) of the cell values of the input raster on a cell-by-cell basis.

    Arguments:
    in_raster_or_constant -- The input raster to be negated (multiplied by -1).

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"Negate_sa",
            ["Negate", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
Negate.__esri_toolname__ = "Negate_ia"
Negate.__esri_toolinfo__ = [
    "::::1"
]


def NonMaximumSuppression(
        in_featureclass,
        confidence_score_field,
        out_featureclass,
        class_value_field="#",
        max_overlap_ratio="#"):
    """NonMaximumSuppression_ia(in_featureclass, confidence_score_field, out_featureclass, {class_value_field}, {max_overlap_ratio})

    Identifies duplicate features from the output of the Detect Objects Using Deep Learning tool as a postprocessing step and creates a new output with no duplicate features. The Detect Objects Using Deep Learning tool can return more than one bounding box or polygon for the same object, especially as a tiling side effect. If two features overlap more than a given maximum ratio, the feature with the lower confidence value will be removed.

    Arguments:
    in_featureclass -- The input feature class or feature layer containing overlapping or duplicate features.
    confidence_score_field -- The field in the feature class that contains the confidence scores as output by the object detection method.
    out_featureclass -- The output feature class with the duplicate features removed.
    class_value_field -- The class value field in the input feature class. If not specified, the tool will use the standard class value fields Classvalue and Value. If these fields do not exist, all features will be treated as the same object class.
    max_overlap_ratio -- The maximum overlap ratio for two overlapping features. This is defined as the ratio of intersection area over union area. The default is 0."""
    @Utils.StateSwapper(Utils.StateSwapper.NoSingleRasterResult)
    def Wrapper(
            in_featureclass,
            confidence_score_field,
            out_featureclass,
            class_value_field,
            max_overlap_ratio):
        result = arcpy.gp.NonMaximumSuppression_ia(
            in_featureclass,
            confidence_score_field,
            out_featureclass,
            class_value_field,
            max_overlap_ratio)
        return result
    return Wrapper(
        in_featureclass,
        confidence_score_field,
        out_featureclass,
        class_value_field,
        max_overlap_ratio)
NonMaximumSuppression.__esri_toolname__ = "NonMaximumSuppression_ia"
NonMaximumSuppression.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::3",
    "::::4",
    "::::5"
]


def NotEqual(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """NotEqual_ia(in_raster_or_constant1, in_raster_or_constant2)

    Performs a Relational not-equal-to operation on two inputs on a cell-by-cell basis.

    Arguments:
    in_raster_or_constant1 -- The input that will be compared to for inequality by the second input.
    in_raster_or_constant2 -- The input that will be compared from for inequality by the first input.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant1,
            in_raster_or_constant2):
        return _wrapLocalFunctionRaster(u"NotEqual_sa",
            ["NotEqual", in_raster_or_constant1, in_raster_or_constant2])
    return Wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)
NotEqual.__esri_toolname__ = "NotEqual_ia"
NotEqual.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def Over(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """Over_ia(in_raster_or_constant1, in_raster_or_constant2)

    For the cell values in the first input that are not 0, the output value will be that of the first input. Where the cell values are 0, the output will be that of the second input raster.

    Arguments:
    in_raster_or_constant1 -- The input for which cell values of 0 will be replaced with the value from the second input.
    in_raster_or_constant2 -- The input whose value will be assigned to the output raster cells where the first input value is 0.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant1,
            in_raster_or_constant2):
        return _wrapLocalFunctionRaster(u"Over_sa",
            ["Over", in_raster_or_constant1, in_raster_or_constant2])
    return Wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)
Over.__esri_toolname__ = "Over_ia"
Over.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def Pick(
        in_position_raster,
        in_rasters_or_constants,
        process_as_multiband="#"):
    """Pick_ia(in_position_raster, [in_rasters_or_constant,...], {process_as_multiband})

    The value from a position raster is used to determine from which raster in a list of input rasters the output cell value will be obtained.

    Arguments:
    in_position_raster -- The input raster defining the position of the raster to use for the output value.
    in_rasters_or_constant -- The list of inputs from which the output value will be selected.
    process_as_multiband -- Specifies how the input multiband raster bands will be processed.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_position_raster,
            in_rasters_or_constants,
            process_as_multiband):
        if Utils.useDefaultArgumentValue(process_as_multiband):
            process_as_multiband = "SINGLE_BAND"
        if process_as_multiband not in ["SINGLE_BAND", "MULTI_BAND"]:
            raise arcpy.ExecuteError("ERROR 000622: Failed to execute (Pick). Parameters are not valid.\nERROR 000621: Input to parameter process_as_multiband not within domain.\n")
        return _wrapLocalFunctionRaster(u"Pick_ia", ["Pick", in_position_raster] + Utils.flattenLists(in_rasters_or_constants), {"flattenBands" : process_as_multiband.upper() == "SINGLE_BAND"})
    return Wrapper(
        in_position_raster,
        in_rasters_or_constants,
        process_as_multiband)
Pick.__esri_toolname__ = "Pick_ia"
Pick.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::4"
]


def Plus(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """Plus_ia(in_raster_or_constant1, in_raster_or_constant2)

    Adds (sums) the values of two rasters on a cell-by-cell basis.

    Arguments:
    in_raster_or_constant1 -- The input whose values will be added to.
    in_raster_or_constant2 -- The input whose values will be added to the first input.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant1,
            in_raster_or_constant2):
        return _wrapLocalFunctionRaster(u"Plus_sa",
            ["Plus", in_raster_or_constant1, in_raster_or_constant2])
    return Wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)
Plus.__esri_toolname__ = "Plus_ia"
Plus.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def Power(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """Power_ia(in_raster_or_constant1, in_raster_or_constant2)

    Raises the cell values in a raster to the power of the values found in another raster.

    Arguments:
    in_raster_or_constant1 -- The input values to be raised to the power defined by the second input.
    in_raster_or_constant2 -- The input that determines the power the values in the first input will be raised to.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant1,
            in_raster_or_constant2):
        return _wrapLocalFunctionRaster(u"Power_sa",
            ["Power", in_raster_or_constant1, in_raster_or_constant2])
    return Wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)
Power.__esri_toolname__ = "Power_ia"
Power.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def PredictUsingRegressionModel(
        in_rasters,
        in_regression_definition):
    """PredictUsingRegressionModel_ia([in_raster,...], in_regression_definition)

    Predicts data values using the output from the Train Random Trees Regression Model tool.

    Arguments:
    in_raster -- The single-band, multidimensional, or multiband raster datasets, or mosaic datasets containing explanatory variables.
    in_regression_definition -- A JSON format file that contains attribute information, statistics, or other information from the regression model. The file has an .ecd extension. The file is the output of the Train Random Trees Regression Model tool.

    Results:
    out_raster_dataset -- Output predicted raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_rasters,
            in_regression_definition):
        out_raster_dataset = "#"
        result = arcpy.gp.PredictUsingRegressionModel_ia(
            in_rasters,
            in_regression_definition,
            out_raster_dataset)
        return _wrapToolRaster(u"PredictUsingRegressionModel_sa", unicode(result.getOutput(0)))
    return Wrapper(
        in_rasters,
        in_regression_definition)
PredictUsingRegressionModel.__esri_toolname__ = "PredictUsingRegressionModel_ia"
PredictUsingRegressionModel.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def PredictUsingTrendRaster(
        in_multidimensional_raster,
        variables="#",
        dimension_def="#",
        dimension_values="#",
        start="#",
        end="#",
        interval_value="#",
        interval_unit="#"):
    """PredictUsingTrendRaster_ia(in_multidimensional_raster, {[variable,...]}, {dimension_def}, {[dimension_value,...]}, {start}, {end}, {interval_value}, {interval_unit})

    Computes a forecasted multidimensional raster using the output trend raster from the Generate Trend Raster tool.

    Arguments:
    in_multidimensional_raster -- The input multidimensional trend raster from the Generate Trend Raster tool.
    variable -- The variable or variables that will be predicted in the analysis. If no variables are specified, all variables will be used.
    dimension_def -- Specifies the method used to provide prediction dimension values.
    dimension_value -- The dimension value or values to be used in the prediction.
    start -- The start date, height, or depth of the dimension interval to be used in the prediction.
    end -- The end date, height, or depth of the dimension interval to be used in the prediction.
    interval_value -- The number of steps between two dimension values to be included in the prediction. The default value is 1.
    interval_unit -- Specifies the unit that will be used for the interval value. This parameter only applies when the dimension of analysis is a time dimension.

    Results:
    out_multidimensional_raster -- Output Multidimensional Raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_multidimensional_raster,
            variables,
            dimension_def,
            dimension_values,
            start,
            end,
            interval_value,
            interval_unit):
        out_multidimensional_raster = "#"
        result = arcpy.gp.PredictUsingTrendRaster_ia(
            in_multidimensional_raster,
            out_multidimensional_raster,
            variables,
            dimension_def,
            dimension_values,
            start,
            end,
            interval_value,
            interval_unit)
        return _wrapToolRaster(u"PredictUsingTrendRaster_sa", unicode(result.getOutput(0)))
    return Wrapper(
        in_multidimensional_raster,
        variables,
        dimension_def,
        dimension_values,
        start,
        end,
        interval_value,
        interval_unit)
PredictUsingTrendRaster.__esri_toolname__ = "PredictUsingTrendRaster_ia"
PredictUsingTrendRaster.__esri_toolinfo__ = [
    "::::1",
    "::::3",
    "::::4",
    "::::5",
    "::::6",
    "::::7",
    "::::8",
    "::::9"
]


def RemoveRasterSegmentTilingArtifacts(
        in_segmented_raster,
        tileSizeX="#",
        tileSizeY="#"):
    """RemoveRasterSegmentTilingArtifacts_ia(in_segmented_raster, {tileSizeX}, {tileSizeY})

    Corrects segments or objects cut by tile boundaries during the segmentation process performed as a raster function. This tool is helpful for some regional processes, such as image segmentation, that have inconsistencies near image tile boundaries.

    Arguments:
    in_segmented_raster -- Select the segmented raster with the tiling artifacts that you want to remove.
    tileSizeX -- Specify the tile width from Segment Mean Shift. If left blank, the default is 512 pixels.
    tileSizeY -- Specify the tile height from Segment Mean Shift. If left blank, the default is 512 pixels.

    Results:
    out_raster_dataset -- Output Segmented Raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_segmented_raster,
            tileSizeX,
            tileSizeY):
        out_raster_dataset = "#"
        result = arcpy.gp.RemoveRasterSegmentTilingArtifacts_ia(
            in_segmented_raster,
            out_raster_dataset,
            tileSizeX,
            tileSizeY)
        return _wrapToolRaster(u"RemoveRasterSegmentTilingArtifacts_sa", unicode(result.getOutput(0)))
    return Wrapper(
        in_segmented_raster,
        tileSizeX,
        tileSizeY)
RemoveRasterSegmentTilingArtifacts.__esri_toolname__ = "RemoveRasterSegmentTilingArtifacts_ia"
RemoveRasterSegmentTilingArtifacts.__esri_toolinfo__ = [
    "::::1",
    "::::3",
    "::::4"
]


def RoundDown(
        in_raster_or_constant):
    """RoundDown_ia(in_raster_or_constant)

    Returns the next lower integer value, just represented as a floating point, for each cell in a raster.

    Arguments:
    in_raster_or_constant -- The input values to be rounded down.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"RoundDown_sa",
            ["RoundDown", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
RoundDown.__esri_toolname__ = "RoundDown_ia"
RoundDown.__esri_toolinfo__ = [
    "::::1"
]


def RoundUp(
        in_raster_or_constant):
    """RoundUp_ia(in_raster_or_constant)

    Returns the next higher integer value, just represented as a floating point, for each cell in a raster.

    Arguments:
    in_raster_or_constant -- The input values to be rounded up.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"RoundUp_sa",
            ["RoundUp", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
RoundUp.__esri_toolname__ = "RoundUp_ia"
RoundUp.__esri_toolinfo__ = [
    "::::1"
]


def Sample(
        in_rasters,
        in_location_data,
        out_table,
        resampling_type="#",
        unique_id_field="#",
        process_as_multidimensional="#",
        acquisition_definition="#",
        statistics_type="#",
        percentile_value="#",
        buffer_distance="#",
        layout="#",
        generate_feature_class="#"):
    """Sample_ia([in_raster,...], in_location_data, out_table, {resampling_type}, {unique_id_field}, {process_as_multidimensional}, {acquisition_definition}, {statistics_type}, {percentile_value}, {buffer_distance}, {layout}, {generate_feature_class})

    Creates a table or a point feature class that shows the values of cells from a raster, or a set of rasters, for defined locations. The locations are defined by raster cells, points, polylines, or polygons.

    Arguments:
    in_raster -- The rasters with values that will be sampled based on the input location data.
    in_location_data -- The data identifying positions where a sample will be taken.
    out_table -- The output table or feature class containing the sampled cell values.
    resampling_type -- The resampling algorithm that will be used to sample a raster to determine how the values will be obtained from the raster.
    unique_id_field -- A field containing a different value for every location or feature in the input location raster or features.
    process_as_multidimensional -- Specifies how the input rasters will be processed.
    acquisition_definition -- Specifies the time, depth, or other acquisition data associated with the location features.
    statistics_type -- Specifies the statistic type to be calculated.
    percentile_value -- This value can range from 0 to 100. The default is 90.
    buffer_distance -- The distance around the location data features. The buffer distance is specified in the linear unit of the location feature's spatial reference. If the feature uses a geographic reference, the unit will be degrees.
    layout -- Specifies whether sampled values will appear in rows or columns in the output table.
    generate_feature_class -- Specifies whether a point feature class with sampled values in its attribute table or a table with sampled values will be generated."""
    @Utils.StateSwapper(Utils.StateSwapper.NoSingleRasterResult)
    def Wrapper(
            in_rasters,
            in_location_data,
            out_table,
            resampling_type,
            unique_id_field,
            process_as_multidimensional,
            acquisition_definition,
            statistics_type,
            percentile_value,
            buffer_distance,
            layout,
            generate_feature_class):
        result = arcpy.gp.Sample_ia(
            in_rasters,
            in_location_data,
            out_table,
            resampling_type,
            unique_id_field,
            process_as_multidimensional,
            acquisition_definition,
            statistics_type,
            percentile_value,
            buffer_distance,
            layout,
            generate_feature_class)
        return result
    return Wrapper(
        in_rasters,
        in_location_data,
        out_table,
        resampling_type,
        unique_id_field,
        process_as_multidimensional,
        acquisition_definition,
        statistics_type,
        percentile_value,
        buffer_distance,
        layout,
        generate_feature_class)
Sample.__esri_toolname__ = "Sample_ia"
Sample.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::3",
    "::::4",
    "::::5",
    "::::6",
    "::::7",
    "::::8",
    "::::9",
    "::::10",
    "::::11",
    "::::12"
]


def SegmentMeanShift(
        in_raster,
        spectral_detail="#",
        spatial_detail="#",
        min_segment_size="#",
        band_indexes="#",
        max_segment_size="#"):
    """SegmentMeanShift_ia(in_raster, {spectral_detail}, {spatial_detail}, {min_segment_size}, {band_indexes}, {max_segment_size})

    Groups into segments adjacent pixels that have similar spectral characteristics.

    Arguments:
    in_raster -- The raster dataset to segment. This can be a multispectral or grayscale image.
    spectral_detail -- The level of importance given to the spectral differences of features in the imagery.
    spatial_detail -- The level of importance given to the proximity between features in the imagery.
    min_segment_size -- The minimum size of a segment. Merge segments smaller than this size with their best fitting neighbor segment. This is related to the minimum mapping unit for your project.
    band_indexes -- The bands that will be used to segment the imagery, separated by a space. If no band indexes are specified, they are determined by the following criteria:
    max_segment_size -- The maximum size of a segment. Segments that are larger than the specified size will be divided. Use this parameter to prevent artifacts in the output raster resulting from large segments.

    Results:
    out_raster_dataset -- Output Raster Dataset"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster,
            spectral_detail,
            spatial_detail,
            min_segment_size,
            band_indexes,
            max_segment_size):
        out_raster_dataset = "#"
        result = arcpy.gp.SegmentMeanShift_ia(
            in_raster,
            out_raster_dataset,
            spectral_detail,
            spatial_detail,
            min_segment_size,
            band_indexes,
            max_segment_size)
        return _wrapToolRaster(u"SegmentMeanShift_sa", unicode(result.getOutput(0)))
    return Wrapper(
        in_raster,
        spectral_detail,
        spatial_detail,
        min_segment_size,
        band_indexes,
        max_segment_size)
SegmentMeanShift.__esri_toolname__ = "SegmentMeanShift_ia"
SegmentMeanShift.__esri_toolinfo__ = [
    "::::1",
    "::::3",
    "::::4",
    "::::5",
    "::::6",
    "::::7"
]


def SetNull(
        in_conditional_raster,
        in_false_raster_or_constant,
        where_clause="#"):
    """SetNull_ia(in_conditional_raster, in_false_raster_or_constant, {where_clause})

    Set Null sets identified cell locations to NoData based on a specified criteria. It returns NoData if a conditional evaluation is true, and returns the value specified by another raster if it is false.

    Arguments:
    in_conditional_raster -- Input raster representing the true or false result of the desired condition.
    in_false_raster_or_constant -- The input whose values will be used as the output cell values if the condition is false.
    where_clause -- A logical expression that determines which of the input cells are to be true or false.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_conditional_raster,
            in_false_raster_or_constant,
            where_clause):
        if Utils.useDefaultArgumentValue(where_clause):
            return _wrapLocalFunctionRaster(u"SetNull_sa",
                ["SetNull", in_conditional_raster, in_false_raster_or_constant])
        out_raster = "#"
        result = arcpy.gp.SetNull_ia(
            in_conditional_raster,
            in_false_raster_or_constant,
            out_raster,
            where_clause)
        return _wrapToolRaster(u"SetNull_sa", unicode(result.getOutput(0)))
    return Wrapper(
        in_conditional_raster,
        in_false_raster_or_constant,
        where_clause)
SetNull.__esri_toolname__ = "SetNull_ia"
SetNull.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::4"
]


def Sin(
        in_raster_or_constant):
    """Sin_ia(in_raster_or_constant)

    Calculates the sine of cells in a raster.

    Arguments:
    in_raster_or_constant -- The input for which to calculate the sine values.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"Sin_sa",
            ["Sin", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
Sin.__esri_toolname__ = "Sin_ia"
Sin.__esri_toolinfo__ = [
    "::::1"
]


def SinH(
        in_raster_or_constant):
    """SinH_ia(in_raster_or_constant)

    Calculates the hyperbolic sine of cells in a raster.

    Arguments:
    in_raster_or_constant -- The input for which to calculate the hyperbolic sine values.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"SinH_sa",
            ["SinH", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
SinH.__esri_toolname__ = "SinH_ia"
SinH.__esri_toolinfo__ = [
    "::::1"
]


def Square(
        in_raster_or_constant):
    """Square_ia(in_raster_or_constant)

    Calculates the square of the cell values in a raster.

    Arguments:
    in_raster_or_constant -- The input values to find the square of.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"Square_sa",
            ["Square", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
Square.__esri_toolname__ = "Square_ia"
Square.__esri_toolinfo__ = [
    "::::1"
]


def SquareRoot(
        in_raster_or_constant):
    """SquareRoot_ia(in_raster_or_constant)

    Calculates the square root of the cell values in a raster.

    Arguments:
    in_raster_or_constant -- The input values to find the square root of.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"SquareRoot_sa",
            ["SquareRoot", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
SquareRoot.__esri_toolname__ = "SquareRoot_ia"
SquareRoot.__esri_toolinfo__ = [
    "::::1"
]


def SummarizeCategoricalRaster(
        in_raster,
        out_table,
        dimension="#",
        aoi="#",
        aoi_id_field="#"):
    """SummarizeCategoricalRaster_ia(in_raster, out_table, {dimension}, {aoi}, {aoi_id_field})

    Generates a table containing the pixel count for each class, in each slice of an input categorical raster.

    Arguments:
    in_raster -- The input multidimensional, categorical raster.
    out_table -- The output summary table. Geodatabase, database, text, Microsoft Excel, and comma-separated value (CSV) tables are supported.
    dimension -- The input dimension to use for the summary. If there is more than one dimension and no value is specified, all slices will be summarized using all combinations of dimension values.
    aoi -- The polygon feature layer containing the area or areas of interest to use when calculating the pixel count per category. If no area of interest is specified, the entire raster dataset will be included in the analysis.
    aoi_id_field -- The field in the polygon feature layer that defines each area of interest. Text and integer fields are supported."""
    @Utils.StateSwapper(Utils.StateSwapper.NoSingleRasterResult)
    def Wrapper(
            in_raster,
            out_table,
            dimension,
            aoi,
            aoi_id_field):
        result = arcpy.gp.SummarizeCategoricalRaster_ia(
            in_raster,
            out_table,
            dimension,
            aoi,
            aoi_id_field)
        return result
    return Wrapper(
        in_raster,
        out_table,
        dimension,
        aoi,
        aoi_id_field)
SummarizeCategoricalRaster.__esri_toolname__ = "SummarizeCategoricalRaster_ia"
SummarizeCategoricalRaster.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::3",
    "::::4",
    "::::5"
]


def Tan(
        in_raster_or_constant):
    """Tan_ia(in_raster_or_constant)

    Calculates the tangent of cells in a raster.

    Arguments:
    in_raster_or_constant -- The input for which to calculate the tangent values.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"Tan_sa",
            ["Tan", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
Tan.__esri_toolname__ = "Tan_ia"
Tan.__esri_toolinfo__ = [
    "::::1"
]


def TanH(
        in_raster_or_constant):
    """TanH_ia(in_raster_or_constant)

    Calculates the hyperbolic tangent of cells in a raster.

    Arguments:
    in_raster_or_constant -- The input to calculate the hyperbolic tangent values for.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant):
        return _wrapLocalFunctionRaster(u"TanH_sa",
            ["TanH", in_raster_or_constant])
    return Wrapper(
        in_raster_or_constant)
TanH.__esri_toolname__ = "TanH_ia"
TanH.__esri_toolinfo__ = [
    "::::1"
]


def Test(
        in_raster,
        where_clause):
    """Test_ia(in_raster, where_clause)

    Performs a Boolean evaluation of the input raster using a logical expression.

    Arguments:
    in_raster -- The input raster on which the Boolean evaluation is performed, based on a logical expression.
    where_clause -- The logical expression that will determine which input cells will return a value of true (1) and which will be false (0).

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster,
            where_clause):
        out_raster = "#"
        result = arcpy.gp.Test_ia(
            in_raster,
            where_clause,
            out_raster)
        return _wrapToolRaster(u"Test_sa", unicode(result.getOutput(0)))
    return Wrapper(
        in_raster,
        where_clause)
Test.__esri_toolname__ = "Test_ia"
Test.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def Times(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """Times_ia(in_raster_or_constant1, in_raster_or_constant2)

    Multiplies the values of two rasters on a cell-by-cell basis.

    Arguments:
    in_raster_or_constant1 -- The input containing the values to be multiplied.
    in_raster_or_constant2 -- The input containing the values by which the first input will be multiplied.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_raster_or_constant1,
            in_raster_or_constant2):
        return _wrapLocalFunctionRaster(u"Times_sa",
            ["Times", in_raster_or_constant1, in_raster_or_constant2])
    return Wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)
Times.__esri_toolname__ = "Times_ia"
Times.__esri_toolinfo__ = [
    "::::1",
    "::::2"
]


def TrainDeepLearningModel(
        in_folder,
        out_folder,
        max_epochs="#",
        model_type="#",
        batch_size="#",
        arguments="#",
        learning_rate="#",
        backbone_model="#",
        pretrained_model="#",
        validation_percentage="#",
        stop_training="#",
        freeze="#"):
    """TrainDeepLearningModel_ia([in_folder,...], out_folder, {max_epochs}, {model_type}, {batch_size}, {arguments}, {learning_rate}, {backbone_model}, {pretrained_model}, {validation_percentage}, {stop_training}, {freeze})

    Trains a deep learning model using the output from the Export Training Data For Deep Learning tool.

    Arguments:
    in_folder -- The folders containing the image chips, labels, and statistics required to train the model. This is the output from the Export Training Data For Deep Learning tool.
    out_folder -- The output folder location that will store the trained model.
    max_epochs -- The maximum number of epochs for which the model will be trained. A maximum epoch of one means the dataset will be passed forward and backward through the neural network one time. The default value is 20.
    model_type -- Specifies the model type that will be used to train the deep learning model.
    batch_size -- The number of training samples to be processed for training at one time. The default value is 2.
    arguments -- The function arguments are defined in the Python raster function class. This is where you list additional deep learning parameters and arguments for experiments and refinement, such as a confidence threshold for adjusting sensitivity. The names of the arguments are populated from reading the Python module.
    learning_rate -- The rate at which existing information will be overwritten with newly acquired information throughout the training process. If no value is specified, the optimal learning rate will be extracted from the learning curve during the training process.
    backbone_model -- Specifies the preconfigured neural network that will be used as the architecture for training the new model. This method is known as Transfer Learning.
    pretrained_model -- A pretrained model that will be used to fine-tune the new model. The input is an Esri Model Definition file (.emd) or a deep learning package file (.dlpk).
    validation_percentage -- The percentage of training samples that will be used for validating the model. The default value is 10.
    stop_training -- Specifies whether early stopping will be implemented.
    freeze -- Specifies whether the backbone layers in the pretrained model will be frozen, so that the weights and biases remain as originally designed."""
    @Utils.StateSwapper(Utils.StateSwapper.NoSingleRasterResult)
    def Wrapper(
            in_folder,
            out_folder,
            max_epochs,
            model_type,
            batch_size,
            arguments,
            learning_rate,
            backbone_model,
            pretrained_model,
            validation_percentage,
            stop_training,
            freeze):
        result = arcpy.gp.TrainDeepLearningModel_ia(
            in_folder,
            out_folder,
            max_epochs,
            model_type,
            batch_size,
            arguments,
            learning_rate,
            backbone_model,
            pretrained_model,
            validation_percentage,
            stop_training,
            freeze)
        return result
    return Wrapper(
        in_folder,
        out_folder,
        max_epochs,
        model_type,
        batch_size,
        arguments,
        learning_rate,
        backbone_model,
        pretrained_model,
        validation_percentage,
        stop_training,
        freeze)
TrainDeepLearningModel.__esri_toolname__ = "TrainDeepLearningModel_ia"
TrainDeepLearningModel.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::3",
    "::::4",
    "::::5",
    "::::6",
    "::::7",
    "::::8",
    "::::9",
    "::::10",
    "::::11",
    "::::12"
]


def TrainIsoClusterClassifier(
        in_raster,
        max_classes,
        out_classifier_definition,
        in_additional_raster="#",
        max_iterations="#",
        min_samples_per_cluster="#",
        skip_factor="#",
        used_attributes="#",
        max_merge_per_iter="#",
        max_merge_distance="#"):
    """TrainIsoClusterClassifier_ia(in_raster, max_classes, out_classifier_definition, {in_additional_raster}, {max_iterations}, {min_samples_per_cluster}, {skip_factor}, {[used_attribute,...]}, {max_merge_per_iter}, {max_merge_distance})

    Generates an Esri classifier definition file (.ecd) using the Iso Cluster classification definition.

    Arguments:
    in_raster -- The raster dataset to classify.
    max_classes -- Maximum number of desired classes to group pixels or segments. This should be set to be greater than the number of classes in your legend.
    out_classifier_definition -- The output JSON format file that will contain attribute information, statistics, hyperplane vectors, and other information for the classifier. An .ecd file will be created.
    in_additional_raster -- Ancillary raster datasets, such as a multispectral image or a DEM, will be incorporated to generate attributes and other required information for classification. This parameter is optional.
    max_iterations -- The maximum number of iterations the clustering process will run.
    min_samples_per_cluster -- The minimum number of pixels or segments in a valid cluster or class.
    skip_factor -- Number of pixels to skip for a pixel image input. If a segmented image is an input, specify the number of segments to skip.
    used_attribute -- Specifies the attributes that will be included in the attribute table associated with the output raster.
    max_merge_per_iter -- The maximum number of cluster merges per iteration. Increasing the number of merges will reduce the number of classes that are created. A lower value will result in more classes.
    max_merge_distance -- The maximum distance between cluster centers in feature space. Increasing the distance will allow more clusters to merge, resulting in fewer classes. A lower value will result in more classes. Values from 0 to 5 typically return the best results."""
    @Utils.StateSwapper(Utils.StateSwapper.NoSingleRasterResult)
    def Wrapper(
            in_raster,
            max_classes,
            out_classifier_definition,
            in_additional_raster,
            max_iterations,
            min_samples_per_cluster,
            skip_factor,
            used_attributes,
            max_merge_per_iter,
            max_merge_distance):
        result = arcpy.gp.TrainIsoClusterClassifier_ia(
            in_raster,
            max_classes,
            out_classifier_definition,
            in_additional_raster,
            max_iterations,
            min_samples_per_cluster,
            skip_factor,
            used_attributes,
            max_merge_per_iter,
            max_merge_distance)
        return result
    return Wrapper(
        in_raster,
        max_classes,
        out_classifier_definition,
        in_additional_raster,
        max_iterations,
        min_samples_per_cluster,
        skip_factor,
        used_attributes,
        max_merge_per_iter,
        max_merge_distance)
TrainIsoClusterClassifier.__esri_toolname__ = "TrainIsoClusterClassifier_ia"
TrainIsoClusterClassifier.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::3",
    "::::4",
    "::::5",
    "::::6",
    "::::7",
    "::::8",
    "::::9",
    "::::10"
]


def TrainKNearestNeighborClassifier(
        in_raster,
        in_training_features,
        out_classifier_definition,
        in_additional_raster="#",
        kNN="#",
        max_samples_per_class="#",
        used_attributes="#",
        dimension_value_field="#"):
    """TrainKNearestNeighborClassifier_ia(in_raster, in_training_features, out_classifier_definition, {in_additional_raster}, {kNN}, {max_samples_per_class}, {[used_attribute,...]}, {dimension_value_field})

    Generates an Esri classifier definition file (.ecd) using the K-Nearest Neighbor classification method.

    Arguments:
    in_raster -- The raster dataset to classify.
    in_training_features -- The training sample file or layer that delineates the training sites.
    out_classifier_definition -- A JSON formatted .ecd file that contains attribute information, statistics, or other information for the classifier.
    in_additional_raster -- Ancillary raster datasets, such as a multispectral image or a DEM, will be incorporated to generate attributes and other required information for classification. This parameter is optional.
    kNN -- The number of neighbors that will be used in searching for each input pixel or segment. Increasing the number of neighbors will decrease the influence of individual neighbors on the outcome of the classification. The default value is 1.
    max_samples_per_class -- The maximum number of training samples that will be used for each class. The default value of 1000 is recommended when the inputs are nonsegmented rasters. A value that is less than or equal to 0 means that the system will use all the samples from the training sites to train the classifier.
    used_attribute -- Specifies the attributes that will be included in the attribute table associated with the output raster.
    dimension_value_field -- Contains dimension values in the input training sample feature class."""
    @Utils.StateSwapper(Utils.StateSwapper.NoSingleRasterResult)
    def Wrapper(
            in_raster,
            in_training_features,
            out_classifier_definition,
            in_additional_raster,
            kNN,
            max_samples_per_class,
            used_attributes,
            dimension_value_field):
        result = arcpy.gp.TrainKNearestNeighborClassifier_ia(
            in_raster,
            in_training_features,
            out_classifier_definition,
            in_additional_raster,
            kNN,
            max_samples_per_class,
            used_attributes,
            dimension_value_field)
        return result
    return Wrapper(
        in_raster,
        in_training_features,
        out_classifier_definition,
        in_additional_raster,
        kNN,
        max_samples_per_class,
        used_attributes,
        dimension_value_field)
TrainKNearestNeighborClassifier.__esri_toolname__ = "TrainKNearestNeighborClassifier_ia"
TrainKNearestNeighborClassifier.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::3",
    "::::4",
    "::::5",
    "::::6",
    "::::7",
    "::::8"
]


def TrainMaximumLikelihoodClassifier(
        in_raster,
        in_training_features,
        out_classifier_definition,
        in_additional_raster="#",
        used_attributes="#",
        dimension_value_field="#"):
    """TrainMaximumLikelihoodClassifier_ia(in_raster, in_training_features, out_classifier_definition, {in_additional_raster}, {[used_attribute,...]}, {dimension_value_field})

    Generates an Esri classifier definition file (.ecd) using the Maximum Likelihood Classifier (MLC) classification definition.

    Arguments:
    in_raster -- The raster dataset to classify.
    in_training_features -- The training sample file or layer that delineates the training sites.
    out_classifier_definition -- The output JSON format file that will contain attribute information, statistics, hyperplane vectors, and other information for the classifier. An .ecd file will be created.
    in_additional_raster -- Incorporates ancillary raster datasets, such as a segmented image or DEM. This parameter is optional.
    used_attribute -- Specifies the attributes that will be included in the attribute table associated with the output raster.
    dimension_value_field -- Contains dimension values in the input training sample feature class."""
    @Utils.StateSwapper(Utils.StateSwapper.NoSingleRasterResult)
    def Wrapper(
            in_raster,
            in_training_features,
            out_classifier_definition,
            in_additional_raster,
            used_attributes,
            dimension_value_field):
        result = arcpy.gp.TrainMaximumLikelihoodClassifier_ia(
            in_raster,
            in_training_features,
            out_classifier_definition,
            in_additional_raster,
            used_attributes,
            dimension_value_field)
        return result
    return Wrapper(
        in_raster,
        in_training_features,
        out_classifier_definition,
        in_additional_raster,
        used_attributes,
        dimension_value_field)
TrainMaximumLikelihoodClassifier.__esri_toolname__ = "TrainMaximumLikelihoodClassifier_ia"
TrainMaximumLikelihoodClassifier.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::3",
    "::::4",
    "::::5",
    "::::6"
]


def TrainRandomTreesClassifier(
        in_raster,
        in_training_features,
        out_classifier_definition,
        in_additional_raster="#",
        max_num_trees="#",
        max_tree_depth="#",
        max_samples_per_class="#",
        used_attributes="#",
        dimension_value_field="#"):
    """TrainRandomTreesClassifier_ia(in_raster, in_training_features, out_classifier_definition, {in_additional_raster}, {max_num_trees}, {max_tree_depth}, {max_samples_per_class}, {[used_attribute,...]}, {dimension_value_field})

    Generates an Esri classifier definition file (.ecd) using the Random Trees classification method.

    Arguments:
    in_raster -- The raster dataset to classify.
    in_training_features -- The training sample file or layer that delineates the training sites.
    out_classifier_definition -- A JSON file that contains attribute information, statistics, or other information for the classifier. An .ecd file is created.
    in_additional_raster -- Ancillary raster datasets, such as a multispectral image or a DEM, will be incorporated to generate attributes and other required information for classification. This parameter is optional.
    max_num_trees -- The maximum number of trees in the forest. Increasing the number of trees will lead to higher accuracy rates, although this improvement will level off eventually. The number of trees increases the processing time linearly.
    max_tree_depth -- The maximum depth of each tree in the forest. Depth is another way of saying the number of rules each tree is allowed to create to come to a decision. Trees will not grow any deeper than this setting.
    max_samples_per_class -- The maximum number of samples that will be used to define each class.
    used_attribute -- Specifies the attributes that will be included in the attribute table associated with the output raster.
    dimension_value_field -- Contains dimension values in the input training sample feature class."""
    @Utils.StateSwapper(Utils.StateSwapper.NoSingleRasterResult)
    def Wrapper(
            in_raster,
            in_training_features,
            out_classifier_definition,
            in_additional_raster,
            max_num_trees,
            max_tree_depth,
            max_samples_per_class,
            used_attributes,
            dimension_value_field):
        result = arcpy.gp.TrainRandomTreesClassifier_ia(
            in_raster,
            in_training_features,
            out_classifier_definition,
            in_additional_raster,
            max_num_trees,
            max_tree_depth,
            max_samples_per_class,
            used_attributes,
            dimension_value_field)
        return result
    return Wrapper(
        in_raster,
        in_training_features,
        out_classifier_definition,
        in_additional_raster,
        max_num_trees,
        max_tree_depth,
        max_samples_per_class,
        used_attributes,
        dimension_value_field)
TrainRandomTreesClassifier.__esri_toolname__ = "TrainRandomTreesClassifier_ia"
TrainRandomTreesClassifier.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::3",
    "::::4",
    "::::5",
    "::::6",
    "::::7",
    "::::8",
    "::::9"
]


def TrainRandomTreesRegressionModel(
        in_rasters,
        in_target_data,
        out_regression_definition,
        target_value_field="#",
        target_dimension_field="#",
        raster_dimension="#",
        out_importance_table="#",
        max_num_trees="#",
        max_tree_depth="#",
        max_samples="#",
        average_points_per_cell="#",
        percent_testing="#",
        out_scatterplots="#",
        out_sample_features="#"):
    """TrainRandomTreesRegressionModel_ia([in_raster,...], in_target_data, out_regression_definition, {target_value_field}, {target_dimension_field}, {raster_dimension}, {out_importance_table}, {max_num_trees}, {max_tree_depth}, {max_samples}, {average_points_per_cell}, {percent_testing}, {out_scatterplots}, {out_sample_features})

    Models the relationship between explanatory variables (independent variables) and a target dataset (dependent variable).

    Arguments:
    in_raster -- The single-band, multidimensional, or multiband raster datasets, or mosaic datasets containing explanatory variables.
    in_target_data -- The raster or point feature class containing the target variable (dependant variable) data.
    out_regression_definition -- A JSON format file with an .ecd extension that contains attribute information, statistics, or other information for the classifier.
    target_value_field -- The field name of the information to model in the target point feature class or raster dataset.
    target_dimension_field -- A date field or numeric field in the input point feature class that defines the dimension values.
    raster_dimension -- The dimension name of the input multidimensional raster (explanatory variables) that links to the dimension in the target data.
    out_importance_table -- A table containing information describing the importance of each explanatory variable used in the model. A larger number indicates the corresponding variable is more correlated to the predicted variable and will contribute more in prediction. Values range between 0 and 1, and the sum of all the values equals 1.
    max_num_trees -- The maximum number of trees in the forest. Increasing the number of trees will lead to higher accuracy rates, although this improvement will level off. The number of trees increases the processing time linearly. The default is 50.
    max_tree_depth -- The maximum depth of each tree in the forest. Depth determines the number of rules each tree can create, resulting in a decision. Trees will not grow any deeper than this setting. The default is 30.
    max_samples -- The maximum number of samples that will be used for the regression analysis. A value that is less than or equal to 0 means that the system will use all the samples from the input target raster or point feature class to train the regression model. The default value is 10,000.
    average_points_per_cell -- Specifies whether the average will be calculated when multiple training points fall into one cell. This parameter is applicable only when the input target is a point feature class.
    percent_testing -- The percentage of test points that will be used for error checking. The tool checks for three types of errors: errors on training points, errors on test points, and errors on test location points. The default is 10.
    out_scatterplots -- The output scatter plots in PDF or HTML format. The output will include scatter plots of training data, test data, and location test data.
    out_sample_features -- The output feature class that will contain target values and predicted values for training points, test points, and location test points."""
    @Utils.StateSwapper(Utils.StateSwapper.NoSingleRasterResult)
    def Wrapper(
            in_rasters,
            in_target_data,
            out_regression_definition,
            target_value_field,
            target_dimension_field,
            raster_dimension,
            out_importance_table,
            max_num_trees,
            max_tree_depth,
            max_samples,
            average_points_per_cell,
            percent_testing,
            out_scatterplots,
            out_sample_features):
        result = arcpy.gp.TrainRandomTreesRegressionModel_ia(
            in_rasters,
            in_target_data,
            out_regression_definition,
            target_value_field,
            target_dimension_field,
            raster_dimension,
            out_importance_table,
            max_num_trees,
            max_tree_depth,
            max_samples,
            average_points_per_cell,
            percent_testing,
            out_scatterplots,
            out_sample_features)
        return result
    return Wrapper(
        in_rasters,
        in_target_data,
        out_regression_definition,
        target_value_field,
        target_dimension_field,
        raster_dimension,
        out_importance_table,
        max_num_trees,
        max_tree_depth,
        max_samples,
        average_points_per_cell,
        percent_testing,
        out_scatterplots,
        out_sample_features)
TrainRandomTreesRegressionModel.__esri_toolname__ = "TrainRandomTreesRegressionModel_ia"
TrainRandomTreesRegressionModel.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::3",
    "::::4",
    "::::5",
    "::::6",
    "::::7",
    "::::8",
    "::::9",
    "::::10",
    "::::11",
    "::::12",
    "::::13",
    "::::14"
]


def TrainSupportVectorMachineClassifier(
        in_raster,
        in_training_features,
        out_classifier_definition,
        in_additional_raster="#",
        max_samples_per_class="#",
        used_attributes="#",
        dimension_value_field="#"):
    """TrainSupportVectorMachineClassifier_ia(in_raster, in_training_features, out_classifier_definition, {in_additional_raster}, {max_samples_per_class}, {[used_attribute,...]}, {dimension_value_field})

    Generates an Esri classifier definition file (.ecd) using the Support Vector Machine (SVM) classification definition.

    Arguments:
    in_raster -- The raster dataset to classify.
    in_training_features -- The training sample file or layer that delineates the training sites.
    out_classifier_definition -- The output JSON format file that will contain attribute information, statistics, hyperplane vectors, and other information for the classifier. An .ecd file will be created.
    in_additional_raster -- Ancillary raster datasets, such as a multispectral image or a DEM, will be incorporated to generate attributes and other required information for classification. This parameter is optional.
    max_samples_per_class -- The maximum number of samples that will be used to define each class.
    used_attribute -- Specifies the attributes that will be included in the attribute table associated with the output raster.
    dimension_value_field -- Contains dimension values in the input training sample feature class."""
    @Utils.StateSwapper(Utils.StateSwapper.NoSingleRasterResult)
    def Wrapper(
            in_raster,
            in_training_features,
            out_classifier_definition,
            in_additional_raster,
            max_samples_per_class,
            used_attributes,
            dimension_value_field):
        result = arcpy.gp.TrainSupportVectorMachineClassifier_ia(
            in_raster,
            in_training_features,
            out_classifier_definition,
            in_additional_raster,
            max_samples_per_class,
            used_attributes,
            dimension_value_field)
        return result
    return Wrapper(
        in_raster,
        in_training_features,
        out_classifier_definition,
        in_additional_raster,
        max_samples_per_class,
        used_attributes,
        dimension_value_field)
TrainSupportVectorMachineClassifier.__esri_toolname__ = "TrainSupportVectorMachineClassifier_ia"
TrainSupportVectorMachineClassifier.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::3",
    "::::4",
    "::::5",
    "::::6",
    "::::7"
]


def UpdateAccuracyAssessmentPoints(
        in_class_data,
        in_points,
        out_points,
        target_field="#",
        polygon_dimension_field="#",
        point_dimension_field="#"):
    """UpdateAccuracyAssessmentPoints_ia(in_class_data, in_points, out_points, {target_field}, {polygon_dimension_field}, {point_dimension_field})

    Updates the Target field in the attribute table to compare reference points to the classified image.

    Arguments:
    in_class_data -- The input classification image or other thematic GIS reference data. The input can be a raster or feature class.
    in_points -- The point feature class providing the accuracy assessment points to be updated.
    out_points -- The output point feature class that contains the updated random point field for accuracy assessment purposes.
    target_field -- Specifies whether the input data is a classified image or ground truth data.
    polygon_dimension_field -- The dimension field for the Input Accuracy Assessment Points parameter value. The assessment points will be updated based on the matching dimension values with this field.
    point_dimension_field -- The dimension field in the Input Accuracy Assessment Points parameter value. Input data with identical dimension values will be used to update corresponding points."""
    @Utils.StateSwapper(Utils.StateSwapper.NoSingleRasterResult)
    def Wrapper(
            in_class_data,
            in_points,
            out_points,
            target_field,
            polygon_dimension_field,
            point_dimension_field):
        result = arcpy.gp.UpdateAccuracyAssessmentPoints_ia(
            in_class_data,
            in_points,
            out_points,
            target_field,
            polygon_dimension_field,
            point_dimension_field)
        return result
    return Wrapper(
        in_class_data,
        in_points,
        out_points,
        target_field,
        polygon_dimension_field,
        point_dimension_field)
UpdateAccuracyAssessmentPoints.__esri_toolname__ = "UpdateAccuracyAssessmentPoints_ia"
UpdateAccuracyAssessmentPoints.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::3",
    "::::4",
    "::::5",
    "::::6"
]


def VideoMetadataToFeatureClass(
        in_video,
        csv_file="#",
        flightpath="#",
        flightpath_type="#",
        imagepath="#",
        imagepath_type="#",
        footprint="#",
        start_time="#",
        stop_time="#",
        min_distance="#",
        min_time="#"):
    """VideoMetadataToFeatureClass_ia(in_video, {csv_file}, {flightpath}, {flightpath_type}, {imagepath}, {imagepath_type}, {footprint}, {start_time}, {stop_time}, {min_distance}, {min_time})

    Extracts the platform, frame center, frame outline, and attributes metadata from an FMV-compliant video. The output geometry and attributes are saved as feature classes.

    Arguments:
    in_video -- The FMV-compliant input video file containing essential metadata for each frame of the video data. The supported video file types include PS, TS, MPG, MPEG, MP2, MPG2, MPEG2, MP4, MPG4, MPEG4, H264, VOB, and M2TS.
    csv_file -- A comma-separated values (CSV) file containing metadata about the video frames for specific times.
    flightpath -- The feature class containing the sensor's flight path information.
    flightpath_type -- Specifies the feature class type for the flight path.
    imagepath -- The output feature class containing the image path information.
    imagepath_type -- Specifies the feature class type for the image path. If you're using a point output, the center of each video frame image will appear on the map.
    footprint -- The output feature class containing the video image footprint information.
    start_time -- The metadata recording start time from the beginning of the video. The input format is d.hh:mm:ss, and the default start time is 0.00:00:00. Metadata time stamps are not used in this field; the time of the video file is used.
    stop_time -- The metadata recording end time. The input format is d.hh:mm:ss. If not set, the value will default to the end of the video. Metadata time stamps are not used in this field.
    min_distance -- The distance between the features in sequential video frames. If left blank, every metadata feature will be extracted and added to the feature class.
    min_time -- The time interval between the features in sequential video frames. If left blank, every metadata feature will be extracted and added to the feature class."""
    @Utils.StateSwapper(Utils.StateSwapper.NoSingleRasterResult)
    def Wrapper(
            in_video,
            csv_file,
            flightpath,
            flightpath_type,
            imagepath,
            imagepath_type,
            footprint,
            start_time,
            stop_time,
            min_distance,
            min_time):
        result = arcpy.gp.VideoMetadataToFeatureClass_ia(
            in_video,
            csv_file,
            flightpath,
            flightpath_type,
            imagepath,
            imagepath_type,
            footprint,
            start_time,
            stop_time,
            min_distance,
            min_time)
        return result
    return Wrapper(
        in_video,
        csv_file,
        flightpath,
        flightpath_type,
        imagepath,
        imagepath_type,
        footprint,
        start_time,
        stop_time,
        min_distance,
        min_time)
VideoMetadataToFeatureClass.__esri_toolname__ = "VideoMetadataToFeatureClass_ia"
VideoMetadataToFeatureClass.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::3",
    "::::4",
    "::::5",
    "::::6",
    "::::7",
    "::::8",
    "::::9",
    "::::10",
    "::::11"
]


def VideoMultiplexer(
        in_video_file,
        metadata_file,
        out_video_file,
        metadata_mapping_file="#",
        timeshift_file="#",
        elevation_layer="#"):
    """VideoMultiplexer_ia(in_video_file, metadata_file, out_video_file, {metadata_mapping_file}, {timeshift_file}, {elevation_layer})

    Creates a video file that combines an archived video stream file and an associated metadata file synchronized by a time stamp.

    Arguments:
    in_video_file -- The input video file that will be converted to a FMV-compliant video file.
    metadata_file -- A comma-separated values (CSV) file containing metadata about the video frames for specific times.
    out_video_file -- The name of the output video file, including the file extension.
    metadata_mapping_file -- A CSV file that contains 5 columns and 87 rows and is based on the FMV_Multiplexer_Field_Mapping_Template.csv template file obtained from C:\Program Files\ArcGIS\Pro\Resources\FullMotionVideo.
    timeshift_file -- A file containing defined time shift intervals.
    elevation_layer -- The source of the elevation needed for calculating the video frame corner coordinates. The source can be a layer, image service, or an average ground elevation or ocean depth. The average elevation value needs to include the units of measurement such as meters or feet or other measure of length."""
    @Utils.StateSwapper(Utils.StateSwapper.NoSingleRasterResult)
    def Wrapper(
            in_video_file,
            metadata_file,
            out_video_file,
            metadata_mapping_file,
            timeshift_file,
            elevation_layer):
        result = arcpy.gp.VideoMultiplexer_ia(
            in_video_file,
            metadata_file,
            out_video_file,
            metadata_mapping_file,
            timeshift_file,
            elevation_layer)
        return result
    return Wrapper(
        in_video_file,
        metadata_file,
        out_video_file,
        metadata_mapping_file,
        timeshift_file,
        elevation_layer)
VideoMultiplexer.__esri_toolname__ = "VideoMultiplexer_ia"
VideoMultiplexer.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::3",
    "::::4",
    "::::5",
    "::::6"
]


def WeightedSum(
        in_weighted_sum_table):
    """WeightedSum_ia(in_weighted_sum_table)

    Overlays several rasters, multiplying each by their given weight and summing them together.

    Arguments:
    in_weighted_sum_table -- The weighted sum table allows you to apply different weights to individual input rasters before they are summed together.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_weighted_sum_table):
        in_weighted_sum_table = Utils.compoundParameterToString(in_weighted_sum_table, ParameterClasses.WSTable)
        # parse out raster names to use as local function arguments
        import re as _re  # Use underscore to avoid polluting user's namespace
        # Construct a regular expression to parse the string version of a single weighted sum table entry
        # for example: "'landuse.tif' VALUE 0.34"
        pattern = _re.compile(pattern=r"""
            ^                   # beginning of string
            \s*                 # any amount of white space
            (?P<raster>.*\S)    # 1. raster name
            \s+                 # at least one white space
            (?P<field>\S+)      # 2. raster field name
            \s+                 # at least one white space
            (?P<weight>\S+)     # 3. raster weight value
            \s*                 # any amount of white space
            $                   # end of string
        """, flags=_re.VERBOSE)
        rasters = ["WeightedSum", ]  # local functions take a list of op name followed by rasters
        fields = []
        weights = []
        for item in in_weighted_sum_table.split(";"):
            item = item.strip()
            if len(item) < 1:
                continue
            m = pattern.match(item)
            raster_name = m.group("raster")
            raster_field = m.group("field")
            weight = float(m.group("weight"))
            raster_name = raster_name.strip("\"'")  # remove surrounding quotation marks
            rasters.append(raster_name)
            fields.append(raster_field)
            weights.append(weight)
        return _wrapLocalFunctionRaster(
            u"WeightedSum_sa",
            rasters,
            {"fields": fields, "weights": weights, "flattenBands": True},
        )
    return Wrapper(
        in_weighted_sum_table)
WeightedSum.__esri_toolname__ = "WeightedSum_ia"
WeightedSum.__esri_toolinfo__ = [
    "Python::WSTable::"
]


def ZonalStatistics(
        in_zone_data,
        zone_field,
        in_value_raster,
        statistics_type="#",
        ignore_nodata="#",
        process_as_multidimensional="#",
        percentile_value="#",
        percentile_interpolation_type="#"):
    """ZonalStatistics_ia(in_zone_data, zone_field, in_value_raster, {statistics_type}, {ignore_nodata}, {process_as_multidimensional}, {percentile_value}, {percentile_interpolation_type})

    Calculates statistics on values of a raster within the zones of another dataset.

    Arguments:
    in_zone_data -- The dataset that defines the zones.
    zone_field -- The field that contains the values that define each zone.
    in_value_raster -- The raster that contains the values on which to calculate a statistic.
    statistics_type -- Specifies the statistic type to be calculated.
    ignore_nodata -- Specifies whether NoData values in the value input will be ignored in the results of the zone that they fall within.
    process_as_multidimensional -- Specifies how the input rasters will be processed if they are multidimensional.
    percentile_value -- The percentile to calculate. The default is 90, indicating the 90th percentile.
    percentile_interpolation_type -- Specifies the method of interpolation to be used when the percentile value falls in between two cell values from the input value raster.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def Wrapper(
            in_zone_data,
            zone_field,
            in_value_raster,
            statistics_type,
            ignore_nodata,
            process_as_multidimensional,
            percentile_value,
            percentile_interpolation_type):
        out_raster = "#"
        result = arcpy.gp.ZonalStatistics_ia(
            in_zone_data,
            zone_field,
            in_value_raster,
            out_raster,
            statistics_type,
            ignore_nodata,
            process_as_multidimensional,
            percentile_value,
            percentile_interpolation_type)
        return _wrapToolRaster(u"ZonalStatistics_sa", unicode(result.getOutput(0)))
    return Wrapper(
        in_zone_data,
        zone_field,
        in_value_raster,
        statistics_type,
        ignore_nodata,
        process_as_multidimensional,
        percentile_value,
        percentile_interpolation_type)
ZonalStatistics.__esri_toolname__ = "ZonalStatistics_ia"
ZonalStatistics.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::3",
    "::::5",
    "::::6",
    "::::7",
    "::::8",
    "::::9"
]


def ZonalStatisticsAsTable(
        in_zone_data,
        zone_field,
        in_value_raster,
        out_table,
        ignore_nodata="#",
        statistics_type="#",
        process_as_multidimensional="#",
        percentile_values="#",
        percentile_interpolation_type="#"):
    """ZonalStatisticsAsTable_ia(in_zone_data, zone_field, in_value_raster, out_table, {ignore_nodata}, {statistics_type}, {process_as_multidimensional}, {[percentile_value,...]}, {percentile_interpolation_type})

    Summarizes the values of a raster within the zones of another dataset and reports the results as a table.

    Arguments:
    in_zone_data -- The dataset that defines the zones.
    zone_field -- The field that contains the values that define each zone.
    in_value_raster -- The raster that contains the values on which to calculate a statistic.
    out_table -- The output table that will contain the summary of the values in each zone.
    ignore_nodata -- Specifies whether NoData values in the value input will be ignored in the results of the zone that they fall within.
    statistics_type -- Specifies the statistic type to be calculated.
    process_as_multidimensional -- Specifies how the input rasters will be processed if they are multidimensional.
    percentile_value -- The percentile to calculate. The default is 90, indicating the 90th percentile.
    percentile_interpolation_type -- Specifies the method of interpolation to be used when the percentile value falls in between two cell values from the input value raster."""
    @Utils.StateSwapper(Utils.StateSwapper.NoSingleRasterResult)
    def Wrapper(
            in_zone_data,
            zone_field,
            in_value_raster,
            out_table,
            ignore_nodata,
            statistics_type,
            process_as_multidimensional,
            percentile_values,
            percentile_interpolation_type):
        result = arcpy.gp.ZonalStatisticsAsTable_ia(
            in_zone_data,
            zone_field,
            in_value_raster,
            out_table,
            ignore_nodata,
            statistics_type,
            process_as_multidimensional,
            percentile_values,
            percentile_interpolation_type)
        return result
    return Wrapper(
        in_zone_data,
        zone_field,
        in_value_raster,
        out_table,
        ignore_nodata,
        statistics_type,
        process_as_multidimensional,
        percentile_values,
        percentile_interpolation_type)
ZonalStatisticsAsTable.__esri_toolname__ = "ZonalStatisticsAsTable_ia"
ZonalStatisticsAsTable.__esri_toolinfo__ = [
    "::::1",
    "::::2",
    "::::3",
    "::::4",
    "::::5",
    "::::6",
    "::::7",
    "::::8",
    "::::9"
]

def ApplyEnvironment(
        in_raster):
    """ApplyEnvironment(in_raster)

    Creates a copy of in_raster with environment settings applied.

    Arguments:
    in_raster -- The input that will be copied.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def wrapper(in_raster):
        return _wrapLocalFunctionRaster(u"ApplyEnvironment",
            ["Copy", in_raster])
    return wrapper(
        in_raster)

def FloatDivide(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """FloatDivide(in_raster_or_constant1, in_raster_or_constant2)

    Divides the values of two rasters on a cell-by-cell basis. The result will
    be a true floating point division.

    Arguments:
    in_raster_or_constant1 -- The input whose values will be divided by the second input.
    in_raster_or_constant2 -- The input whose values the first input are to be divided by.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def wrapper(in_raster_or_constant1,
            in_raster_or_constant2):
        return _wrapLocalFunctionRaster(u"Divide_sa",
            ["FloatDivide", in_raster_or_constant1, in_raster_or_constant2])
    return wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)

def FloorDivide(
        in_raster_or_constant1,
        in_raster_or_constant2):
    """FloorDivide(in_raster_or_constant1, in_raster_or_constant2)

    Divides the values of two rasters on a cell-by-cell basis. The result will
    be a floored floating point division.

    Arguments:
    in_raster_or_constant1 -- The input whose values will be divided by the second input.
    in_raster_or_constant2 -- The input whose values the first input are to be divided by.

    Results:
    out_raster -- Output raster"""
    @Utils.StateSwapper(Utils.StateSwapper.SingleRasterResult)
    def wrapper(
            in_raster_or_constant1,
            in_raster_or_constant2):
        return _wrapLocalFunctionRaster(u"Divide_sa",
            ["FloorDivide", in_raster_or_constant1, in_raster_or_constant2])
    return wrapper(
        in_raster_or_constant1,
        in_raster_or_constant2)